@@ -1,7 +1,7 @@
 ;; Lepton EDA library - Scheme API
 ;; Copyright (C) 2010-2011 Peter Brett <peter@peter-b.co.uk>
 ;; Copyright (C) 2012-2016 gEDA Contributors
-;; Copyright (C) 2017-2020 Lepton EDA Contributors
+;; Copyright (C) 2017-2021 Lepton EDA Contributors
 ;;
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -22,34 +22,119 @@
   ;; Optional arguments
   #:use-module (ice-9 optargs)
   #:use-module (srfi srfi-1)
+  #:use-module (system foreign)
+  #:use-module (rnrs bytevectors)
 
   ;; Import C procedures
   #:use-module (lepton core component)
   #:use-module (lepton core object)
-  #:use-module (lepton core smob))
+  #:use-module (lepton ffi)
 
-(define-public object-type %object-type)
-(define-public object-id %object-id)
-(define-public object? %object?)
+  #:export (object?
+            object-id
+            object-type
+            object-type?
+            arc?
+            box?
+            bus?
+            circle?
+            component?
+            line?
+            net?
+            path?
+            picture?
+            pin?
+            text?
+            copy-object
+            object-bounds
+            object-color
+            set-object-color!
+            object-component
+            object-embedded?
+            set-object-embedded!
+            object-selectable?
+            set-object-selectable!))
 
-(define-public (object-type? x type)
-  (if (object? x)
-      (eq? (object-type x) type)
-      #f))
+(define (object? object)
+  "Returns #t if OBJECT is a #<geda-object> instance, otherwise
+returns #f."
+  (true? (edascm_is_object (scm->pointer object))))
 
-(define-public copy-object %copy-object)
 
-(define-public object-color %object-color)
-(define-public set-object-color! %set-object-color!)
+(define (object-id object)
+  "Returns an internal id number of the OBJECT."
+  (let ((id (lepton_object_get_id (geda-object->pointer object))))
+    (and (not (= id -1))
+         id)))
+
+
+(define (object-type object)
+  "Returns a Scheme symbol representing the type of OBJECT."
+  (define pointer (geda-object->pointer* object 1))
+
+  (cond
+   ((arc? object) 'arc)
+   ((box? object) 'box)
+   ((bus? object) 'bus)
+   ((circle? object) 'circle)
+   ((component? object) 'complex)
+   ((line? object) 'line)
+   ((net? object) 'net)
+   ((path? object) 'path)
+   ((picture? object) 'picture)
+   ((pin? object) 'pin)
+   ((text? object) 'text)
+   (else (error "Object ~A has bad type '~A'"
+                object
+                (integer->char (lepton_object_get_type pointer))))))
+
+(define (object-type? x type)
+  (and (object? x)
+       (eq? (object-type x) type)))
+
+(define (copy-object object)
+  "Returns a copy of OBJECT."
+  (define pointer (geda-object->pointer* object 1))
+
+  (pointer->geda-object (lepton_object_copy pointer)))
+
+
+(define (object-color object)
+  "Returns the colormap index of the color used to draw
+OBJECT. Note that the color may not be meaningful for some object
+types."
+  (define pointer (geda-object->pointer* object 1))
+
+  (lepton_object_get_color pointer))
+
+
+(define (set-object-color! object color)
+  "Set the colormap index of the color used to draw OBJECT to COLOR.
+Note that the color may not be meaningful for some object types.
+Returns OBJECT."
+  (define pointer (geda-object->pointer* object 1))
+
+  (lepton_object_set_color pointer color)
+
+  object)
+
 
 (define-public object-connections %object-connections)
 
-(define-public object-component %object-component)
+(define (object-component object)
+  "Returns the component object that contains OBJECT.
+If OBJECT is not part of a component, returns #f."
+  (define pointer (geda-object->pointer* object 1))
+
+  (let ((parent-pointer (lepton_object_get_parent pointer)))
+    (and (not (null-pointer? parent-pointer))
+         (pointer->geda-object parent-pointer))))
 
 ;;;; Lines
 
-(define-public (line? l)
-  (object-type? l 'line))
+(define (line? object)
+  "Returns #t if OBJECT is a line object, otherwise returns #f."
+  (true? (lepton_object_is_line (geda-object->pointer object))))
 
 (define*-public (set-line! l start end #:optional color)
   (%set-line! l
@@ -79,8 +164,9 @@
 
 ;;;; Nets
 
-(define-public (net? l)
-  (object-type? l 'net))
+(define-public (net? object)
+  "Returns #t if OBJECT is a net object, otherwise returns #f."
+  (true? (lepton_object_is_net (geda-object->pointer object))))
 
 (define*-public (make-net start end #:optional color)
   (let ((l (%make-net)))
@@ -88,8 +174,9 @@
 
 ;;;; Buses
 
-(define-public (bus? l)
-  (object-type? l 'bus))
+(define (bus? object)
+  "Returns #t if OBJECT is a bus object, otherwise returns #f."
+  (true? (lepton_object_is_bus (geda-object->pointer object))))
 
 (define*-public (make-bus start end #:optional color)
   (let ((l (%make-bus)))
@@ -97,8 +184,9 @@
 
 ;;;; Pins
 
-(define-public (pin? l)
-  (object-type? l 'pin))
+(define (pin? object)
+  "Returns #t if OBJECT is a pin object, otherwise returns #f."
+  (true? (lepton_object_is_pin (geda-object->pointer object))))
 
 (define-public (net-pin? l)
   (and (pin? l) (equal? (%pin-type l) 'net)))
@@ -117,8 +205,9 @@
 ;;;; Boxes
 
 
-(define-public (box? l)
-  (object-type? l 'box))
+(define (box? object)
+  "Returns #t if OBJECT is a box object, otherwise returns #f."
+  (true? (lepton_object_is_box (geda-object->pointer object))))
 
 (define*-public (set-box! b top-left bottom-right #:optional color)
   (%set-box! b
@@ -148,8 +237,9 @@
 
 ;;;; Circles
 
-(define-public (circle? c)
-  (object-type? c 'circle))
+(define (circle? object)
+  "Returns #t if OBJECT is a circle object, otherwise returns #f."
+  (true? (lepton_object_is_circle (geda-object->pointer object))))
 
 (define*-public (set-circle! c center radius #:optional color)
   (%set-circle! c
@@ -178,8 +268,9 @@
 
 ;;;; Arcs
 
-(define-public (arc? a)
-  (object-type? a 'arc))
+(define (arc? object)
+  "Returns #t if OBJECT is a arc object, otherwise returns #f."
+  (true? (lepton_object_is_arc (geda-object->pointer object))))
 
 (define*-public (set-arc! a center radius start-angle sweep-angle
                           #:optional color)
@@ -218,8 +309,9 @@
 
 ;;;; Paths
 
-(define-public (path? x)
-  (object-type? x 'path))
+(define (path? object)
+  "Returns #t if OBJECT is a path object, otherwise returns #f."
+  (true? (lepton_object_is_path (geda-object->pointer object))))
 
 (define*-public (make-path #:optional color)
   (let ((p (%make-path)))
@@ -264,8 +356,9 @@
 
 ;;;; Pictures
 
-(define-public (picture? x)
-  (object-type? x 'picture))
+(define (picture? object)
+  "Returns #t if OBJECT is a picture object, otherwise returns #f."
+  (true? (lepton_object_is_picture (geda-object->pointer object))))
 
 (define-public (set-picture! p top-left bottom-right angle mirror)
   (%set-picture! p (car top-left) (cdr top-left)
@@ -304,8 +397,9 @@
 
 ;;;; Text
 
-(define-public (text? t)
-  (object-type? t 'text))
+(define (text? object)
+  "Returns #t if OBJECT is a text object, otherwise returns #f."
+  (true? (lepton_object_is_text (geda-object->pointer object))))
 
 (define*-public (set-text! t anchor align angle string size visible show
                            #:optional color)
@@ -356,17 +450,18 @@
 
 ;;;; Component objects
 
-(define-public (component? c)
-  (object-type? c 'complex))
+(define (component? object)
+  "Returns #t if OBJECT is a component object, otherwise returns #f."
+  (true? (lepton_object_is_component (geda-object->pointer object))))
 
 (define-public (set-component! c position angle mirror locked)
   (%set-component! c (car position) (cdr position) angle mirror locked))
 
 (define-public (set-component-with-transform! c position angle mirror locked)
   (let ((obj (%set-component! c 0 0 0 #f locked)))
-    (%translate-object!
-      (%rotate-object!
-        (if mirror (%mirror-object! obj 0) obj)
+    (translate-object!
+      (rotate-object!
+        (if mirror (mirror-object! obj 0) obj)
         0 0 angle)
     (car position)
     (cdr position))))
@@ -435,45 +530,171 @@
 
 ;;;; Object bounds
 
-(define-public object-bounds %object-bounds)
+;;; Get bounds of one object.
+(define (one-object-bounds object)
+  (define pointer (geda-object->pointer* object 1))
+  (define xmin (make-bytevector (sizeof int)))
+  (define ymin (make-bytevector (sizeof int)))
+  (define xmax (make-bytevector (sizeof int)))
+  (define ymax (make-bytevector (sizeof int)))
+
+  (let ((result (lepton_object_calculate_visible_bounds
+                 pointer
+                 ;; If to include hidden text objects.
+                 1
+                 (bytevector->pointer xmin)
+                 (bytevector->pointer ymin)
+                 (bytevector->pointer xmax)
+                 (bytevector->pointer ymax))))
+    (and (= result 1)
+         (cons (cons (bytevector-sint-ref xmin 0 (native-endianness) (sizeof int))
+                     (bytevector-sint-ref ymax 0 (native-endianness) (sizeof int)))
+               (cons (bytevector-sint-ref xmax 0 (native-endianness) (sizeof int))
+                     (bytevector-sint-ref ymin 0 (native-endianness) (sizeof int)))))))
+
 
 (define-public (fold-bounds . bounds)
   (fold
    (lambda (a b)
      (if (and a b)
-         ;; calc bounds
+         ;; Calculate bounds.
          (cons (cons (min (caar a) (caar b))    ; left
                      (max (cdar a) (cdar b)))   ; top
                (cons (max (cadr a) (cadr b))    ; right
-                     (min (cddr a) (cddr b)))) ; bottom
+                     (min (cddr a) (cddr b))))  ; bottom
 
-         ;; return whichever isn't #f
+         ;; Return whichever isn't #f.
          (or a b)))
-   #f ;; default
+   ;; Default.
+   #f
    bounds))
 
+(define (object-bounds . objects)
+  "Returns the bounds of the objects in the variable-length
+argument list OBJECTS.  The bounds are returned as a pair
+structure of the form: ((left . top) . (right . bottom)).  If the
+list OBJECTS is empty, or none of the objects has any
+bounds (e.g. because they are all empty components and/or text
+strings), returns #f.  Warning: This function always returns the
+actual bounds of the objects, not the visible bounds."
+  (apply fold-bounds (map one-object-bounds objects)))
+
+
 ;;;; Object transformations
 
 (define-public (translate-objects! vector . objects)
   (for-each
-   (lambda (x) (%translate-object! x (car vector) (cdr vector)))
+   (lambda (x) (translate-object! x (car vector) (cdr vector)))
    objects)
   objects)
 
 (define-public (rotate-objects! center angle . objects)
   (for-each
-   (lambda (x) (%rotate-object! x (car center) (cdr center) angle))
+   (lambda (x) (rotate-object! x (car center) (cdr center) angle))
    objects)
   objects)
 
 (define-public (mirror-objects! x . objects)
   (for-each
-   (lambda (obj) (%mirror-object! obj x))
+   (lambda (obj) (mirror-object! obj x))
    objects)
   objects)
 
-( define-public object-selectable?     %object-selectable? )
-( define-public set-object-selectable! %set-object-selectable! )
 
-( define-public object-embedded?     %object-embedded? )
-( define-public set-object-embedded! %set-object-embedded! )
+(define (object-selectable? object)
+  "Checks the state of OBJECT's selectable flag: if it's true, the
+object is considered to be unlocked, otherwise it is locked.
+Returns #t if OBJECT is selectable, otherwise returns #f."
+  (define pointer (geda-object->pointer* object 1))
+
+  (true? (lepton_object_get_selectable pointer)))
+
+
+(define (set-object-selectable! object selectable?)
+  "Sets OBJECT's selectable flag to SELECTABLE?, thus locking or
+unlocking OBJECT.  Locked objects cannot be selected in GUI.
+Returns OBJECT."
+  (define pointer (geda-object->pointer* object 1))
+
+  (unless (eq? (object-selectable? object) selectable?)
+    (lepton_object_set_selectable pointer (if selectable? 1 0))
+    (lepton_object_page_set_changed pointer))
+
+  object)
+
+
+
+(define (object-embedded? object)
+  "Check whether OBJECT is embedded."
+  (define pointer (geda-object->pointer* object 1))
+
+  (or (and (component? object)
+           (true? (lepton_component_object_get_embedded pointer)))
+      (and (picture? object)
+           (true? (lepton_picture_object_get_embedded pointer)))))
+
+
+(define (set-object-embedded! object embed?)
+  "Unembeds OBJECT if EMBED? is #f, otherwise embeds it.  OBJECT
+must be a component or a picture, otherwise the procedure does
+nothing.  Returns OBJECT."
+  (define (embed-func embed unembed)
+    (if embed? embed unembed))
+
+  (define (embed-component x)
+    ((embed-func lepton_component_object_embed
+                 lepton_component_object_unembed) x))
+
+  (define (embed-picture x)
+    ((embed-func lepton_picture_object_embed
+                 lepton_picture_object_unembed) x))
+
+  (define pointer (geda-object->pointer* object 1))
+
+  (or (and (component? object) (embed-component pointer))
+      (and (picture? object) (embed-picture pointer)))
+
+  object)
+
+;;; Mirrors OBJECT using X as x-coordinate of centre of rotation.
+;;; Returns OBJECT.
+(define (mirror-object! object x)
+  (define pointer (geda-object->pointer* object 1))
+
+  (lepton_object_emit_pre_change_notify pointer)
+  (lepton_object_mirror x 0 pointer)
+  (lepton_object_emit_change_notify pointer)
+  (lepton_object_page_set_changed pointer)
+
+  object)
+
+
+;;; Rotates OBJECT anti-clockwise by ANGLE about the coordinate of
+;;; centre of rotation specified by X and Y.  ANGLE must be an
+;;; integer multiple of 90 degrees.  Returns OBJECT.
+(define (rotate-object! object x y angle)
+  (define pointer (geda-object->pointer* object 1))
+
+  (let ((angle (euclidean-remainder angle 360)))
+    (when (not (zero? (euclidean-remainder angle 90)))
+      (error "Wrong rotation angle: ~A" angle))
+
+    (lepton_object_emit_pre_change_notify pointer)
+    (lepton_object_rotate x y angle pointer)
+    (lepton_object_emit_change_notify pointer)
+    (lepton_object_page_set_changed pointer)
+
+    object))
+
+;;; Translate OBJECT by DX in the x-axis and DY in the y-axis.  DX
+;;; and DY are integer distances along corresponding axes.
+;;; Returns OBJECT.
+(define (translate-object! object dx dy)
+  (define pointer (geda-object->pointer* object 1))
+
+  (lepton_object_emit_pre_change_notify pointer)
+  (lepton_object_translate pointer dx dy)
+  (lepton_object_emit_change_notify pointer)
+  (lepton_object_page_set_changed pointer)
+
+  object)
