@@ -1,7 +1,7 @@
 ;;; Lepton EDA netlister
 ;;; Copyright (C) 1998-2010 Ales Hvezda
 ;;; Copyright (C) 1998-2017 gEDA Contributors
-;;; Copyright (C) 2017-2020 Lepton EDA Contributors
+;;; Copyright (C) 2017-2021 Lepton EDA Contributors
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 (define-module (netlist)
   #:use-module (srfi srfi-1)
   #:use-module (srfi srfi-26)
+  #:use-module (ice-9 format)
   #:use-module (ice-9 match)
   #:use-module ((ice-9 rdelim) #:select (read-string) #:prefix rdelim:)
   #:use-module (ice-9 ftw)
@@ -262,15 +263,15 @@ REFDES. As a result, slots may be repeated in the returned list."
   (if (> wrap-length (string-length string-to-wrap))
       string-to-wrap ; Last snippet of string
       (let ((pos (string-rindex string-to-wrap #\space 0 wrap-length)))
-	(cond ((not pos)
+        (cond ((not pos)
                (display (G_ "Couldn't wrap string  at requested position\n"))
-	       " Wrap error!")
-	      (else
-	       (string-append
-		(substring string-to-wrap 0 pos)
-		wrap-char
-		"\n "
-		(gnetlist:wrap (substring string-to-wrap (+ pos 1)) wrap-length wrap-char)))))))
+               " Wrap error!")
+              (else
+               (string-append
+                (substring string-to-wrap 0 pos)
+                wrap-char
+                "\n "
+                (gnetlist:wrap (substring string-to-wrap (+ pos 1)) wrap-length wrap-char)))))))
 
 ;; example use
 ; (define (run-test test-string wrap-len)
@@ -816,7 +817,7 @@ General options:
 Report bugs at <https://github.com/lepton-eda/lepton-eda/issues>
 Lepton EDA homepage: <https://github.com/lepton-eda/lepton-eda>
 ")
-          (car (program-arguments)))
+          (basename (car (program-arguments))))
   (primitive-exit 0))
 
 
@@ -968,7 +969,7 @@ Lepton EDA homepage: <https://github.com/lepton-eda/lepton-eda>
   )
 
   ( when opt-version
-    ( display-lepton-version #:print-name #t )
+    ( display-lepton-version #:print-name #t #:copyright #t )
     ( primitive-exit 0 )
   )
 
@@ -1073,4 +1074,3 @@ Lepton EDA homepage: <https://github.com/lepton-eda/lepton-eda>
 
 ) ; let
 ) ; main()
-
