@@ -8,6 +8,8 @@
        (b (copy-object a)))
 
   (test-equal 'box (object-type a))
+  (test-assert (object-type? a 'box))
+  (test-assert (not (object-type? a 'x)))
 
   (test-assert (box? a))
   (test-assert (box? b))
