@@ -1,7 +1,7 @@
 /* Lepton EDA library
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #include <string.h>
 #endif
 
-#include "libgeda_priv.h"
+#include "liblepton_priv.h"
 
 /*! \brief Save a file
  *  \par Function Description
@@ -37,7 +37,7 @@
  *  \bug g_access introduces a race condition in certain cases, but
  *  solves bug #698565 in the normal use-case
  *
- *  \param [in] object_list The head of a GList of OBJECTs to save.
+ *  \param [in] object_list The head of a GList of LeptonObjects to save.
  *  \param [in] filename    The filename to save the data to.
  *  \param [in,out] err     #GError structure for error reporting.
  *  \return 1 on success, 0 on failure.
@@ -58,7 +58,7 @@ o_save (const GList *object_list,
     return 0;
   }
 
-  buffer = geda_object_list_to_buffer (object_list);
+  buffer = lepton_object_list_to_buffer (object_list);
   if (!g_file_set_contents (filename, buffer, strlen(buffer), err)) {
     g_free (buffer);
     return 0;
@@ -78,30 +78,34 @@ o_save (const GList *object_list,
  *  The name argument is used for debugging, and should be set to a
  *  meaningful string (e.g. the name of the file the data is from).
  *
- *  \param [in,out] page         The PAGE object.
+ *  \param [in,out] page         The LeptonPage object.
  *  \param [in]     object_list  The object_list to read data to.
  *  \param [in]     buffer       The memory buffer to read from.
  *  \param [in]     size         The size of the buffer.
  *  \param [in]     name         The name to describe the data with.
  *  \return GList of objects if successful read, or NULL on error.
  */
-GList *o_read_buffer (PAGE *page, GList *object_list,
-                      char *buffer, const int size,
-                      const char *name, GError **err)
+GList
+*o_read_buffer (LeptonPage *page,
+                GList *object_list,
+                char *buffer,
+                const int size,
+                const char *name,
+                GError **err)
 {
   const char *line = NULL;
   TextBuffer *tb = NULL;
 
   char objtype;
   GList *object_list_save=NULL;
-  OBJECT *new_obj=NULL;
+  LeptonObject *new_obj=NULL;
   GList *new_attrs_list;
   GList *new_object_list = NULL;
   GList *iter;
   unsigned int release_ver = 0;
   unsigned int fileformat_ver = 0;
   int found_pin = 0;
-  OBJECT* last_component = NULL;
+  LeptonObject* last_component = NULL;
   int itemsread = 0;
 
   int embedded_level = 0;
@@ -167,7 +171,7 @@ GList *o_read_buffer (PAGE *page, GList *object_list,
         break;
 
       case(OBJ_PICTURE):
-        new_obj = o_picture_read (line, tb, release_ver, fileformat_ver, err);
+        new_obj = lepton_picture_object_read (line, tb, release_ver, fileformat_ver, err);
         if (new_obj == NULL)
           goto error;
         new_object_list = g_list_prepend (new_object_list, new_obj);
@@ -175,12 +179,11 @@ GList *o_read_buffer (PAGE *page, GList *object_list,
 
       case(OBJ_CIRCLE):
         if ((new_obj = o_circle_read (line, release_ver, fileformat_ver, err)) == NULL)
-	  goto error;
+          goto error;
         new_object_list = g_list_prepend (new_object_list, new_obj);
         break;
 
       case(OBJ_COMPONENT):
-      case(OBJ_PLACEHOLDER):
         if ((new_obj = o_component_read (page, line, release_ver, fileformat_ver, err)) == NULL)
           goto error;
         new_object_list = g_list_prepend (new_object_list, new_obj);
@@ -236,26 +239,27 @@ GList *o_read_buffer (PAGE *page, GList *object_list,
           }
 
           /* slots only apply to component objects */
-          if (new_obj != NULL &&
-              (new_obj->type == OBJ_COMPONENT ||
-               new_obj->type == OBJ_PLACEHOLDER)) {
+          if (lepton_object_is_component (new_obj))
+          {
             s_slot_update_object (new_obj);
           }
           new_obj = NULL;
         }
         else {
-          g_set_error (err, EDA_ERROR, EDA_ERROR_PARSE, _("Read unexpected attach "
-                                                                 "symbol start marker in [%1$s] :\n>>\n%2$s<<\n"),
-                       name, line);
+          g_set_error (err,
+                       EDA_ERROR,
+                       EDA_ERROR_PARSE,
+                       _("Read unexpected attach "
+                         "symbol start marker in [%1$s] :\n>>\n%2$s<<\n"),
+                       name,
+                       line);
           goto error;
         }
         break;
 
       case(START_EMBEDDED):
-        if (new_obj != NULL &&
-            (new_obj->type == OBJ_COMPONENT ||
-             new_obj->type == OBJ_PLACEHOLDER)) {
-
+        if (lepton_object_is_component (new_obj))
+        {
           object_list_save = new_object_list;
           new_object_list = new_obj->component->prim_objs;
 
@@ -272,18 +276,18 @@ GList *o_read_buffer (PAGE *page, GList *object_list,
         if (embedded_level>0) {
           /* don't do this since objects are already
            * stored/read translated
-           * geda_component_object_translate (new_object_list->x, new_object_list->y, new_object_list->component);
+           * lepton_component_object_translate (new_object_list->x, new_object_list->y, new_object_list->component);
            */
           new_object_list = g_list_reverse (new_object_list);
 
-          new_obj = (OBJECT*) object_list_save->data;
+          new_obj = (LeptonObject*) object_list_save->data;
           new_obj->component->prim_objs = new_object_list;
           new_object_list = object_list_save;
 
           /* set the parent field now */
           for (iter = new_obj->component->prim_objs;
                iter != NULL; iter = g_list_next (iter)) {
-            OBJECT *tmp = (OBJECT*) iter->data;
+            LeptonObject *tmp = (LeptonObject*) iter->data;
             tmp->parent = new_obj;
           }
 
@@ -350,8 +354,8 @@ GList *o_read_buffer (PAGE *page, GList *object_list,
     cfg_read_bool ("schematic.gui", "force-boundingbox",
                    default_force_boundingbox, &force_boundingbox);
 
-    geda_pin_object_update_whichend (new_object_list,
-                                     (found_pin == 1 || force_boundingbox));
+    lepton_pin_object_update_whichend (new_object_list,
+                                       (found_pin == 1 || force_boundingbox));
   }
 
   s_textbuffer_free(tb);
@@ -362,7 +366,7 @@ GList *o_read_buffer (PAGE *page, GList *object_list,
   return(object_list);
 
 error:
-  geda_object_list_delete (new_object_list);
+  lepton_object_list_delete (new_object_list);
 
   unsigned long linenum = s_textbuffer_linenum (tb);
   g_prefix_error (err, "Parsing stopped at line %lu:\n", linenum);
@@ -374,14 +378,14 @@ error:
  *  \par Function Description
  *  This function reads a file in gEDA format.
  *
- *  \param [in,out] page         The PAGE object.
+ *  \param [in,out] page         The LeptonPage object.
  *  \param [in]     filename     The filename to read from.
  *  \param [in,out] err          #GError structure for error reporting, or
  *                               NULL to disable error reporting
  *  \return page
  */
-PAGE*
-o_read (PAGE *page,
+LeptonPage*
+o_read (LeptonPage *page,
         char *filename,
         GError **err)
 {
