@@ -1,6 +1,6 @@
-/* libleptonrenderer - Rendering Lepton EDA schematics with Cairo
+/* Lepton EDA library
  * Copyright (C) 2010-2016 gEDA Contributors
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -129,44 +129,44 @@ static void eda_renderer_update_contexts (EdaRenderer *renderer, cairo_t *new_cr
                                           PangoContext *new_pc);
 
 static void eda_renderer_set_color (EdaRenderer *renderer, int color);
-static int eda_renderer_is_drawable (EdaRenderer *renderer, OBJECT *object);
-static int eda_renderer_draw_hatch (EdaRenderer *renderer, OBJECT *object);
+static int eda_renderer_is_drawable (EdaRenderer *renderer, LeptonObject *object);
+static int eda_renderer_draw_hatch (EdaRenderer *renderer, LeptonObject *object);
 
-static void eda_renderer_default_draw (EdaRenderer *renderer, OBJECT *object);
+static void eda_renderer_default_draw (EdaRenderer *renderer, LeptonObject *object);
 static void eda_renderer_draw_list (EdaRenderer *renderer, GList *objects);
-static void eda_renderer_draw_line (EdaRenderer *renderer, OBJECT *object);
-static void eda_renderer_draw_pin (EdaRenderer *renderer, OBJECT *object);
-static void eda_renderer_draw_net (EdaRenderer *renderer, OBJECT *object);
-static void eda_renderer_draw_bus (EdaRenderer *renderer, OBJECT *object);
-static void eda_renderer_draw_box (EdaRenderer *renderer, OBJECT *object);
-static void eda_renderer_draw_arc (EdaRenderer *renderer, OBJECT *object);
-static void eda_renderer_draw_circle (EdaRenderer *renderer, OBJECT *object);
-static void eda_renderer_draw_path (EdaRenderer *renderer, OBJECT *object);
-static void eda_renderer_draw_text (EdaRenderer *renderer, OBJECT *object);
-static int eda_renderer_prepare_text (EdaRenderer *renderer, const GedaObject *object);
-static void eda_renderer_calc_text_position (EdaRenderer *renderer, const GedaObject *object,
+static void eda_renderer_draw_line (EdaRenderer *renderer, LeptonObject *object);
+static void eda_renderer_draw_pin (EdaRenderer *renderer, LeptonObject *object);
+static void eda_renderer_draw_net (EdaRenderer *renderer, LeptonObject *object);
+static void eda_renderer_draw_bus (EdaRenderer *renderer, LeptonObject *object);
+static void eda_renderer_draw_box (EdaRenderer *renderer, LeptonObject *object);
+static void eda_renderer_draw_arc (EdaRenderer *renderer, LeptonObject *object);
+static void eda_renderer_draw_circle (EdaRenderer *renderer, LeptonObject *object);
+static void eda_renderer_draw_path (EdaRenderer *renderer, LeptonObject *object);
+static void eda_renderer_draw_text (EdaRenderer *renderer, LeptonObject *object);
+static int eda_renderer_prepare_text (EdaRenderer *renderer, const LeptonObject *object);
+static void eda_renderer_calc_text_position (EdaRenderer *renderer, const LeptonObject *object,
                                              double *x, double *y);
-static void eda_renderer_draw_picture (EdaRenderer *renderer, OBJECT *object);
-static void eda_renderer_draw_component (EdaRenderer *renderer, OBJECT *object);
+static void eda_renderer_draw_picture (EdaRenderer *renderer, LeptonObject *object);
+static void eda_renderer_draw_component (EdaRenderer *renderer, LeptonObject *object);
 
-static void eda_renderer_default_draw_grips (EdaRenderer *renderer, OBJECT *object);
+static void eda_renderer_default_draw_grips (EdaRenderer *renderer, LeptonObject *object);
 static void eda_renderer_draw_grips_list (EdaRenderer *renderer, GList *objects) G_GNUC_UNUSED;
 static void eda_renderer_draw_grips_impl (EdaRenderer *renderer, int type, int n_grips, ...);
-static void eda_renderer_draw_arc_grips (EdaRenderer *renderer, OBJECT *object);
-static void eda_renderer_draw_path_grips (EdaRenderer *renderer, OBJECT *object);
-static void eda_renderer_draw_text_grips (EdaRenderer *renderer, OBJECT *object);
+static void eda_renderer_draw_arc_grips (EdaRenderer *renderer, LeptonObject *object);
+static void eda_renderer_draw_path_grips (EdaRenderer *renderer, LeptonObject *object);
+static void eda_renderer_draw_text_grips (EdaRenderer *renderer, LeptonObject *object);
 
-static void eda_renderer_default_draw_cues (EdaRenderer *renderer, OBJECT *object);
+static void eda_renderer_default_draw_cues (EdaRenderer *renderer, LeptonObject *object);
 static void eda_renderer_draw_cues_list (EdaRenderer *renderer, GList *objects);
-static void eda_renderer_draw_end_cues (EdaRenderer *renderer, OBJECT *object,
+static void eda_renderer_draw_end_cues (EdaRenderer *renderer, LeptonObject *object,
                                         int end);
-static void eda_renderer_draw_mid_cues (EdaRenderer *renderer, OBJECT *object);
+static void eda_renderer_draw_mid_cues (EdaRenderer *renderer, LeptonObject *object);
 static void eda_renderer_draw_junction_cue (EdaRenderer *renderer, int x, int y,
                                             int is_bus);
 
 static gboolean
 eda_renderer_default_get_user_bounds (EdaRenderer *renderer,
-                                      const GedaObject *object,
+                                      const LeptonObject *object,
                                       double *left,
                                       double *top,
                                       double *right,
@@ -476,12 +476,12 @@ eda_renderer_draw_list (EdaRenderer *renderer, GList *objects)
   GList *iter;
 
   for (iter = objects; iter != NULL; iter = g_list_next (iter)) {
-    eda_renderer_draw (renderer, (OBJECT *) iter->data);
+    eda_renderer_draw (renderer, (LeptonObject *) iter->data);
   }
 }
 
 void
-eda_renderer_draw (EdaRenderer *renderer, OBJECT *object)
+eda_renderer_draw (EdaRenderer *renderer, LeptonObject *object)
 {
   g_return_if_fail (EDA_IS_RENDERER(renderer));
 
@@ -489,9 +489,9 @@ eda_renderer_draw (EdaRenderer *renderer, OBJECT *object)
 }
 
 static void
-eda_renderer_default_draw (EdaRenderer *renderer, OBJECT *object)
+eda_renderer_default_draw (EdaRenderer *renderer, LeptonObject *object)
 {
-  void (*draw_func)(EdaRenderer *, OBJECT *);
+  void (*draw_func)(EdaRenderer *, LeptonObject *);
 
   g_return_if_fail (object != NULL);
   g_return_if_fail (renderer->priv->cr != NULL);
@@ -500,7 +500,7 @@ eda_renderer_default_draw (EdaRenderer *renderer, OBJECT *object)
 
   if (!eda_renderer_is_drawable (renderer, object)) return;
 
-  switch (object->type) {
+  switch (lepton_object_get_type (object)) {
   case OBJ_LINE:        draw_func = eda_renderer_draw_line; break;
   case OBJ_NET:         draw_func = eda_renderer_draw_net; break;
   case OBJ_BUS:         draw_func = eda_renderer_draw_bus; break;
@@ -511,15 +511,13 @@ eda_renderer_default_draw (EdaRenderer *renderer, OBJECT *object)
   case OBJ_PATH:        draw_func = eda_renderer_draw_path; break;
   case OBJ_TEXT:        draw_func = eda_renderer_draw_text; break;
   case OBJ_PICTURE:     draw_func = eda_renderer_draw_picture; break;
-
-  case OBJ_COMPONENT:
-  case OBJ_PLACEHOLDER: draw_func = eda_renderer_draw_component; break;
+  case OBJ_COMPONENT:   draw_func = eda_renderer_draw_component; break;
 
   default:
     g_return_if_reached ();
   }
 
-  eda_renderer_set_color (renderer, geda_object_get_drawing_color (object));
+  eda_renderer_set_color (renderer, lepton_object_get_drawing_color (object));
   draw_func (renderer, object);
 }
 
@@ -547,23 +545,24 @@ eda_renderer_is_drawable_color (EdaRenderer *renderer, int color,
   g_return_val_if_fail ((color >= 0) || (color < (int) map->len), FALSE);
 
   /* Otherwise, return enabled flag of object's color */
-  return (&g_array_index (map, GedaColor, color))->enabled;
+  return (&g_array_index (map, LeptonColor, color))->enabled;
 }
 
 static int
-eda_renderer_is_drawable (EdaRenderer *renderer, OBJECT *object)
+eda_renderer_is_drawable (EdaRenderer *renderer, LeptonObject *object)
 {
-  int color = geda_object_get_drawing_color (object);
+  int color = lepton_object_get_drawing_color (object);
 
   /* Always attempt to draw component objects */
-  if ((object->type == OBJ_COMPONENT) || (object->type == OBJ_PLACEHOLDER)) {
+  if (lepton_object_is_component (object))
+  {
     return TRUE;
   }
   return eda_renderer_is_drawable_color (renderer, color, TRUE);
 }
 
 static int
-eda_renderer_draw_hatch (EdaRenderer *renderer, OBJECT *object)
+eda_renderer_draw_hatch (EdaRenderer *renderer, LeptonObject *object)
 {
   void (*hatch_func)(void *, gint, gint, GArray *);
   void *hatch_data;
@@ -571,7 +570,7 @@ eda_renderer_draw_hatch (EdaRenderer *renderer, OBJECT *object)
   guint i;
 
   /* Horrible horrible hacks! */
-  switch (object->type) {
+  switch (lepton_object_get_type (object)) {
   case OBJ_BOX:
     hatch_func = (void (*)(void *, gint, gint, GArray *)) m_hatch_box;
     hatch_data = (void *) object->box;
@@ -602,17 +601,19 @@ eda_renderer_draw_hatch (EdaRenderer *renderer, OBJECT *object)
   }
 
   /* Handle mesh and hatch fill types */
-  fill_lines = g_array_new (FALSE, FALSE, sizeof (GedaLine));
-  if (geda_fill_type_draw_first_hatch (object->fill_type)) {
+  fill_lines = g_array_new (FALSE, FALSE, sizeof (LeptonLine));
+  if (lepton_fill_type_draw_first_hatch (object->fill_type))
+  {
     hatch_func (hatch_data, object->fill_angle1, object->fill_pitch1, fill_lines);
   }
-  if (geda_fill_type_draw_second_hatch (object->fill_type)) {
+  if (lepton_fill_type_draw_second_hatch (object->fill_type))
+  {
     hatch_func (hatch_data, object->fill_angle2, object->fill_pitch2, fill_lines);
   }
 
   /* Draw fill pattern */
   for (i = 0; i < fill_lines->len; i++) {
-    GedaLine *line = &g_array_index (fill_lines, GedaLine, i);
+    LeptonLine *line = &g_array_index (fill_lines, LeptonLine, i);
     eda_cairo_line (renderer->priv->cr, EDA_RENDERER_CAIRO_FLAGS (renderer),
                     END_NONE, object->fill_width,
                     line->x[0], line->y[0], line->x[1], line->y[1]);
@@ -627,30 +628,31 @@ eda_renderer_draw_hatch (EdaRenderer *renderer, OBJECT *object)
 }
 
 static void
-eda_renderer_draw_component (EdaRenderer *renderer, OBJECT *object)
+eda_renderer_draw_component (EdaRenderer *renderer, LeptonObject *object)
 {
   /* Recurse */
   eda_renderer_draw_list (renderer, object->component->prim_objs);
 }
 
 static void
-eda_renderer_draw_line (EdaRenderer *renderer, OBJECT *object)
+eda_renderer_draw_line (EdaRenderer *renderer, LeptonObject *object)
 {
   eda_cairo_line (renderer->priv->cr, EDA_RENDERER_CAIRO_FLAGS (renderer),
-                  object->line_end,
-                  object->line_width,
+                  lepton_object_get_stroke_cap_type (object),
+                  lepton_object_get_stroke_width (object),
                   object->line->x[0], object->line->y[0],
                   object->line->x[1], object->line->y[1]);
   eda_cairo_stroke (renderer->priv->cr, EDA_RENDERER_CAIRO_FLAGS (renderer),
-                    object->line_type,
-                    object->line_end,
-                    EDA_RENDERER_STROKE_WIDTH (renderer, object->line_width),
-                    object->line_length,
-                    object->line_space);
+                    lepton_object_get_stroke_type (object),
+                    lepton_object_get_stroke_cap_type (object),
+                    EDA_RENDERER_STROKE_WIDTH (renderer,
+                                               lepton_object_get_stroke_width (object)),
+                    lepton_object_get_stroke_dash_length (object),
+                    lepton_object_get_stroke_space_length (object));
 }
 
 static void
-eda_renderer_draw_net (EdaRenderer *renderer, OBJECT *object)
+eda_renderer_draw_net (EdaRenderer *renderer, LeptonObject *object)
 {
   eda_cairo_line (renderer->priv->cr, EDA_RENDERER_CAIRO_FLAGS (renderer),
                   END_SQUARE, NET_WIDTH,
@@ -663,7 +665,7 @@ eda_renderer_draw_net (EdaRenderer *renderer, OBJECT *object)
 }
 
 static void
-eda_renderer_draw_bus (EdaRenderer *renderer, OBJECT *object)
+eda_renderer_draw_bus (EdaRenderer *renderer, LeptonObject *object)
 {
   eda_cairo_line (renderer->priv->cr, EDA_RENDERER_CAIRO_FLAGS (renderer),
                   END_SQUARE, BUS_WIDTH,
@@ -676,9 +678,9 @@ eda_renderer_draw_bus (EdaRenderer *renderer, OBJECT *object)
 }
 
 static void
-eda_renderer_draw_pin (EdaRenderer *renderer, OBJECT *object)
+eda_renderer_draw_pin (EdaRenderer *renderer, LeptonObject *object)
 {
-  int width = geda_pin_object_get_width (object);
+  int width = lepton_pin_object_get_width (object);
 
   eda_cairo_line (renderer->priv->cr, EDA_RENDERER_CAIRO_FLAGS (renderer),
                   END_SQUARE, width,
@@ -691,7 +693,7 @@ eda_renderer_draw_pin (EdaRenderer *renderer, OBJECT *object)
 }
 
 static void
-eda_renderer_draw_box (EdaRenderer *renderer, OBJECT *object)
+eda_renderer_draw_box (EdaRenderer *renderer, LeptonObject *object)
 {
   int fill_solid = FALSE;
 
@@ -700,37 +702,41 @@ eda_renderer_draw_box (EdaRenderer *renderer, OBJECT *object)
 
   /* Draw outline of box */
   eda_cairo_box (renderer->priv->cr, EDA_RENDERER_CAIRO_FLAGS (renderer),
-                 object->line_width,
+                 lepton_object_get_stroke_width (object),
                  object->box->lower_x, object->box->lower_y,
                  object->box->upper_x, object->box->upper_y);
   if (fill_solid) cairo_fill_preserve (renderer->priv->cr);
   eda_cairo_stroke (renderer->priv->cr, EDA_RENDERER_CAIRO_FLAGS (renderer),
-                    object->line_type, object->line_end,
-                    EDA_RENDERER_STROKE_WIDTH (renderer, object->line_width),
-                    object->line_length, object->line_space);
+                    lepton_object_get_stroke_type (object),
+                    lepton_object_get_stroke_cap_type (object),
+                    EDA_RENDERER_STROKE_WIDTH (renderer,
+                                               lepton_object_get_stroke_width (object)),
+                    lepton_object_get_stroke_dash_length (object),
+                    lepton_object_get_stroke_space_length (object));
 }
 
 static void
-eda_renderer_draw_arc (EdaRenderer *renderer, OBJECT *object)
+eda_renderer_draw_arc (EdaRenderer *renderer, LeptonObject *object)
 {
   eda_cairo_arc (renderer->priv->cr, EDA_RENDERER_CAIRO_FLAGS (renderer),
-                 object->line_width,
-                 geda_arc_object_get_center_x (object),
-                 geda_arc_object_get_center_y (object),
-                 geda_arc_object_get_radius (object),
-                 geda_arc_object_get_start_angle (object),
-                 geda_arc_object_get_sweep_angle (object));
+                 lepton_object_get_stroke_width (object),
+                 lepton_arc_object_get_center_x (object),
+                 lepton_arc_object_get_center_y (object),
+                 lepton_arc_object_get_radius (object),
+                 lepton_arc_object_get_start_angle (object),
+                 lepton_arc_object_get_sweep_angle (object));
 
   eda_cairo_stroke (renderer->priv->cr, EDA_RENDERER_CAIRO_FLAGS (renderer),
-                    object->line_type,
-                    object->line_end,
-                    EDA_RENDERER_STROKE_WIDTH (renderer, object->line_width),
-                    object->line_length,
-                    object->line_space);
+                    lepton_object_get_stroke_type (object),
+                    lepton_object_get_stroke_cap_type (object),
+                    EDA_RENDERER_STROKE_WIDTH (renderer,
+                                               lepton_object_get_stroke_width (object)),
+                    lepton_object_get_stroke_dash_length (object),
+                    lepton_object_get_stroke_space_length (object));
 }
 
 static void
-eda_renderer_draw_circle (EdaRenderer *renderer, OBJECT *object)
+eda_renderer_draw_circle (EdaRenderer *renderer, LeptonObject *object)
 {
   int fill_solid = FALSE;
 
@@ -739,20 +745,23 @@ eda_renderer_draw_circle (EdaRenderer *renderer, OBJECT *object)
 
   /* Draw outline of circle */
   eda_cairo_arc (renderer->priv->cr, EDA_RENDERER_CAIRO_FLAGS (renderer),
-                 object->line_width,
-                 geda_circle_object_get_center_x (object),
-                 geda_circle_object_get_center_y (object),
-                 geda_circle_object_get_radius (object),
+                 lepton_object_get_stroke_width (object),
+                 lepton_circle_object_get_center_x (object),
+                 lepton_circle_object_get_center_y (object),
+                 lepton_circle_object_get_radius (object),
                  0, 360);
   if (fill_solid) cairo_fill_preserve (renderer->priv->cr);
   eda_cairo_stroke (renderer->priv->cr, EDA_RENDERER_CAIRO_FLAGS (renderer),
-                    object->line_type, object->line_end,
-                    EDA_RENDERER_STROKE_WIDTH (renderer, object->line_width),
-                    object->line_length, object->line_space);
+                    lepton_object_get_stroke_type (object),
+                    lepton_object_get_stroke_cap_type (object),
+                    EDA_RENDERER_STROKE_WIDTH (renderer,
+                                               lepton_object_get_stroke_width (object)),
+                    lepton_object_get_stroke_dash_length (object),
+                    lepton_object_get_stroke_space_length (object));
 }
 
 static void
-eda_renderer_draw_path (EdaRenderer *renderer, OBJECT *object)
+eda_renderer_draw_path (EdaRenderer *renderer, LeptonObject *object)
 {
   int fill_solid = FALSE;
 
@@ -761,18 +770,22 @@ eda_renderer_draw_path (EdaRenderer *renderer, OBJECT *object)
 
   /* Draw outline of path */
   eda_cairo_path (renderer->priv->cr, EDA_RENDERER_CAIRO_FLAGS (renderer),
-                  object->line_width, object->path->num_sections,
+                  lepton_object_get_stroke_width (object),
+                  object->path->num_sections,
                   object->path->sections);
 
   if (fill_solid) cairo_fill_preserve (renderer->priv->cr);
   eda_cairo_stroke (renderer->priv->cr, EDA_RENDERER_CAIRO_FLAGS (renderer),
-                    object->line_type, object->line_end,
-                    EDA_RENDERER_STROKE_WIDTH0 (renderer, object->line_width),
-                    object->line_length, object->line_space);
+                    lepton_object_get_stroke_type (object),
+                    lepton_object_get_stroke_cap_type (object),
+                    EDA_RENDERER_STROKE_WIDTH0 (renderer,
+                                                lepton_object_get_stroke_width (object)),
+                    lepton_object_get_stroke_dash_length (object),
+                    lepton_object_get_stroke_space_length (object));
 }
 
 static void
-eda_renderer_draw_text (EdaRenderer *renderer, OBJECT *object)
+eda_renderer_draw_text (EdaRenderer *renderer, LeptonObject *object)
 {
   double x, y;
   double dummy = 0, small_dist = TEXT_MARKER_SIZE;
@@ -851,7 +864,7 @@ eda_renderer_draw_text (EdaRenderer *renderer, OBJECT *object)
 }
 
 static int
-eda_renderer_prepare_text (EdaRenderer *renderer, const GedaObject *object)
+eda_renderer_prepare_text (EdaRenderer *renderer, const LeptonObject *object)
 {
   gint angle;
   double points_size, dx, dy;
@@ -861,7 +874,7 @@ eda_renderer_prepare_text (EdaRenderer *renderer, const GedaObject *object)
   PangoFontDescription *desc;
   PangoAttrList *attrs;
 
-  points_size = geda_text_object_get_size_in_points (object);
+  points_size = lepton_text_object_get_size_in_points (object);
   size = lrint (points_size * PANGO_SCALE);
 
   /* Set hinting as appropriate */
@@ -900,7 +913,7 @@ eda_renderer_prepare_text (EdaRenderer *renderer, const GedaObject *object)
   cairo_translate (renderer->priv->cr, object->text->x, object->text->y);
 
   /* Special case turns upside-down text back upright */
-  angle = geda_text_object_get_angle (object);
+  angle = lepton_text_object_get_angle (object);
   if (angle != 180) {
     cairo_rotate (renderer->priv->cr, M_PI * angle / 180.);
   }
@@ -924,7 +937,7 @@ eda_renderer_prepare_text (EdaRenderer *renderer, const GedaObject *object)
 /* Calculate position to draw text relative to text origin marker, in
  * world coordinates. */
 static void
-eda_renderer_calc_text_position (EdaRenderer *renderer, const GedaObject *object,
+eda_renderer_calc_text_position (EdaRenderer *renderer, const LeptonObject *object,
                                  double *x, double *y)
 {
   PangoRectangle inked_rect, logical_rect;
@@ -955,7 +968,7 @@ eda_renderer_calc_text_position (EdaRenderer *renderer, const GedaObject *object
   y_middle = y_upper - logical_rect.height / 2.;  /* Middle of inked extents */
   y_lower  = y_upper - logical_rect.height;       /* Baseline of bottom line */
 
-  switch (geda_text_object_get_alignment (object)) {
+  switch (lepton_text_object_get_alignment (object)) {
     case LOWER_LEFT:
     case LOWER_MIDDLE:
     case LOWER_RIGHT:
@@ -967,12 +980,12 @@ eda_renderer_calc_text_position (EdaRenderer *renderer, const GedaObject *object
    * the text is rotated to 180 degrees, since the drawing code
    * does not rotate the text to be shown upside down.
    */
-  if (geda_text_object_get_angle (object) == 180) {
+  if (lepton_text_object_get_angle (object) == 180) {
     temp = y_lower; y_lower = y_upper; y_upper = temp;
     temp = x_left;  x_left  = x_right; x_right = temp;
   }
 
-  switch (geda_text_object_get_alignment (object)) {
+  switch (lepton_text_object_get_alignment (object)) {
     default:
       /* Fall through to LOWER_left case */
     case LOWER_LEFT:    *y = y_lower;  *x = x_left;   break;
@@ -992,23 +1005,28 @@ eda_renderer_calc_text_position (EdaRenderer *renderer, const GedaObject *object
 }
 
 static void
-eda_renderer_draw_picture (EdaRenderer *renderer, OBJECT *object)
+eda_renderer_draw_picture (EdaRenderer *renderer, LeptonObject *object)
 {
   int swap_wh;
   double orig_width, orig_height;
   GdkPixbuf *pixbuf;
+  int angle;
+  int lower_x, lower_y, upper_x, upper_y;
 
   /* Get a pixbuf. If image doesn't exist, libgeda should
    * provide a fallback image. */
   pixbuf = GDK_PIXBUF (g_object_ref (object->picture->pixbuf));
 
+  lower_x = lepton_picture_object_get_lower_x (object);
+  lower_y = lepton_picture_object_get_lower_y (object);
+  upper_x = lepton_picture_object_get_upper_x (object);
+  upper_y = lepton_picture_object_get_upper_y (object);
+
   /* If no pixbuf was found, fall back to drawing an outline */
   if (pixbuf == NULL || EDA_RENDERER_CHECK_FLAG (renderer,
                                                  FLAG_PICTURE_OUTLINE)) {
     eda_cairo_box (renderer->priv->cr, EDA_RENDERER_CAIRO_FLAGS (renderer),
-                   0,
-                   object->picture->lower_x, object->picture->lower_y,
-                   object->picture->upper_x, object->picture->upper_y);
+                   0, lower_x, lower_y, upper_x, upper_y);
     eda_cairo_stroke (renderer->priv->cr, EDA_RENDERER_CAIRO_FLAGS (renderer),
                       TYPE_SOLID, END_SQUARE,
                       EDA_RENDERER_STROKE_WIDTH (renderer, 0),
@@ -1020,28 +1038,30 @@ eda_renderer_draw_picture (EdaRenderer *renderer, OBJECT *object)
 
   cairo_save (renderer->priv->cr);
 
-  swap_wh = ((object->picture->angle == 90) || (object->picture->angle == 270));
+  angle = lepton_picture_object_get_angle (object);
+
+  swap_wh = ((angle == 90) || (angle == 270));
   orig_width  = swap_wh ? gdk_pixbuf_get_height (object->picture->pixbuf)
                         : gdk_pixbuf_get_width (object->picture->pixbuf);
   orig_height = swap_wh ? gdk_pixbuf_get_width (object->picture->pixbuf)
                         : gdk_pixbuf_get_height (object->picture->pixbuf);
 
-  cairo_translate (renderer->priv->cr,
-                   object->picture->upper_x, object->picture->upper_y);
+  cairo_translate (renderer->priv->cr, upper_x, upper_y);
   cairo_scale (renderer->priv->cr,
-               abs (object->picture->upper_x - object->picture->lower_x) / orig_width,
-               - abs (object->picture->upper_y - object->picture->lower_y) / orig_height);
+               abs (upper_x - lower_x) / orig_width,
+               - abs (upper_y - lower_y) / orig_height);
 
   /* Evil magic translates picture origin to the right position for a given rotation */
-  switch (object->picture->angle) {
+  switch (angle) {
     case 0:                                                                    break;
     case 90:   cairo_translate (renderer->priv->cr, 0,          orig_height);  break;
     case 180:  cairo_translate (renderer->priv->cr, orig_width, orig_height);  break;
     case 270:  cairo_translate (renderer->priv->cr, orig_width, 0          );  break;
   }
 
-  cairo_rotate (renderer->priv->cr, -object->picture->angle * M_PI / 180.);
-  if (object->picture->mirrored) {
+  cairo_rotate (renderer->priv->cr, -angle * M_PI / 180.);
+  if (lepton_picture_object_get_mirrored (object))
+  {
     cairo_translate (renderer->priv->cr, gdk_pixbuf_get_width (pixbuf), 0);
     cairo_scale (renderer->priv->cr, -1, 1);
   }
@@ -1068,12 +1088,12 @@ eda_renderer_draw_grips_list (EdaRenderer *renderer, GList *objects)
 {
   GList *iter;
   for (iter = objects; iter != NULL; iter = g_list_next (iter)) {
-    eda_renderer_draw_grips (renderer, (OBJECT *) iter->data);
+    eda_renderer_draw_grips (renderer, (LeptonObject *) iter->data);
   }
 }
 
 void
-eda_renderer_draw_grips (EdaRenderer *renderer, OBJECT *object)
+eda_renderer_draw_grips (EdaRenderer *renderer, LeptonObject *object)
 {
   g_return_if_fail (EDA_IS_RENDERER (renderer));
 
@@ -1081,7 +1101,7 @@ eda_renderer_draw_grips (EdaRenderer *renderer, OBJECT *object)
 }
 
 static void
-eda_renderer_default_draw_grips (EdaRenderer *renderer, OBJECT *object)
+eda_renderer_default_draw_grips (EdaRenderer *renderer, LeptonObject *object)
 {
   g_return_if_fail (object != NULL);
   g_return_if_fail (EDA_IS_RENDERER (renderer));
@@ -1092,7 +1112,7 @@ eda_renderer_default_draw_grips (EdaRenderer *renderer, OBJECT *object)
   if (!eda_renderer_is_drawable_color (renderer, GRIP_STROKE_COLOR, FALSE))
     return;
 
-  switch (object->type) {
+  switch (lepton_object_get_type (object)) {
   case OBJ_LINE:
   case OBJ_NET:
   case OBJ_BUS:
@@ -1114,8 +1134,8 @@ eda_renderer_default_draw_grips (EdaRenderer *renderer, OBJECT *object)
   case OBJ_CIRCLE:
     /* Grip at bottom right of containing square */
     eda_renderer_draw_grips_impl (renderer, GRIP_SQUARE, 1,
-        geda_circle_object_get_center_x (object) + geda_circle_object_get_radius (object),
-        geda_circle_object_get_center_y (object) - geda_circle_object_get_radius (object));
+        lepton_circle_object_get_center_x (object) + lepton_circle_object_get_radius (object),
+        lepton_circle_object_get_center_y (object) - lepton_circle_object_get_radius (object));
     break;
   case OBJ_PATH:
     eda_renderer_draw_path_grips (renderer, object);
@@ -1124,14 +1144,19 @@ eda_renderer_default_draw_grips (EdaRenderer *renderer, OBJECT *object)
     eda_renderer_draw_text_grips (renderer, object);
     break;
   case OBJ_PICTURE:
-    eda_renderer_draw_grips_impl (renderer, GRIP_SQUARE, 4,
-        object->picture->upper_x, object->picture->upper_y,
-        object->picture->lower_x, object->picture->upper_y,
-        object->picture->upper_x, object->picture->lower_y,
-        object->picture->lower_x, object->picture->lower_y);
+    eda_renderer_draw_grips_impl (renderer,
+                                  GRIP_SQUARE,
+                                  4,
+                                  lepton_picture_object_get_upper_x (object),
+                                  lepton_picture_object_get_upper_y (object),
+                                  lepton_picture_object_get_lower_x (object),
+                                  lepton_picture_object_get_upper_y (object),
+                                  lepton_picture_object_get_upper_x (object),
+                                  lepton_picture_object_get_lower_y (object),
+                                  lepton_picture_object_get_lower_x (object),
+                                  lepton_picture_object_get_lower_y (object));
     break;
   case OBJ_COMPONENT:
-  case OBJ_PLACEHOLDER:
     /* No grips */
     break;
   default:
@@ -1183,7 +1208,7 @@ eda_renderer_draw_grips_impl (EdaRenderer *renderer, int type, int n_grips, ...)
 }
 
 static void
-eda_renderer_draw_arc_grips (EdaRenderer *renderer, OBJECT *object)
+eda_renderer_draw_arc_grips (EdaRenderer *renderer, LeptonObject *object)
 {
   double radius, start_angle, sweep_angle;
   int x1, y1, x2, y2, x3, y3;
@@ -1197,12 +1222,12 @@ eda_renderer_draw_arc_grips (EdaRenderer *renderer, OBJECT *object)
    *   <DT>*</DT><DD>one at the end of the arc - at (<B>x2</B>,<B>y2</B>).
    */
 
-  x1 = geda_arc_object_get_center_x (object);
-  y1 = geda_arc_object_get_center_y (object);
+  x1 = lepton_arc_object_get_center_x (object);
+  y1 = lepton_arc_object_get_center_y (object);
 
-  radius      = geda_arc_object_get_radius (object);
-  start_angle = geda_arc_object_get_start_angle (object);
-  sweep_angle = geda_arc_object_get_sweep_angle (object);
+  radius      = lepton_arc_object_get_radius (object);
+  start_angle = lepton_arc_object_get_start_angle (object);
+  sweep_angle = lepton_arc_object_get_sweep_angle (object);
 
   x2 = x1 + radius * cos ( start_angle                * M_PI / 180);
   y2 = y1 + radius * sin ( start_angle                * M_PI / 180);
@@ -1216,11 +1241,11 @@ eda_renderer_draw_arc_grips (EdaRenderer *renderer, OBJECT *object)
 }
 
 static void
-eda_renderer_draw_path_grips (EdaRenderer *renderer, OBJECT *object)
+eda_renderer_draw_path_grips (EdaRenderer *renderer, LeptonObject *object)
 {
   int i, last_x = 0, last_y = 0, next_x, next_y;
   for (i = 0; i < object->path->num_sections; i++) {
-    PATH_SECTION *section = object->path->sections + i;
+    LeptonPathSection *section = object->path->sections + i;
 
     if (section->code != PATH_END) {
       next_x = section->x3;
@@ -1260,7 +1285,7 @@ eda_renderer_draw_path_grips (EdaRenderer *renderer, OBJECT *object)
 }
 
 static void
-eda_renderer_draw_text_grips (EdaRenderer *renderer, OBJECT *object)
+eda_renderer_draw_text_grips (EdaRenderer *renderer, LeptonObject *object)
 {
   double dummy = 0, small_dist = TEXT_MARKER_SIZE;
   int x = object->text->x;
@@ -1307,24 +1332,24 @@ eda_renderer_draw_cues_list (EdaRenderer *renderer, GList *objects)
   GList *iter;
 
   for (iter = objects; iter != NULL; iter = g_list_next (iter)) {
-    eda_renderer_draw_cues (renderer, (OBJECT *) iter->data);
+    eda_renderer_draw_cues (renderer, (LeptonObject *) iter->data);
   }
 }
 
 void
-eda_renderer_draw_cues (EdaRenderer *renderer, OBJECT *object)
+eda_renderer_draw_cues (EdaRenderer *renderer, LeptonObject *object)
 {
   g_return_if_fail (EDA_IS_RENDERER (renderer));
   EDA_RENDERER_GET_CLASS (renderer)->draw_cues (renderer, object);
 }
 
 static void
-eda_renderer_default_draw_cues (EdaRenderer *renderer, OBJECT *object)
+eda_renderer_default_draw_cues (EdaRenderer *renderer, LeptonObject *object)
 {
   g_return_if_fail (object != NULL);
   g_return_if_fail (renderer->priv->cr != NULL);
 
-  switch (object->type) {
+  switch (lepton_object_get_type (object)) {
   case OBJ_LINE:
   case OBJ_BOX:
   case OBJ_ARC:
@@ -1334,7 +1359,6 @@ eda_renderer_default_draw_cues (EdaRenderer *renderer, OBJECT *object)
   case OBJ_PICTURE:
     break;
   case OBJ_COMPONENT:
-  case OBJ_PLACEHOLDER:
     /* Recurse */
     eda_renderer_draw_cues_list (renderer, object->component->prim_objs);
     break;
@@ -1354,7 +1378,7 @@ eda_renderer_default_draw_cues (EdaRenderer *renderer, OBJECT *object)
 }
 
 static void
-eda_renderer_draw_end_cues (EdaRenderer *renderer, OBJECT *object, int end)
+eda_renderer_draw_end_cues (EdaRenderer *renderer, LeptonObject *object, int end)
 {
   int x = object->line->x[end], y = object->line->y[end];
   int conn_count = 0;
@@ -1363,20 +1387,21 @@ eda_renderer_draw_end_cues (EdaRenderer *renderer, OBJECT *object, int end)
   GList *iter;
 
   /* We should never be at the unconnectable end of a pin */
-  g_return_if_fail ((object->type != OBJ_PIN) || (object->whichend == end));
+  g_return_if_fail (!lepton_object_is_pin (object) ||
+                    (object->whichend == end));
 
   /* Check whether the current object is a bus or bus pin */
-  is_bus = ((object->type == OBJ_BUS)
-            || ((object->type == OBJ_PIN)
+  is_bus = (lepton_object_is_bus (object)
+            || (lepton_object_is_pin (object)
                 && (object->pin_type == PIN_TYPE_BUS)));
 
   for (iter = object->conn_list; iter != NULL; iter = g_list_next (iter)) {
-    CONN *conn = (CONN *) iter->data;
+    LeptonConn *conn = (LeptonConn *) iter->data;
     if ((conn->x != x) || (conn->y != y)) continue;
 
     /* Check whether the connected object is a bus or bus pin */
-    is_bus |= ((conn->other_object->type == OBJ_BUS)
-               || ((conn->other_object->type == OBJ_PIN)
+    is_bus |= (lepton_object_is_bus (conn->other_object)
+               || (lepton_object_is_pin (conn->other_object)
                    && (conn->other_object->pin_type == PIN_TYPE_BUS)));
 
     if (conn->type == CONN_MIDPOINT) {
@@ -1390,7 +1415,8 @@ eda_renderer_draw_end_cues (EdaRenderer *renderer, OBJECT *object, int end)
 
   /* Draw a midpoint, if necessary */
   if ((conn_type == CONN_MIDPOINT)
-      || ((object->type == OBJ_NET) && (conn_count > 1))) {
+      || (lepton_object_is_net (object) && (conn_count > 1)))
+  {
     eda_renderer_draw_junction_cue (renderer, x, y, is_bus);
     return;
   }
@@ -1400,7 +1426,7 @@ eda_renderer_draw_end_cues (EdaRenderer *renderer, OBJECT *object, int end)
     return;
   eda_renderer_set_color (renderer, NET_ENDPOINT_COLOR);
 
-  switch (object->type) {
+  switch (lepton_object_get_type (object)) {
   case OBJ_NET:
   case OBJ_PIN:
     /* If less than one thing was connected to this end of the net
@@ -1421,16 +1447,16 @@ eda_renderer_draw_end_cues (EdaRenderer *renderer, OBJECT *object, int end)
 }
 
 static void
-eda_renderer_draw_mid_cues (EdaRenderer *renderer, OBJECT *object)
+eda_renderer_draw_mid_cues (EdaRenderer *renderer, LeptonObject *object)
 {
   GList *iter;
   for (iter = object->conn_list; iter != NULL; iter = g_list_next (iter)) {
-    CONN *conn = (CONN *) iter->data;
+    LeptonConn *conn = (LeptonConn *) iter->data;
 
     if (conn->type == CONN_MIDPOINT) {
-      int is_bus = ((object->type == OBJ_BUS)
-                    || (conn->other_object->type == OBJ_BUS)
-                    || ((conn->other_object->type == OBJ_PIN)
+      int is_bus = (lepton_object_is_bus (object)
+                    || lepton_object_is_bus (conn->other_object)
+                    || (lepton_object_is_pin (conn->other_object)
                         && (conn->other_object->pin_type == PIN_TYPE_BUS)));
       eda_renderer_draw_junction_cue (renderer, conn->x, conn->y, is_bus);
     }
@@ -1459,7 +1485,7 @@ eda_renderer_draw_junction_cue (EdaRenderer *renderer, int x, int y, int is_bus)
 
 gboolean
 eda_renderer_get_user_bounds (EdaRenderer *renderer,
-                              const GedaObject *object,
+                              const LeptonObject *object,
                               double *left,
                               double *top,
                               double *right,
@@ -1474,7 +1500,7 @@ eda_renderer_get_user_bounds (EdaRenderer *renderer,
 
 static gboolean
 eda_renderer_default_get_user_bounds (EdaRenderer *renderer,
-                                      const GedaObject *object,
+                                      const LeptonObject *object,
                                       double *left,
                                       double *top,
                                       double *right,
@@ -1483,7 +1509,7 @@ eda_renderer_default_get_user_bounds (EdaRenderer *renderer,
   g_return_val_if_fail ((object != NULL), FALSE);
   g_return_val_if_fail ((renderer->priv->cr != NULL), FALSE);
 
-  switch (object->type) {
+  switch (lepton_object_get_type (object)) {
   case OBJ_TEXT:
     return eda_renderer_get_text_user_bounds (object, FALSE,
                                               left, top, right, bottom);
@@ -1494,11 +1520,10 @@ eda_renderer_default_get_user_bounds (EdaRenderer *renderer,
   case OBJ_PATH:
   case OBJ_PICTURE:
   case OBJ_COMPONENT:
-  case OBJ_PLACEHOLDER:
   case OBJ_NET:
   case OBJ_BUS:
   case OBJ_PIN:
-    /* No rendered bounds available for most OBJECT types. */
+    /* No rendered bounds available for most LeptonObject types. */
     return FALSE;
   default:
     g_return_val_if_reached (FALSE);
@@ -1506,7 +1531,7 @@ eda_renderer_default_get_user_bounds (EdaRenderer *renderer,
 }
 
 gboolean
-eda_renderer_get_text_user_bounds (const GedaObject *object,
+eda_renderer_get_text_user_bounds (const LeptonObject *object,
                                    gboolean enable_hidden,
                                    double *left,
                                    double *top,
