@@ -1,7 +1,7 @@
 /* Lepton EDA library
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2015 gEDA Contributors
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,9 +26,10 @@
  *  The part before the equal character is called <b>name</b> the
  *  part of the string behind the equal character is called <b>value</b>
  *
- *  Attributes are attached to OBJECTs (st_object). Each attribute has
- *  a reference to the object it is attached to. Each object that has
- *  attributes has a list of pointers to its attributes.
+ *  Attributes are attached to LeptonObjects (st_object). Each
+ *  attribute has a reference to the object it is attached
+ *  to. Each object that has attributes has a list of pointers to
+ *  its attributes.
  *
  *  \image html o_attrib_overview.png
  *  \image latex o_attrib_overview.pdf "attribute overview" width=14cm
@@ -48,16 +49,16 @@
 #endif
 #include <math.h>
 
-#include "libgeda_priv.h"
+#include "liblepton_priv.h"
 
 
 /*! \brief Add an attribute to an existing attribute list.
  *
- *  \param [in]  object     The OBJECT we're adding the attribute to.
+ *  \param [in]  object     The LeptonObject we're adding the attribute to.
  *  \param [in]  item       The item you want to add as an attribute.
  */
 void
-o_attrib_add (OBJECT *object, OBJECT *item)
+o_attrib_add (LeptonObject *object, LeptonObject *item)
 {
   /* Add link from item to attrib listing */
   item->attached_to = object;
@@ -72,8 +73,8 @@ o_attrib_add (OBJECT *object, OBJECT *item)
  *  \param [in]  set_color    Whether or not we should set the new attribute's color.
  */
 void
-o_attrib_attach (OBJECT *attrib,
-                 OBJECT *object,
+o_attrib_attach (LeptonObject *attrib,
+                 LeptonObject *object,
                  int set_color)
 {
   g_return_if_fail (attrib != NULL);
@@ -82,11 +83,12 @@ o_attrib_attach (OBJECT *attrib,
   /* is the object already part of the list ? */
   if (g_list_find (object->attribs, attrib)) {
     g_warning (_("Attribute [%1$s] already attached\n"),
-               geda_text_object_get_string (attrib));
+               lepton_text_object_get_string (attrib));
     return;
   }
 
-  if (attrib->type != OBJ_TEXT) {
+  if (!lepton_object_is_text (attrib))
+  {
     g_warning (_("Attempt to attach non text item as an attribute!\n"));
     return;
   }
@@ -104,7 +106,7 @@ o_attrib_attach (OBJECT *attrib,
   o_attrib_add (object, attrib);
 
   if (set_color)
-    o_set_color (attrib, ATTRIBUTE_COLOR);
+    lepton_object_set_color (attrib, ATTRIBUTE_COLOR);
 }
 
 
@@ -116,13 +118,13 @@ o_attrib_attach (OBJECT *attrib,
  */
 void
 o_attrib_attach_list (GList *attr_list,
-                      OBJECT *object,
+                      LeptonObject *object,
                       int set_color)
 {
   GList *iter;
 
   for (iter = attr_list; iter != NULL; iter = g_list_next (iter))
-    o_attrib_attach ((OBJECT*) iter->data, object, set_color);
+    o_attrib_attach ((LeptonObject*) iter->data, object, set_color);
 }
 
 
@@ -131,17 +133,17 @@ o_attrib_attach_list (GList *attr_list,
  *  \param [in,out] object    The object whose attributes to detach.
  */
 void
-o_attrib_detach_all (OBJECT *object)
+o_attrib_detach_all (LeptonObject *object)
 {
-  OBJECT *a_current;
+  LeptonObject *a_current;
   GList *a_iter;
 
   for (a_iter = object->attribs; a_iter != NULL;
        a_iter = g_list_next (a_iter)) {
-    a_current = (OBJECT*) a_iter->data;
+    a_current = (LeptonObject*) a_iter->data;
 
     a_current->attached_to = NULL;
-    o_set_color (a_current, DETACHED_ATTRIBUTE_COLOR);
+    lepton_object_set_color (a_current, DETACHED_ATTRIBUTE_COLOR);
   }
 
   g_list_free (object->attribs);
@@ -154,16 +156,16 @@ o_attrib_detach_all (OBJECT *object)
  */
 void o_attrib_print(GList *attributes)
 {
-  OBJECT *a_current;
+  LeptonObject *a_current;
   GList *a_iter;
 
   a_iter = attributes;
 
   while (a_iter != NULL) {
-    a_current = (OBJECT*) a_iter->data;
+    a_current = (LeptonObject*) a_iter->data;
     printf("Attribute points to: %1$s\n", a_current->name);
     if (a_current->text) {
-      printf("\tText is: %1$s\n", geda_text_object_get_string (a_current));
+      printf("\tText is: %1$s\n", lepton_text_object_get_string (a_current));
     }
 
     a_iter = g_list_next (a_iter);
@@ -177,11 +179,11 @@ void o_attrib_print(GList *attributes)
  *  This function should be used when detaching an attribute.
  *
  *  \param [in] list      The attribute list to remove attribute from.
- *  \param [in] remove    The OBJECT to remove from list.
+ *  \param [in] remove    The LeptonObject to remove from list.
  */
 void
 o_attrib_remove (GList **list,
-                 OBJECT *remove)
+                 LeptonObject *remove)
 {
   g_return_if_fail (remove != NULL);
 
@@ -192,20 +194,23 @@ o_attrib_remove (GList **list,
 
 /*! \brief Read attributes from a TextBuffer.
  *
- *  \param [in]  page                   The PAGE object.
+ *  \param [in]  page                   The LeptonPage object.
  *  \param [in]  object_to_get_attribs  Object which gets these attribs.
  *  \param [in]  tb                     The text buffer to read from.
  *  \param [in]  release_ver            libgeda release version number.
  *  \param [in]  fileformat_ver         file format version number.
  *  \return GList of attributes read, or NULL on error.
  */
-GList *o_read_attribs (PAGE *page,
-                       OBJECT *object_to_get_attribs,
-                       TextBuffer *tb,
-                       unsigned int release_ver, unsigned int fileformat_ver, GError ** err)
+GList*
+o_read_attribs (LeptonPage *page,
+                LeptonObject *object_to_get_attribs,
+                TextBuffer *tb,
+                unsigned int release_ver,
+                unsigned int fileformat_ver,
+                GError ** err)
 {
   GList *object_list = NULL;
-  OBJECT *new_obj;
+  LeptonObject *new_obj;
   const char *line = NULL;
   char objtype;
   int ATTACH=FALSE;
@@ -250,7 +255,6 @@ GList *o_read_attribs (PAGE *page,
         break;
 
       case(OBJ_COMPONENT):
-      case(OBJ_PLACEHOLDER):
         if ((new_obj = o_component_read (page, line, release_ver, fileformat_ver, err)) == NULL)
           goto error;
         object_list = g_list_prepend (object_list, new_obj);
@@ -303,7 +307,7 @@ GList *o_read_attribs (PAGE *page,
                _("Unexpected end-of-file in attribute list"));
 
 error:
-  geda_object_list_delete (object_list);
+  lepton_object_list_delete (object_list);
   return NULL;
 }
 
@@ -367,24 +371,24 @@ o_attrib_string_get_name_value (const gchar *string, gchar **name_ptr, gchar **v
 }
 
 
-/*! \brief Get name and value from an attribute OBJECT
+/*! \brief Get name and value from an attribute LeptonObject
  *
  *  \par Function Description
  *  See o_attrib_string_get_name_value() for more details
  *
- *  \param [in]  attrib     The attribute OBJECT whose name/value to return.
+ *  \param [in]  attrib     The attribute LeptonObject whose name/value to return.
  *  \param [out] name_ptr   The return location for the name, or NULL.
  *  \param [out] value_ptr  The return location for the value, or NULL.
  *  \return TRUE on success, FALSE otherwise.
  */
 gboolean
-o_attrib_get_name_value (const OBJECT *attrib,
+o_attrib_get_name_value (const LeptonObject *attrib,
                          gchar **name_ptr,
                          gchar **value_ptr)
 {
-  g_return_val_if_fail (attrib->type == OBJ_TEXT, FALSE);
+  g_return_val_if_fail (lepton_object_is_text (attrib), FALSE);
 
-  return o_attrib_string_get_name_value (geda_text_object_get_string (attrib),
+  return o_attrib_string_get_name_value (lepton_text_object_get_string (attrib),
                                          name_ptr, value_ptr);
 }
 
@@ -395,20 +399,21 @@ o_attrib_get_name_value (const OBJECT *attrib,
  * object \a attrib.  If \a attrib is an invalid attribute, returns
  * NULL.
  *
- * \param attrib   An attribute #OBJECT
+ * \param attrib   An attribute #LeptonObject
  * \return The interned attribute name, or NULL.
  */
 const gchar *
-o_attrib_get_name (const OBJECT *attrib)
+o_attrib_get_name (const LeptonObject *attrib)
 {
   g_return_val_if_fail (attrib, 0);
-  g_return_val_if_fail (attrib->type == OBJ_TEXT, 0);
+  g_return_val_if_fail (lepton_object_is_text (attrib), 0);
+
   return attrib->text->name;
 }
 
 /*! \brief Find all floating attributes in the given object list.
  *
- *  \param [in] list  GList of OBJECTs to search for floating attributes.
+ *  \param [in] list  GList of LeptonObjects to search for floating attributes.
  *  \return GList of floating attributes from the input list
  *
  *  Caller must g_list_free() the returned list.
@@ -417,10 +422,10 @@ GList *o_attrib_find_floating_attribs (const GList *list)
 {
   GList *floating_attributes = NULL;
   const GList *iter;
-  OBJECT *o_current;
+  LeptonObject *o_current;
 
   for (iter = list; iter != NULL; iter = g_list_next (iter)) {
-    o_current = (OBJECT*) iter->data;
+    o_current = (LeptonObject*) iter->data;
 
     /* Skip non text objects, attached attributes and text which doesn't
      * constitute a valid attributes (e.g. general text placed on the page)
@@ -448,7 +453,7 @@ GList *o_attrib_find_floating_attribs (const GList *list)
  *  \param [in] count    Which occurrence to return.
  *  \return The n'th attribute object in the given list with the given name.
  */
-OBJECT *o_attrib_find_attrib_by_name (const GList *list,
+LeptonObject *o_attrib_find_attrib_by_name (const GList *list,
                                       const char *name,
                                       int count)
 {
@@ -458,8 +463,8 @@ OBJECT *o_attrib_find_attrib_by_name (const GList *list,
   int num_found = 0;
 
   for (const GList *iter = list; iter; iter = g_list_next (iter)) {
-    OBJECT *attrib = (OBJECT*) iter->data;
-    g_return_val_if_fail (attrib->type == OBJ_TEXT, NULL);
+    LeptonObject *attrib = (LeptonObject*) iter->data;
+    g_return_val_if_fail (lepton_object_is_text (attrib), NULL);
 
     if ((needle == o_attrib_get_name (attrib)) &&
         (num_found++ == count)) {
@@ -487,7 +492,7 @@ static char *o_attrib_search_attrib_list_by_name (const GList *list,
                                                   const char *name,
                                                   int counter)
 {
-  OBJECT *attrib;
+  LeptonObject *attrib;
   char *value = NULL;
 
   attrib = o_attrib_find_attrib_by_name (list, name, counter);
@@ -506,7 +511,7 @@ static char *o_attrib_search_attrib_list_by_name (const GList *list,
  *  Counter is the n'th occurrence of the attribute, and starts searching
  *  from zero.  Zero is the first occurrence of an attribute.
  *
- *  \param [in] list     GList of OBJECTs to search for floating attributes.
+ *  \param [in] list     GList of LeptonObjects to search for floating attributes.
  *  \param [in] name     Character string with attribute name to search for.
  *  \param [in] counter  Which occurrence to return.
  *  \return Character string with attribute value, NULL otherwise.
@@ -536,7 +541,7 @@ char *o_attrib_search_floating_attribs_by_name (const GList *list,
  *  Counter is the n'th occurrence of the attribute, and starts searching
  *  from zero.  Zero is the first occurrence of an attribute.
  *
- *  \param [in] object   The OBJECT whose attached attributes to search.
+ *  \param [in] object   The LeptonObject whose attached attributes to search.
  *  \param [in] name     Character string with attribute name to search for.
  *  \param [in] counter  Which occurrence to return.
  *  \return Character string with attribute value, NULL otherwise.
@@ -544,7 +549,7 @@ char *o_attrib_search_floating_attribs_by_name (const GList *list,
  *  \warning
  *  Caller must g_free returned character string.
  */
-char *o_attrib_search_attached_attribs_by_name (OBJECT *object,
+char *o_attrib_search_attached_attribs_by_name (LeptonObject *object,
                                                 const char *name,
                                                 int counter)
 {
@@ -559,7 +564,7 @@ char *o_attrib_search_attached_attribs_by_name (OBJECT *object,
  *  Counter is the n'th occurrence of the attribute, and starts searching
  *  from zero.  Zero is the first occurrence of an attribute.
  *
- *  \param [in] object   The OBJECT whose inherited attributes to search.
+ *  \param [in] object   The LeptonObject whose inherited attributes to search.
  *  \param [in] name     Character string with attribute name to search for.
  *  \param [in] counter  Which occurrence to return.
  *  \return Character string with attribute value, NULL otherwise.
@@ -567,12 +572,11 @@ char *o_attrib_search_attached_attribs_by_name (OBJECT *object,
  *  \warning
  *  Caller must g_free returned character string.
  */
-char *o_attrib_search_inherited_attribs_by_name (OBJECT *object,
+char *o_attrib_search_inherited_attribs_by_name (LeptonObject *object,
                                                  const char *name,
                                                  int counter)
 {
-  g_return_val_if_fail (object->type == OBJ_COMPONENT ||
-                        object->type == OBJ_PLACEHOLDER, NULL);
+  g_return_val_if_fail (lepton_object_is_component (object), NULL);
 
   return o_attrib_search_floating_attribs_by_name (object->component->prim_objs, name, counter);
 }
@@ -587,12 +591,12 @@ char *o_attrib_search_inherited_attribs_by_name (OBJECT *object,
  *
  *  Caller must g_free() the returned character string.
  *
- *  \param [in] object   OBJECT who's attributes to search.
+ *  \param [in] object   LeptonObject who's attributes to search.
  *  \param [in] name     Character string with attribute name to search for.
  *  \param [in] counter  Which occurrence to return.
  *  \return              Attribute value, NULL if not found.
  */
-char *o_attrib_search_object_attribs_by_name (OBJECT *object,
+char *o_attrib_search_object_attribs_by_name (LeptonObject *object,
                                               const char *name,
                                               int counter)
 {
@@ -612,20 +616,20 @@ char *o_attrib_search_object_attribs_by_name (OBJECT *object,
  *  \par Function Description
  *
  *  This function aggregates the attached and inherited attributes
- *  belonging to a given OBJECT into one GList and returns it.
+ *  belonging to a given LeptonObject into one GList and returns it.
  *  Inherited attributes are those which live as toplevel un-attached
- *  attributes inside in a component OBJECT's prim_objs.
+ *  attributes inside in a component LeptonObject's prim_objs.
  *
  *  Caller must g_list_free() the returned GList.
  *
- *  \param [in] object  OBJECT whose attributes to return.
+ *  \param [in] object  LeptonObject whose attributes to return.
  *  \return             A GList of attached and inherited attributes.
  */
-GList * o_attrib_return_attribs (OBJECT *object)
+GList * o_attrib_return_attribs (LeptonObject *object)
 {
   GList *attribs = NULL;
   GList *inherited_attribs;
-  OBJECT *a_current;
+  LeptonObject *a_current;
   GList *a_iter;
 
   g_return_val_if_fail (object != NULL, NULL);
@@ -633,9 +637,9 @@ GList * o_attrib_return_attribs (OBJECT *object)
   /* Directly attached attributes */
   for (a_iter = object->attribs; a_iter != NULL;
        a_iter = g_list_next (a_iter)) {
-    a_current = (OBJECT*) a_iter->data;
+    a_current = (LeptonObject*) a_iter->data;
 
-    if (a_current->type != OBJ_TEXT)
+    if (!lepton_object_is_text (a_current))
       continue;
 
     /* Don't add invalid attributes to the list */
@@ -648,9 +652,8 @@ GList * o_attrib_return_attribs (OBJECT *object)
   attribs = g_list_reverse (attribs);
 
   /* Inherited attributes (inside component objects) */
-  if (object->type == OBJ_COMPONENT ||
-      object->type == OBJ_PLACEHOLDER) {
-
+  if (lepton_object_is_component (object))
+  {
     inherited_attribs =
       o_attrib_find_floating_attribs (object->component->prim_objs);
 
@@ -661,16 +664,16 @@ GList * o_attrib_return_attribs (OBJECT *object)
 }
 
 
-/*! \brief Query whether a given attribute OBJECT is "inherited".
+/*! \brief Query whether a given attribute LeptonObject is "inherited".
  *
  *  \par Function Description
- *  This function returns TRUE if the given attribute OBJECT is a
+ *  This function returns TRUE if the given attribute LeptonObject is a
  *  toplevel un-attached attribute inside a component's prim_objs.
  *
- *  \param [in] attrib       OBJECT who's status to query.
+ *  \param [in] attrib       LeptonObject who's status to query.
  *  \return TRUE if the attribute is inherited, FALSE otherwise.
  */
-int o_attrib_is_inherited (const OBJECT *attrib)
+int o_attrib_is_inherited (const LeptonObject *attrib)
 {
   return (attrib->attached_to == NULL &&
           attrib->parent != NULL);
@@ -681,9 +684,8 @@ int o_attrib_is_inherited (const OBJECT *attrib)
  *  \return  TRUE if \a obj is an attribute, FALSE otherwise.
  */
 gboolean
-o_attrib_is_attrib (const OBJECT *obj)
+o_attrib_is_attrib (const LeptonObject *obj)
 {
-  return (obj &&
-          (obj->type == OBJ_TEXT) &&
+  return (lepton_object_is_text (obj) &&
           o_attrib_get_name (obj));
 }
