@@ -2,7 +2,7 @@
  * Copyright (C) 2003-2010 Stuart D. Brorson.
  * Copyright (C) 2016 Peter Brett <peter@peter-b.co.uk>
  * Copyright (C) 2003-2016 gEDA Contributors
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -48,7 +48,7 @@
  * Gattrib specific includes
  *------------------------------------------------------------------*/
 #include <liblepton/liblepton.h>
-#include <liblepton/libgedaguile.h>
+#include <liblepton/libleptonguile.h>
 #include "../include/struct.h"     /* typdef and struct declarations */
 #include "../include/prototype.h"  /* function prototypes */
 #include "../include/globals.h"
@@ -68,15 +68,18 @@ x_window_create_menu(GtkWindow *window, GtkWidget **menubar);
 static void
 x_window_set_default_icon( void );
 
-static TOPLEVEL *window_toplevel = NULL;
+static void
+x_window_set_title (GList* plist);
+
+static LeptonToplevel *window_toplevel = NULL;
 
 void
-x_window_set_toplevel (TOPLEVEL *toplevel)
+x_window_set_toplevel (LeptonToplevel *toplevel)
 {
   window_toplevel = toplevel;
 }
 
-TOPLEVEL*
+LeptonToplevel*
 x_window_get_toplevel ()
 {
   return window_toplevel;
@@ -103,8 +106,6 @@ x_window_init ()
   /*  window is a global declared in globals.h.  */
   window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 
-  gtk_window_set_title( GTK_WINDOW(window), _("lepton-attrib - Lepton EDA attribute editor"));
-
   g_signal_connect(window, "delete_event",
                    G_CALLBACK (attrib_really_quit), 0);
 
@@ -125,8 +126,52 @@ x_window_init ()
   /* -----  Now init notebook widget  ----- */
   notebook = gtk_notebook_new();
   gtk_notebook_set_tab_pos(GTK_NOTEBOOK(notebook), GTK_POS_BOTTOM);
+  gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
   gtk_box_pack_start(GTK_BOX(main_vbox), notebook, TRUE, TRUE, 0);
 
+
+  /* Status bar:
+  */
+  GtkWidget* sbar = gtk_statusbar_new();
+  gtk_box_pack_start (GTK_BOX (main_vbox), sbar, FALSE, TRUE, 0);
+  GtkWidget* marea = gtk_statusbar_get_message_area (GTK_STATUSBAR (sbar));
+
+  GtkWidget* label_1 = gtk_label_new (NULL);
+  gtk_label_set_markup (GTK_LABEL (label_1), _("   Color Legend:  "));
+
+  GtkWidget* label_inv      = gtk_label_new (_(" Invisible ") );
+  GtkWidget* label_val      = gtk_label_new (_(" Show value "));
+  GtkWidget* label_name     = gtk_label_new (_(" Show name "));
+  GtkWidget* label_name_val = gtk_label_new (_(" Show name and value "));
+
+  gtk_box_pack_start (GTK_BOX (marea), label_1, FALSE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (marea), gtk_vseparator_new() , FALSE, TRUE, 0);
+
+  gtk_box_pack_start (GTK_BOX (marea), label_inv, FALSE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (marea), gtk_vseparator_new() , FALSE, TRUE, 0);
+
+  gtk_box_pack_start (GTK_BOX (marea), label_val, FALSE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (marea), gtk_vseparator_new() , FALSE, TRUE, 0);
+
+  gtk_box_pack_start (GTK_BOX (marea), label_name, FALSE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (marea), gtk_vseparator_new() , FALSE, TRUE, 0);
+
+  gtk_box_pack_start (GTK_BOX (marea), label_name_val, FALSE, TRUE, 0);
+
+  GdkColor color;
+  gdk_color_parse ("grey", &color);
+  gtk_widget_modify_fg (label_inv, GTK_STATE_NORMAL, &color);
+
+  gdk_color_parse ("black", &color);
+  gtk_widget_modify_fg (label_val, GTK_STATE_NORMAL, &color);
+
+  gdk_color_parse ("red", &color);
+  gtk_widget_modify_fg (label_name, GTK_STATE_NORMAL, &color);
+
+  gdk_color_parse ("blue", &color);
+  gtk_widget_modify_fg (label_name_val, GTK_STATE_NORMAL, &color);
+
+
   /* -----  Now malloc -- but don't fill out -- space for sheets  ----- */
   /* This basically sets up the overhead for the sheets, as I understand
    * it.  The memory for the actual sheet cells is allocated later,
@@ -464,6 +509,72 @@ x_window_set_default_icon( void )
 }
 
 
+/*! \brief Set the main window's title.
+ *
+ *  \param plist  The list of LeptonPage objects (opened pages).
+ */
+static void
+x_window_set_title (GList* plist)
+{
+  g_return_if_fail (plist != NULL);
+  g_return_if_fail (window != NULL);
+
+  const gchar* prog_name = "lepton-attrib";
+  gchar* title = NULL;
+
+  if (g_list_length (plist) == 1)
+  {
+    const gchar* fpath = s_page_get_filename ((LeptonPage *) plist->data);
+    gchar* fname = g_path_get_basename (fpath);
+
+    title = g_strdup_printf ("%s - %s", fname, prog_name);
+
+    g_free (fname);
+  }
+  else
+  if (g_list_length (plist) > 1)
+  {
+    title = g_strdup_printf ("%s - %s", _("Multiple files"), prog_name);
+  }
+  else
+  {
+    title = g_strdup_printf ("%s", prog_name);
+  }
+
+  gtk_window_set_title (GTK_WINDOW (window), title);
+  g_free (title);
+}
+
+
+/*! \brief Indicate if document has \a changed in the title.
+ */
+void
+x_window_set_title_changed (int changed)
+{
+  const gchar* title = gtk_window_get_title (GTK_WINDOW (window));
+  const gchar* prefix = "* ";
+
+  if (changed)
+  {
+    if (!g_str_has_prefix (title, prefix))
+    {
+      gchar* title_new = g_strdup_printf ("%s%s", prefix, title);
+      gtk_window_set_title (GTK_WINDOW (window), title_new);
+      g_free (title_new);
+    }
+  }
+  else
+  {
+    if (g_str_has_prefix (title, prefix))
+    {
+      gchar* title_new = g_strdup (title + strlen (prefix));
+      gtk_window_set_title (GTK_WINDOW (window), title_new);
+      g_free (title_new);
+    }
+  }
+}
+
+
 /*! \brief Open lepton-attrib window.
  *
  * The function populates the spreadsheet data structure and
@@ -473,9 +584,9 @@ void
 lepton_attrib_window ()
 {
   GList *iter;
-  PAGE *p_local;
+  LeptonPage *p_local;
 
-  TOPLEVEL *toplevel = edascm_c_current_toplevel ();
+  LeptonToplevel *toplevel = edascm_c_current_toplevel ();
   x_window_set_toplevel (toplevel);
 
   /* Initialize GTK window. */
@@ -485,11 +596,11 @@ lepton_attrib_window ()
      in globals.h) */
   sheet_head = s_sheet_data_new();
 
-  for (iter = geda_list_get_glist (toplevel->pages);
+  for (iter = lepton_list_get_glist (toplevel->pages);
        iter != NULL;
        iter = g_list_next (iter)) {
 
-    p_local = (PAGE*) iter->data;
+    p_local = (LeptonPage*) iter->data;
     s_toplevel_set_page_current (toplevel, p_local);
 
     /* Now add all items found to the master lists */
@@ -528,10 +639,10 @@ lepton_attrib_window ()
   sheet_head->pin_table = s_table_new(sheet_head->pin_count, sheet_head->pin_attrib_count);
 
   /* must iterate over all pages in design */
-  for ( iter = geda_list_get_glist( toplevel->pages );
+  for ( iter = lepton_list_get_glist( toplevel->pages );
         iter != NULL;
         iter = g_list_next( iter ) ) {
-    p_local = (PAGE *)iter->data;
+    p_local = (LeptonPage *)iter->data;
 
     /* only traverse pages which are toplevel */
     if (p_local->page_control == 0) {
@@ -558,4 +669,6 @@ lepton_attrib_window ()
 
   /* ---------- Now verify correctness of entire design.  ---------- */
   s_toplevel_verify_design(toplevel);  /* toplevel is a global */
+
+  x_window_set_title (lepton_list_get_glist (toplevel->pages));
 }
