@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -76,13 +76,13 @@ get_property (GObject *object, guint param_id, GValue *value, GParamSpec *pspec)
 
 static GList*
 get_subpages (GschemToplevel *w_current,
-              PAGE *page);
+              LeptonPage *page);
 
 static void
-object_weakref_cb (OBJECT *object, GschemFindTextState *state);
+object_weakref_cb (LeptonObject *object, GschemFindTextState *state);
 
 static void
-remove_object (GschemFindTextState *state, OBJECT *object);
+remove_object (GschemFindTextState *state, LeptonObject *object);
 
 static void
 select_cb (GtkTreeSelection *selection, GschemFindTextState *state);
@@ -184,7 +184,7 @@ assign_store (GschemFindTextState *state, GSList *objects, gboolean filter_text)
 
   while (object_iter != NULL) {
     char *basename;
-    OBJECT *object = (OBJECT*) object_iter->data;
+    LeptonObject *object = (LeptonObject*) object_iter->data;
     const char *str;
     GtkTreeIter tree_iter;
 
@@ -200,13 +200,14 @@ assign_store (GschemFindTextState *state, GSList *objects, gboolean filter_text)
       continue;
     }
 
-    if (filter_text && (object->type != OBJ_TEXT)) {
+    if (filter_text && !lepton_object_is_text (object))
+    {
       g_warning ("expecting a text object");
       continue;
     }
 
     if (filter_text) {
-      str = geda_text_object_get_string (object);
+      str = lepton_text_object_get_string (object);
     } else {
       str = scm_to_utf8_string (scm_call_1 (scm_c_public_ref ("schematic symbol check",
                                                               "object-blaming-info"),
@@ -218,7 +219,7 @@ assign_store (GschemFindTextState *state, GSList *objects, gboolean filter_text)
       continue;
     }
 
-    s_object_weak_ref (object, (NotifyFunc) object_weakref_cb, state);
+    lepton_object_weak_ref (object, (NotifyFunc) object_weakref_cb, state);
 
     gtk_list_store_append (state->store, &tree_iter);
 
@@ -311,9 +312,9 @@ clear_store (GschemFindTextState *state)
                               &value);
 
     if (G_VALUE_HOLDS_POINTER (&value)) {
-      OBJECT *object = (OBJECT*) g_value_get_pointer (&value);
+      LeptonObject *object = (LeptonObject*) g_value_get_pointer (&value);
 
-      s_object_weak_unref (object, (NotifyFunc) object_weakref_cb, state);
+      lepton_object_weak_unref (object, (NotifyFunc) object_weakref_cb, state);
     }
 
     g_value_unset (&value);
@@ -347,7 +348,7 @@ find_objects_using_pattern (GSList *pages,
 
   while (page_iter != NULL) {
     const GList *object_iter;
-    PAGE *page = (PAGE*) page_iter->data;
+    LeptonPage *page = (LeptonPage*) page_iter->data;
 
     page_iter = g_slist_next (page_iter);
 
@@ -359,7 +360,7 @@ find_objects_using_pattern (GSList *pages,
     object_iter = s_page_objects (page);
 
     while (object_iter != NULL) {
-      OBJECT *object = (OBJECT*) object_iter->data;
+      LeptonObject *object = (LeptonObject*) object_iter->data;
       const char *str;
 
       object_iter = g_list_next (object_iter);
@@ -369,15 +370,16 @@ find_objects_using_pattern (GSList *pages,
         continue;
       }
 
-      if (object->type != OBJ_TEXT) {
+      if (!lepton_object_is_text (object))
+      {
         continue;
       }
 
-      if (!(o_is_visible (object) || include_hidden)) {
+      if (!(lepton_object_is_visible (object) || include_hidden)) {
         continue;
       }
 
-      str = geda_text_object_get_string (object);
+      str = lepton_text_object_get_string (object);
 
       if (str == NULL) {
         g_warning ("NULL string encountered");
@@ -426,7 +428,7 @@ find_objects_using_regex (GSList *pages,
 
   while (page_iter != NULL) {
     const GList *object_iter;
-    PAGE *page = (PAGE*) page_iter->data;
+    LeptonPage *page = (LeptonPage*) page_iter->data;
 
     page_iter = g_slist_next (page_iter);
 
@@ -438,7 +440,7 @@ find_objects_using_regex (GSList *pages,
     object_iter = s_page_objects (page);
 
     while (object_iter != NULL) {
-      OBJECT *object = (OBJECT*) object_iter->data;
+      LeptonObject *object = (LeptonObject*) object_iter->data;
       const char *str;
 
       object_iter = g_list_next (object_iter);
@@ -448,15 +450,16 @@ find_objects_using_regex (GSList *pages,
         continue;
       }
 
-      if (object->type != OBJ_TEXT) {
+      if (!lepton_object_is_text (object))
+      {
         continue;
       }
 
-      if (!(o_is_visible (object) || include_hidden)) {
+      if (!(lepton_object_is_visible (object) || include_hidden)) {
         continue;
       }
 
-      str = geda_text_object_get_string (object);
+      str = lepton_text_object_get_string (object);
 
       if (str == NULL) {
         g_warning ("NULL string encountered");
@@ -494,7 +497,7 @@ find_objects_using_substring (GSList *pages,
 
   while (page_iter != NULL) {
     const GList *object_iter;
-    PAGE *page = (PAGE*) page_iter->data;
+    LeptonPage *page = (LeptonPage*) page_iter->data;
 
     page_iter = g_slist_next (page_iter);
 
@@ -506,7 +509,7 @@ find_objects_using_substring (GSList *pages,
     object_iter = s_page_objects (page);
 
     while (object_iter != NULL) {
-      OBJECT *object = (OBJECT*) object_iter->data;
+      LeptonObject *object = (LeptonObject*) object_iter->data;
       const char *str;
 
       object_iter = g_list_next (object_iter);
@@ -516,15 +519,16 @@ find_objects_using_substring (GSList *pages,
         continue;
       }
 
-      if (object->type != OBJ_TEXT) {
+      if (!lepton_object_is_text (object))
+      {
         continue;
       }
 
-      if (!(o_is_visible (object) || include_hidden)) {
+      if (!(lepton_object_is_visible (object) || include_hidden)) {
         continue;
       }
 
-      str = geda_text_object_get_string (object);
+      str = lepton_text_object_get_string (object);
 
       if (str == NULL) {
         g_warning ("NULL string encountered");
@@ -581,8 +585,8 @@ scm_to_gslist (SCM list_s)
 static GSList*
 find_objects_using_check (GSList *pages)
 {
-  PAGE *page = (PAGE*) pages->data;
-  TOPLEVEL *toplevel = page->toplevel;
+  LeptonPage *page = (LeptonPage*) pages->data;
+  LeptonToplevel *toplevel = page->toplevel;
   scm_dynwind_begin ((scm_t_dynwind_flags) 0);
   edascm_dynwind_toplevel (toplevel);
   GSList *objects = scm_to_gslist (scm_call_0 (scm_c_public_ref ("schematic symbol check",
@@ -610,7 +614,7 @@ get_pages (GschemToplevel *w_current,
   GHashTable *visit_list = g_hash_table_new (NULL, NULL);
 
   while (input_list != NULL) {
-    PAGE *page = (PAGE*) input_list->data;
+    LeptonPage *page = (LeptonPage*) input_list->data;
 
     input_list = g_list_delete_link (input_list, input_list);
 
@@ -668,7 +672,7 @@ get_property (GObject *object, guint param_id, GValue *value, GParamSpec *pspec)
  */
 static GList*
 get_subpages (GschemToplevel *w_current,
-              PAGE *page)
+              LeptonPage *page)
 {
   const GList *object_iter;
   GList *page_list = NULL;
@@ -681,7 +685,7 @@ get_subpages (GschemToplevel *w_current,
     char *attrib;
     char **filenames;
     char **iter;
-    OBJECT *object = (OBJECT*) object_iter->data;
+    LeptonObject *object = (LeptonObject*) object_iter->data;
 
     object_iter = g_list_next (object_iter);
 
@@ -690,7 +694,8 @@ get_subpages (GschemToplevel *w_current,
       continue;
     }
 
-    if (object->type != OBJ_COMPONENT) {
+    if (!lepton_object_is_component (object))
+    {
       continue;
     }
 
@@ -715,7 +720,7 @@ get_subpages (GschemToplevel *w_current,
     }
 
     for (iter = filenames; *iter != NULL; iter++) {
-      PAGE *subpage = s_hierarchy_load_subpage (w_current, page, *iter, NULL);
+      LeptonPage *subpage = s_hierarchy_load_subpage (w_current, page, *iter, NULL);
 
       if (subpage != NULL) {
         page_list = g_list_prepend (page_list, subpage);
@@ -797,7 +802,7 @@ gschem_find_text_state_init (GschemFindTextState *state)
  *  \param [in] state
  */
 static void
-object_weakref_cb (OBJECT *object, GschemFindTextState *state)
+object_weakref_cb (LeptonObject *object, GschemFindTextState *state)
 {
   g_return_if_fail (state != NULL);
 
@@ -817,7 +822,7 @@ object_weakref_cb (OBJECT *object, GschemFindTextState *state)
  *  \param [in] object the object to remove from the store
  */
 static void
-remove_object (GschemFindTextState *state, OBJECT *object)
+remove_object (GschemFindTextState *state, LeptonObject *object)
 {
   GtkTreeIter iter;
   gboolean valid;
@@ -837,7 +842,7 @@ remove_object (GschemFindTextState *state, OBJECT *object)
                               &value);
 
     if (G_VALUE_HOLDS_POINTER (&value)) {
-      OBJECT *other = (OBJECT*) g_value_get_pointer (&value);
+      LeptonObject *other = (LeptonObject*) g_value_get_pointer (&value);
 
       if (object == other) {
         g_value_unset (&value);
@@ -877,7 +882,7 @@ select_cb (GtkTreeSelection *selection, GschemFindTextState *state)
                               &value);
 
     if (G_VALUE_HOLDS_POINTER (&value)) {
-      OBJECT *object = (OBJECT*) g_value_get_pointer (&value);
+      LeptonObject *object = (LeptonObject*) g_value_get_pointer (&value);
 
       if (object != NULL) {
         g_signal_emit_by_name (state, "select-object", object);
