@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,14 +27,14 @@
 #define GET_BOX_WIDTH(w)  abs((w)->second_wx - (w)->first_wx)
 #define GET_BOX_HEIGHT(w) abs((w)->second_wy - (w)->first_wy)
 
-#define GET_PICTURE_WIDTH(w)			\
+#define GET_PICTURE_WIDTH(w)                    \
   abs((w)->second_wx - (w)->first_wx)
-#define GET_PICTURE_HEIGHT(w)						\
+#define GET_PICTURE_HEIGHT(w)                                           \
   (w)->pixbuf_wh_ratio == 0 ? 0 : abs((w)->second_wx - (w)->first_wx)/(w)->pixbuf_wh_ratio
-#define GET_PICTURE_LEFT(w)			\
+#define GET_PICTURE_LEFT(w)                     \
   MIN((w)->first_wx, (w)->second_wx)
-#define GET_PICTURE_TOP(w)						\
-  (w)->first_wy > (w)->second_wy ? (w)->first_wy  :			\
+#define GET_PICTURE_TOP(w)                                              \
+  (w)->first_wy > (w)->second_wy ? (w)->first_wy  :                     \
   (w)->first_wy+abs((w)->second_wx - (w)->first_wx)/(w)->pixbuf_wh_ratio
 
 
@@ -58,12 +58,12 @@
  *  \param [in]  x          Current x coordinate of pointer in world units.
  *  \param [in]  y          Current y coordinate of pointer in world units.
  *  \param [out] whichone   Which grip point is selected.
- *  \return Pointer to OBJECT the grip is on, NULL otherwise.
+ *  \return Pointer to LeptonObject the grip is on, NULL otherwise.
  */
-OBJECT *o_grips_search_world(GschemToplevel *w_current, int x, int y, int *whichone)
+LeptonObject *o_grips_search_world(GschemToplevel *w_current, int x, int y, int *whichone)
 {
-  OBJECT *object=NULL;
-  OBJECT *found=NULL;
+  LeptonObject *object=NULL;
+  LeptonObject *found=NULL;
   GList *s_current;
   int size;
   int w_size;
@@ -71,7 +71,7 @@ OBJECT *o_grips_search_world(GschemToplevel *w_current, int x, int y, int *which
   GschemPageView *page_view = gschem_toplevel_get_current_page_view (w_current);
   g_return_val_if_fail (page_view != NULL, NULL);
 
-  TOPLEVEL *toplevel = gschem_toplevel_get_toplevel (w_current);
+  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
   g_return_val_if_fail (toplevel != NULL, NULL);
 
 
@@ -83,11 +83,11 @@ OBJECT *o_grips_search_world(GschemToplevel *w_current, int x, int y, int *which
   size = GRIP_SIZE / 2;
   w_size = gschem_page_view_WORLDabs (page_view, size);
 
-  s_current = geda_list_get_glist( toplevel->page_current->selection_list );
+  s_current = lepton_list_get_glist( toplevel->page_current->selection_list );
   while (s_current != NULL) {
-    object = (OBJECT *) s_current->data;
+    object = (LeptonObject *) s_current->data;
     if (object) {
-      switch(object->type) {
+      switch (lepton_object_get_type (object)) {
         case(OBJ_ARC):
           /* check the grips of the arc object */
           found = o_grips_search_arc_world(w_current, object,
@@ -198,24 +198,24 @@ static gboolean inside_grip( int x, int y, int grip_x, int grip_y, int size )
  *  representing a grip in world units.
  *
  *  \param [in]  w_current  The GschemToplevel object.
- *  \param [in]  o_current  Arc OBJECT to check.
+ *  \param [in]  o_current  Arc LeptonObject to check.
  *  \param [in]  x          Current x coordinate of pointer in world units.
  *  \param [in]  y          Current y coordinate of pointer in world units.
  *  \param [in]  size       Half the width of the grip square in world units.
  *  \param [out] whichone   Which grip point is selected.
- *  \return Pointer to OBJECT the grip is on, NULL otherwise.
+ *  \return Pointer to LeptonObject the grip is on, NULL otherwise.
  */
-OBJECT *o_grips_search_arc_world(GschemToplevel *w_current, OBJECT *o_current,
+LeptonObject *o_grips_search_arc_world(GschemToplevel *w_current, LeptonObject *o_current,
                                  int x, int y, int size, int *whichone)
 {
   int centerx, centery, radius, start_angle, sweep_angle;
   double tmp;
 
-  centerx     = geda_arc_object_get_center_x (o_current);
-  centery     = geda_arc_object_get_center_y (o_current);
-  radius      = geda_arc_object_get_radius (o_current);
-  start_angle = geda_arc_object_get_start_angle (o_current);
-  sweep_angle = geda_arc_object_get_sweep_angle (o_current);
+  centerx     = lepton_arc_object_get_center_x (o_current);
+  centery     = lepton_arc_object_get_center_y (o_current);
+  radius      = lepton_arc_object_get_radius (o_current);
+  start_angle = lepton_arc_object_get_start_angle (o_current);
+  sweep_angle = lepton_arc_object_get_sweep_angle (o_current);
 
   /* check the grip on the center of the arc */
   if (inside_grip(x, y, centerx, centery, size)) {
@@ -263,14 +263,14 @@ OBJECT *o_grips_search_arc_world(GschemToplevel *w_current, OBJECT *o_current,
  *  the square representing a grip in world units.
  *
  *  \param [in]  w_current  The GschemToplevel object.
- *  \param [in]  o_current  Box OBJECT to check.
+ *  \param [in]  o_current  Box LeptonObject to check.
  *  \param [in]  x          Current x coordinate of pointer in world units.
  *  \param [in]  y          Current y coordinate of pointer in world units.
  *  \param [in]  size       Half the width of the grip square in world units.
  *  \param [out] whichone   Which grip point is selected.
- *  \return Pointer to OBJECT the grip is on, NULL otherwise.
+ *  \return Pointer to LeptonObject the grip is on, NULL otherwise.
  */
-OBJECT *o_grips_search_box_world(GschemToplevel *w_current, OBJECT *o_current,
+LeptonObject *o_grips_search_box_world(GschemToplevel *w_current, LeptonObject *o_current,
                                  int x, int y, int size, int *whichone)
 {
   /* inside upper left grip ? */
@@ -328,17 +328,17 @@ OBJECT *o_grips_search_box_world(GschemToplevel *w_current, OBJECT *o_current,
  *  square representing a grip in world units.
  *
  *  \param [in]  w_current  The GschemToplevel object.
- *  \param [in]  o_current  Picture OBJECT to check.
+ *  \param [in]  o_current  Picture LeptonObject to check.
  *  \param [in]  x          Current x coordinate of pointer in world units.
  *  \param [in]  y          Current y coordinate of pointer in world units.
  *  \param [in]  size       Half the width of the grip square in world units.
  *  \param [out] whichone   Which grip point is selected.
- *  \return Pointer to OBJECT the grip is on, NULL otherwise.
+ *  \return Pointer to LeptonObject the grip is on, NULL otherwise.
  */
-OBJECT *o_grips_search_path_world(GschemToplevel *w_current, OBJECT *o_current,
+LeptonObject *o_grips_search_path_world(GschemToplevel *w_current, LeptonObject *o_current,
                                      int x, int y, int size, int *whichone)
 {
-  PATH_SECTION *section;
+  LeptonPathSection *section;
   int i;
   int grip_no = 0;
 
@@ -398,44 +398,47 @@ OBJECT *o_grips_search_path_world(GschemToplevel *w_current, OBJECT *o_current,
  *  square representing a grip in world units.
  *
  *  \param [in]  w_current  The GschemToplevel object.
- *  \param [in]  o_current  Picture OBJECT to check.
+ *  \param [in]  o_current  Picture LeptonObject to check.
  *  \param [in]  x          Current x coordinate of pointer in world units.
  *  \param [in]  y          Current y coordinate of pointer in world units.
  *  \param [in]  size       Half the width of the grip square in world units.
  *  \param [out] whichone   Which grip point is selected.
- *  \return Pointer to OBJECT the grip is on, NULL otherwise.
+ *  \return Pointer to LeptonObject the grip is on, NULL otherwise.
  */
-OBJECT *o_grips_search_picture_world(GschemToplevel *w_current, OBJECT *o_current,
+LeptonObject *o_grips_search_picture_world(GschemToplevel *w_current, LeptonObject *o_current,
                                      int x, int y, int size, int *whichone)
 {
+  int lower_x, lower_y, upper_x, upper_y;
+
+  lower_x = lepton_picture_object_get_lower_x (o_current);
+  lower_y = lepton_picture_object_get_lower_y (o_current);
+  upper_x = lepton_picture_object_get_upper_x (o_current);
+  upper_y = lepton_picture_object_get_upper_y (o_current);
+
   /* inside upper left grip ? */
-  if (inside_grip(x, y,
-                  o_current->picture->upper_x,
-                  o_current->picture->upper_y, size)) {
+  if (inside_grip (x, y, upper_x, upper_y, size))
+  {
     *whichone = PICTURE_UPPER_LEFT;
     return(o_current);
   }
 
   /* inside lower right grip ? */
-  if (inside_grip(x, y,
-                  o_current->picture->lower_x,
-                  o_current->picture->lower_y, size)) {
+  if (inside_grip (x, y, lower_x, lower_y, size))
+  {
     *whichone = PICTURE_LOWER_RIGHT;
     return(o_current);
   }
 
   /* inside upper right grip ? */
-  if (inside_grip(x, y,
-                  o_current->picture->lower_x,
-                  o_current->picture->upper_y, size)) {
+  if (inside_grip (x, y, lower_x, upper_y, size))
+  {
     *whichone = PICTURE_UPPER_RIGHT;
     return(o_current);
   }
 
   /* inside lower left grip ? */
-  if (inside_grip(x, y,
-                  o_current->picture->upper_x,
-                  o_current->picture->lower_y, size)) {
+  if (inside_grip (x, y, upper_x, lower_y, size))
+  {
     *whichone = PICTURE_LOWER_LEFT;
     return(o_current);
   }
@@ -461,19 +464,19 @@ OBJECT *o_grips_search_picture_world(GschemToplevel *w_current, OBJECT *o_curren
  *  The identifier of this grip is <B>CIRCLE_RADIUS</B>.
  *
  *  \param [in]  w_current  The GschemToplevel object.
- *  \param [in]  o_current  Circle OBJECT to check.
+ *  \param [in]  o_current  Circle LeptonObject to check.
  *  \param [in]  x          Current x coordinate of pointer in world units.
  *  \param [in]  y          Current y coordinate of pointer in world units.
  *  \param [in]  size       Half the width of the grip square in world units.
  *  \param [out] whichone   Which grip point is selected.
- *  \return Pointer to OBJECT the grip is on, NULL otherwise.
+ *  \return Pointer to LeptonObject the grip is on, NULL otherwise.
  */
-OBJECT *o_grips_search_circle_world(GschemToplevel *w_current, OBJECT *o_current,
+LeptonObject *o_grips_search_circle_world(GschemToplevel *w_current, LeptonObject *o_current,
                                     int x, int y, int size, int *whichone)
 {
-  gint center_x = geda_circle_object_get_center_x (o_current);
-  gint center_y = geda_circle_object_get_center_y (o_current);
-  gint radius = geda_circle_object_get_radius (o_current);
+  gint center_x = lepton_circle_object_get_center_x (o_current);
+  gint center_y = lepton_circle_object_get_center_y (o_current);
+  gint radius = lepton_circle_object_get_radius (o_current);
 
   /* check the grip for radius */
   if (inside_grip(x, y,
@@ -500,14 +503,14 @@ OBJECT *o_grips_search_circle_world(GschemToplevel *w_current, OBJECT *o_current
  *  The parameter <B>size</B> is half the size of the grip in world units.
  *
  *  \param [in]  w_current  The GschemToplevel object.
- *  \param [in]  o_current  Line OBJECT to check.
+ *  \param [in]  o_current  Line LeptonObject to check.
  *  \param [in]  x          Current x coordinate of pointer in world units.
  *  \param [in]  y          Current y coordinate of pointer in world units.
  *  \param [in]  size       Half the width of the grip square in world units.
  *  \param [out] whichone   Which grip point is selected.
- *  \return Pointer to OBJECT the grip is on, NULL otherwise.
+ *  \return Pointer to LeptonObject the grip is on, NULL otherwise.
  */
-OBJECT *o_grips_search_line_world(GschemToplevel *w_current, OBJECT *o_current,
+LeptonObject *o_grips_search_line_world(GschemToplevel *w_current, LeptonObject *o_current,
                                   int x, int y, int size, int *whichone)
 {
   /* check the grip on the end of line 1 */
@@ -549,25 +552,25 @@ OBJECT *o_grips_search_line_world(GschemToplevel *w_current, OBJECT *o_current,
  *  These angles are expressed in degrees.
  *
  *  \param [in]  w_current  The GschemToplevel object.
- *  \param [in]  o_current  Arc OBJECT to check.
+ *  \param [in]  o_current  Arc LeptonObject to check.
  *  \param [in]  x          (unused)
  *  \param [in]  y          (unused)
  *  \param [out] whichone   (unused)
  */
-static void o_grips_start_arc(GschemToplevel *w_current, OBJECT *o_current,
+static void o_grips_start_arc(GschemToplevel *w_current, LeptonObject *o_current,
                               int x, int y, int whichone)
 {
   w_current->last_drawb_mode = LAST_DRAWB_MODE_NONE;
 
   /* describe the arc with GschemToplevel variables */
   /* center */
-  w_current->first_wx = geda_arc_object_get_center_x (o_current);
-  w_current->first_wy = geda_arc_object_get_center_y (o_current);
+  w_current->first_wx = lepton_arc_object_get_center_x (o_current);
+  w_current->first_wy = lepton_arc_object_get_center_y (o_current);
   /* radius */
-  w_current->distance = geda_arc_object_get_radius (o_current);
+  w_current->distance = lepton_arc_object_get_radius (o_current);
   /* angles */
-  w_current->second_wx = geda_arc_object_get_start_angle (o_current);
-  w_current->second_wy = geda_arc_object_get_sweep_angle (o_current);
+  w_current->second_wx = lepton_arc_object_get_start_angle (o_current);
+  w_current->second_wy = lepton_arc_object_get_sweep_angle (o_current);
 
   /* draw the first temporary arc */
   /* o_arc_invalidate_rubber (w_current); */
@@ -590,12 +593,12 @@ static void o_grips_start_arc(GschemToplevel *w_current, OBJECT *o_current,
  *  to change during the action.
  *
  *  \param [in]  w_current  The GschemToplevel object.
- *  \param [in]  o_current  Box OBJECT to check.
+ *  \param [in]  o_current  Box LeptonObject to check.
  *  \param [in]  x          (unused)
  *  \param [in]  y          (unused)
  *  \param [out] whichone   Which coordinate to check.
  */
-static void o_grips_start_box(GschemToplevel *w_current, OBJECT *o_current,
+static void o_grips_start_box(GschemToplevel *w_current, LeptonObject *o_current,
                               int x, int y, int whichone)
 {
   w_current->last_drawb_mode = LAST_DRAWB_MODE_NONE;
@@ -653,15 +656,15 @@ static void o_grips_start_box(GschemToplevel *w_current, OBJECT *o_current,
  *  suppose to change during the action.
  *
  *  \param [in]  w_current  The GschemToplevel object.
- *  \param [in]  o_current  Picture OBJECT to check.
+ *  \param [in]  o_current  Picture LeptonObject to check.
  *  \param [in]  x          (unused)
  *  \param [in]  y          (unused)
  *  \param [out] whichone   Which coordinate to check.
  */
-static void o_grips_start_path(GschemToplevel *w_current, OBJECT *o_current,
+static void o_grips_start_path(GschemToplevel *w_current, LeptonObject *o_current,
                                int x, int y, int whichone)
 {
-  PATH_SECTION *section;
+  LeptonPathSection *section;
   int i;
   int grip_no = 0;
   int gx = -1;
@@ -723,47 +726,54 @@ static void o_grips_start_path(GschemToplevel *w_current, OBJECT *o_current,
  *  suppose to change during the action.
  *
  *  \param [in]  w_current  The GschemToplevel object.
- *  \param [in]  o_current  Picture OBJECT to check.
+ *  \param [in]  o_current  Picture LeptonObject to check.
  *  \param [in]  x          (unused)
  *  \param [in]  y          (unused)
  *  \param [out] whichone   Which coordinate to check.
  */
-static void o_grips_start_picture(GschemToplevel *w_current, OBJECT *o_current,
+static void o_grips_start_picture(GschemToplevel *w_current, LeptonObject *o_current,
                                   int x, int y, int whichone)
 {
+  int lower_x, lower_y, upper_x, upper_y;
+
+  lower_x = lepton_picture_object_get_lower_x (o_current);
+  lower_y = lepton_picture_object_get_lower_y (o_current);
+  upper_x = lepton_picture_object_get_upper_x (o_current);
+  upper_y = lepton_picture_object_get_upper_y (o_current);
+
   w_current->last_drawb_mode = LAST_DRAWB_MODE_NONE;
 
-  w_current->current_pixbuf = o_picture_get_pixbuf (o_current);
+  w_current->current_pixbuf = lepton_picture_object_get_pixbuf (o_current);
   w_current->pixbuf_filename =
-    g_strdup (o_picture_get_filename (o_current));
-  w_current->pixbuf_wh_ratio = o_picture_get_ratio (o_current);
+    g_strdup (lepton_picture_object_get_filename (o_current));
+  w_current->pixbuf_wh_ratio = lepton_picture_object_get_real_ratio (o_current);
 
   /* (second_wx,second_wy) is the selected corner */
   /* (first_wx, first_wy) is the opposite corner */
   switch(whichone) {
     case PICTURE_UPPER_LEFT:
-      w_current->second_wx = o_current->picture->upper_x;
-      w_current->second_wy = o_current->picture->upper_y;
-      w_current->first_wx = o_current->picture->lower_x;
-      w_current->first_wy = o_current->picture->lower_y;
+      w_current->second_wx = upper_x;
+      w_current->second_wy = upper_y;
+      w_current->first_wx  = lower_x;
+      w_current->first_wy  = lower_y;
       break;
     case PICTURE_LOWER_RIGHT:
-      w_current->second_wx = o_current->picture->lower_x;
-      w_current->second_wy = o_current->picture->lower_y;
-      w_current->first_wx = o_current->picture->upper_x;
-      w_current->first_wy = o_current->picture->upper_y;
+      w_current->second_wx = lower_x;
+      w_current->second_wy = lower_y;
+      w_current->first_wx  = upper_x;
+      w_current->first_wy  = upper_y;
       break;
     case PICTURE_UPPER_RIGHT:
-      w_current->second_wx = o_current->picture->lower_x;
-      w_current->second_wy = o_current->picture->upper_y;
-      w_current->first_wx = o_current->picture->upper_x;
-      w_current->first_wy = o_current->picture->lower_y;
+      w_current->second_wx = lower_x;
+      w_current->second_wy = upper_y;
+      w_current->first_wx  = upper_x;
+      w_current->first_wy  = lower_y;
       break;
     case PICTURE_LOWER_LEFT:
-      w_current->second_wx = o_current->picture->upper_x;
-      w_current->second_wy = o_current->picture->lower_y;
-      w_current->first_wx = o_current->picture->lower_x;
-      w_current->first_wy = o_current->picture->upper_y;
+      w_current->second_wx = upper_x;
+      w_current->second_wy = lower_y;
+      w_current->first_wx  = lower_x;
+      w_current->first_wy  = upper_y;
       break;
     default:
       return; /* error */
@@ -790,21 +800,21 @@ static void o_grips_start_picture(GschemToplevel *w_current, OBJECT *o_current,
  *  The radius of the circle is stored in <B>w_current->distance</B>.
  *
  *  \param [in]  w_current  The GschemToplevel object.
- *  \param [in]  o_current  Circle OBJECT to check.
+ *  \param [in]  o_current  Circle LeptonObject to check.
  *  \param [in]  x          (unused)
  *  \param [in]  y          (unused)
  *  \param [out] whichone   Which coordinate to check.
  */
-static void o_grips_start_circle(GschemToplevel *w_current, OBJECT *o_current,
+static void o_grips_start_circle(GschemToplevel *w_current, LeptonObject *o_current,
                                  int x, int y, int whichone)
 {
 
   w_current->last_drawb_mode = LAST_DRAWB_MODE_NONE;
 
   /* store circle center and radius in GschemToplevel structure */
-  w_current->first_wx = geda_circle_object_get_center_x (o_current);
-  w_current->first_wy = geda_circle_object_get_center_y (o_current);
-  w_current->distance = geda_circle_object_get_radius (o_current);
+  w_current->first_wx = lepton_circle_object_get_center_x (o_current);
+  w_current->first_wy = lepton_circle_object_get_center_y (o_current);
+  w_current->distance = lepton_circle_object_get_radius (o_current);
 
   /* draw the first temporary circle */
   /* o_circle_invalidate_rubber (w_current); */
@@ -823,12 +833,12 @@ static void o_grips_start_circle(GschemToplevel *w_current, OBJECT *o_current,
  *  (<B>w_current->second_wx</B>,<B>w_current->second_wy</B>).
  *
  *  \param [in]  w_current  The GschemToplevel object.
- *  \param [in]  o_current  Line OBJECT to check.
+ *  \param [in]  o_current  Line LeptonObject to check.
  *  \param [in]  x          (unused)
  *  \param [in]  y          (unused)
  *  \param [out] whichone   Which coordinate to check.
  */
-static void o_grips_start_line(GschemToplevel *w_current, OBJECT *o_current,
+static void o_grips_start_line(GschemToplevel *w_current, LeptonObject *o_current,
                                int x, int y, int whichone)
 {
   w_current->last_drawb_mode = LAST_DRAWB_MODE_NONE;
@@ -869,9 +879,9 @@ static void o_grips_start_line(GschemToplevel *w_current, OBJECT *o_current,
  */
 void o_grips_start(GschemToplevel *w_current, int w_x, int w_y)
 {
-  OBJECT *object;
+  LeptonObject *object;
   int whichone;
-  void (*func) (GschemToplevel*, OBJECT*, int, int, int) = NULL;
+  void (*func) (GschemToplevel*, LeptonObject*, int, int, int) = NULL;
 
   /* search if there is a grip on a selected object at (w_x,w_y) */
   object = o_grips_search_world(w_current, w_x, w_y, &whichone);
@@ -886,7 +896,7 @@ void o_grips_start(GschemToplevel *w_current, int w_x, int w_y)
 
     /* there is one */
     /* depending on its type, start the modification process */
-    switch (object->type) {
+    switch (lepton_object_get_type (object)) {
     case OBJ_ARC:     func = o_grips_start_arc;     break;
     case OBJ_BOX:     func = o_grips_start_box;     break;
     case OBJ_PATH:    func = o_grips_start_path;    break;
@@ -933,7 +943,7 @@ void o_grips_motion(GschemToplevel *w_current, int w_x, int w_y)
   g_assert( w_current->inside_action != 0 );
   g_return_if_fail( w_current->which_object != NULL );
 
-  switch(w_current->which_object->type) {
+  switch (lepton_object_get_type (w_current->which_object)) {
     case OBJ_ARC:
       o_arc_motion (w_current, w_x, w_y, grip);
       break;
@@ -978,7 +988,7 @@ void o_grips_motion(GschemToplevel *w_current, int w_x, int w_y)
  */
 void o_grips_cancel(GschemToplevel *w_current)
 {
-  OBJECT *object = w_current->which_object;
+  LeptonObject *object = w_current->which_object;
 
   /* reset global variables */
   w_current->which_grip = -1;
@@ -1002,17 +1012,17 @@ void o_grips_cancel(GschemToplevel *w_current)
  *  If the grip at the center of the arc has been moved - modifying the radius
  *  of the arc -, the new radius is calculated expressed in world unit
  *  (the center is unchanged). It is updated with the function
- *  #geda_arc_object_modify().
+ *  #lepton_arc_object_modify().
  *
  *  If one of the end of arc grip has been moved - modifying one of the
  *  angles describing the arc -, this angle is updated with the
- *  #geda_arc_object_modify() function.
+ *  #lepton_arc_object_modify() function.
  *
  *  \param [in] w_current  The GschemToplevel object.
- *  \param [in] o_current  Arc OBJECT to end modification on.
+ *  \param [in] o_current  Arc LeptonObject to end modification on.
  *  \param [in] whichone   Which grip is pointed to.
  */
-static void o_grips_end_arc(GschemToplevel *w_current, OBJECT *o_current,
+static void o_grips_end_arc(GschemToplevel *w_current, LeptonObject *o_current,
                             int whichone)
 {
   int arg1, arg2;
@@ -1048,7 +1058,7 @@ static void o_grips_end_arc(GschemToplevel *w_current, OBJECT *o_current,
   }
 
   /* modify the arc with the parameters determined above */
-  geda_arc_object_modify (o_current, arg1, arg2, whichone);
+  lepton_arc_object_modify (o_current, arg1, arg2, whichone);
 }
 
 /*! \todo Finish function documentation!!!
@@ -1056,10 +1066,10 @@ static void o_grips_end_arc(GschemToplevel *w_current, OBJECT *o_current,
  *  \par Function Description
  *
  *  \param [in] w_current  The GschemToplevel object.
- *  \param [in] o_current  Box OBJECT to end modification on.
+ *  \param [in] o_current  Box LeptonObject to end modification on.
  *  \param [in] whichone   Which grip is pointed to.
  */
-static void o_grips_end_box(GschemToplevel *w_current, OBJECT *o_current,
+static void o_grips_end_box(GschemToplevel *w_current, LeptonObject *o_current,
                             int whichone)
 {
   int box_width, box_height;
@@ -1076,7 +1086,7 @@ static void o_grips_end_box(GschemToplevel *w_current, OBJECT *o_current,
     return;
   }
 
-  geda_box_object_modify (o_current, w_current->second_wx, w_current->second_wy, whichone);
+  lepton_box_object_modify (o_current, w_current->second_wx, w_current->second_wy, whichone);
 }
 
 /*! \todo Finish function documentation!!!
@@ -1084,16 +1094,16 @@ static void o_grips_end_box(GschemToplevel *w_current, OBJECT *o_current,
  *  \par Function Description
  *
  *  \param [in] w_current  The GschemToplevel object.
- *  \param [in] o_current  Picture OBJECT to end modification on.
+ *  \param [in] o_current  Picture LeptonObject to end modification on.
  *  \param [in] whichone   Which grip is pointed to.
  */
-static void o_grips_end_path(GschemToplevel *w_current, OBJECT *o_current,
+static void o_grips_end_path(GschemToplevel *w_current, LeptonObject *o_current,
                              int whichone)
 {
-  geda_path_object_modify (o_current,
-                           w_current->second_wx,
-                           w_current->second_wy,
-                           whichone);
+  lepton_path_object_modify (o_current,
+                             w_current->second_wx,
+                             w_current->second_wy,
+                             whichone);
 }
 
 /*! \todo Finish function documentation!!!
@@ -1101,10 +1111,10 @@ static void o_grips_end_path(GschemToplevel *w_current, OBJECT *o_current,
  *  \par Function Description
  *
  *  \param [in] w_current  The GschemToplevel object.
- *  \param [in] o_current  Picture OBJECT to end modification on.
+ *  \param [in] o_current  Picture LeptonObject to end modification on.
  *  \param [in] whichone   Which grip is pointed to.
  */
-static void o_grips_end_picture(GschemToplevel *w_current, OBJECT *o_current,
+static void o_grips_end_picture(GschemToplevel *w_current, LeptonObject *o_current,
                                 int whichone)
 {
   /* don't allow zero width/height pictures
@@ -1116,8 +1126,10 @@ static void o_grips_end_picture(GschemToplevel *w_current, OBJECT *o_current,
     return;
   }
 
-  o_picture_modify (o_current,
-                    w_current->second_wx, w_current->second_wy, whichone);
+  lepton_picture_object_modify (o_current,
+                                w_current->second_wx,
+                                w_current->second_wy,
+                                whichone);
 
   g_object_unref (w_current->current_pixbuf);
   w_current->current_pixbuf = NULL;
@@ -1138,10 +1150,10 @@ static void o_grips_end_picture(GschemToplevel *w_current, OBJECT *o_current,
  *  The last value of the radius is in <B>w_current->distance</B> in screen units.
  *
  *  \param [in] w_current  The GschemToplevel object.
- *  \param [in] o_current  Circle OBJECT to end modification on.
+ *  \param [in] o_current  Circle LeptonObject to end modification on.
  *  \param [in] whichone   Which grip is pointed to.
  */
-static void o_grips_end_circle(GschemToplevel *w_current, OBJECT *o_current,
+static void o_grips_end_circle(GschemToplevel *w_current, LeptonObject *o_current,
                                int whichone)
 {
   /* don't allow zero radius circles
@@ -1154,7 +1166,7 @@ static void o_grips_end_circle(GschemToplevel *w_current, OBJECT *o_current,
   }
 
   /* modify the radius of the circle */
-  geda_circle_object_modify (o_current, w_current->distance, -1, CIRCLE_RADIUS);
+  lepton_circle_object_modify (o_current, w_current->distance, -1, CIRCLE_RADIUS);
 }
 
 /*! \brief End process of modifying line object with grip.
@@ -1170,10 +1182,10 @@ static void o_grips_end_circle(GschemToplevel *w_current, OBJECT *o_current,
  *  allowed. In this case, the process is stopped and the line unchanged.
  *
  *  \param [in] w_current  The GschemToplevel object.
- *  \param [in] o_current  Line OBJECT to end modification on.
+ *  \param [in] o_current  Line LeptonObject to end modification on.
  *  \param [in] whichone   Which grip is pointed to.
  */
-static void o_grips_end_line(GschemToplevel *w_current, OBJECT *o_current,
+static void o_grips_end_line(GschemToplevel *w_current, LeptonObject *o_current,
                              int whichone)
 {
   /* don't allow zero length nets / lines / pins
@@ -1187,8 +1199,8 @@ static void o_grips_end_line(GschemToplevel *w_current, OBJECT *o_current,
   }
 
   /* modify the right line end according to whichone */
-  geda_line_object_modify (o_current,
-                           w_current->second_wx, w_current->second_wy, whichone);
+  lepton_line_object_modify (o_current,
+                             w_current->second_wx, w_current->second_wy, whichone);
 }
 
 
@@ -1205,10 +1217,10 @@ static void o_grips_end_line(GschemToplevel *w_current, OBJECT *o_current,
  *  allowed. In this case, the process is stopped and the line unchanged.
  *
  *  \param [in] w_current  The GschemToplevel object.
- *  \param [in] o_current  Net OBJECT to end modification on.
+ *  \param [in] o_current  Net LeptonObject to end modification on.
  *  \param [in] whichone   Which grip is pointed to.
  */
-static void o_grips_end_net(GschemToplevel *w_current, OBJECT *o_current,
+static void o_grips_end_net(GschemToplevel *w_current, LeptonObject *o_current,
                             int whichone)
 {
   GList *connected_objects;
@@ -1223,8 +1235,8 @@ static void o_grips_end_net(GschemToplevel *w_current, OBJECT *o_current,
   }
 
   s_conn_remove_object_connections (o_current);
-  geda_net_object_modify (o_current, w_current->second_wx,
-                          w_current->second_wy, w_current->which_grip);
+  lepton_net_object_modify (o_current, w_current->second_wx,
+                            w_current->second_wy, w_current->which_grip);
   s_conn_update_object (o_current->page, o_current);
 
   /* add bus rippers if necessary */
@@ -1246,10 +1258,10 @@ static void o_grips_end_net(GschemToplevel *w_current, OBJECT *o_current,
  *  allowed. In this case, the process is stopped and the line unchanged.
  *
  *  \param [in] w_current  The GschemToplevel object.
- *  \param [in] o_current  Net OBJECT to end modification on.
+ *  \param [in] o_current  Net LeptonObject to end modification on.
  *  \param [in] whichone   Which grip is pointed to.
  */
-static void o_grips_end_pin(GschemToplevel *w_current, OBJECT *o_current,
+static void o_grips_end_pin(GschemToplevel *w_current, LeptonObject *o_current,
                             int whichone)
 {
   /* don't allow zero length pin
@@ -1262,10 +1274,10 @@ static void o_grips_end_pin(GschemToplevel *w_current, OBJECT *o_current,
   }
 
   s_conn_remove_object_connections (o_current);
-  geda_pin_object_modify (o_current,
-                          w_current->second_wx,
-                          w_current->second_wy,
-                          w_current->which_grip);
+  lepton_pin_object_modify (o_current,
+                            w_current->second_wx,
+                            w_current->second_wy,
+                            w_current->which_grip);
   s_conn_update_object (o_current->page, o_current);
 }
 
@@ -1282,10 +1294,10 @@ static void o_grips_end_pin(GschemToplevel *w_current, OBJECT *o_current,
  *  allowed. In this case, the process is stopped and the bus unchanged.
  *
  *  \param [in] w_current  The GschemToplevel object.
- *  \param [in] o_current  bus OBJECT to end modification on.
+ *  \param [in] o_current  bus LeptonObject to end modification on.
  *  \param [in] whichone   Which grip is pointed to.
  */
-static void o_grips_end_bus(GschemToplevel *w_current, OBJECT *o_current,
+static void o_grips_end_bus(GschemToplevel *w_current, LeptonObject *o_current,
                             int whichone)
 {
   /* don't allow zero length bus
@@ -1298,8 +1310,8 @@ static void o_grips_end_bus(GschemToplevel *w_current, OBJECT *o_current,
   }
 
   s_conn_remove_object_connections (o_current);
-  geda_bus_object_modify (o_current, w_current->second_wx,
-                          w_current->second_wy, w_current->which_grip);
+  lepton_bus_object_modify (o_current, w_current->second_wx,
+                            w_current->second_wy, w_current->which_grip);
   s_conn_update_object (o_current->page, o_current);
 }
 
@@ -1322,8 +1334,8 @@ static void o_grips_end_bus(GschemToplevel *w_current, OBJECT *o_current,
  */
 void o_grips_end(GschemToplevel *w_current)
 {
-  TOPLEVEL *toplevel = gschem_toplevel_get_toplevel (w_current);
-  OBJECT *object;
+  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
+  LeptonObject *object;
   int grip;
 
   g_assert (w_current->inside_action != 0);
@@ -1338,7 +1350,7 @@ void o_grips_end(GschemToplevel *w_current)
     return;
   }
 
-  switch(object->type) {
+  switch (lepton_object_get_type (object)) {
 
     case(OBJ_ARC):
     /* modify an arc object */
@@ -1418,7 +1430,7 @@ void o_grips_draw_rubber (GschemToplevel *w_current, EdaRenderer *renderer)
 {
   g_return_if_fail (w_current->which_object != NULL);
 
-  switch(w_current->which_object->type) {
+  switch (lepton_object_get_type (w_current->which_object)) {
     case OBJ_ARC:
       o_arc_draw_rubber (w_current, renderer);
       break;
