@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,25 +43,24 @@
  */
 void o_edit(GschemToplevel *w_current, GList *list)
 {
-  OBJECT *o_current;
+  LeptonObject *o_current;
   const gchar *str = NULL;
 
   if (list == NULL) {
     return;
   }
 
-  o_current = (OBJECT *) list->data;
+  o_current = (LeptonObject *) list->data;
   if (o_current == NULL) {
     fprintf (stderr, "o_edit: ERROR: Got an unexpected NULL\n");
     exit(-1);
   }
 
   /* for now deal with only the first item */
-  switch(o_current->type) {
+  switch (lepton_object_get_type (o_current)) {
 
     /* also add the ability to multi attrib edit: nets, busses, pins */
     case(OBJ_COMPONENT):
-    case(OBJ_PLACEHOLDER):
     case(OBJ_NET):
     case(OBJ_PIN):
     case(OBJ_BUS):
@@ -75,7 +74,7 @@ void o_edit(GschemToplevel *w_current, GList *list)
     arc_angle_dialog(w_current, o_current);
     break;
     case(OBJ_TEXT):
-      str = geda_text_object_get_string (o_current);
+      str = lepton_text_object_get_string (o_current);
       if (o_attrib_is_attrib (o_current) &&
         /* attribute editor only accept 1-line values for attribute */
         o_text_num_lines (str) == 1) {
@@ -106,22 +105,22 @@ void o_lock(GschemToplevel *w_current)
   g_return_if_fail (w_current->toplevel != NULL);
   g_return_if_fail (w_current->toplevel->page_current != NULL);
 
-  PAGE*  page = w_current->toplevel->page_current;
-  GList* objs = geda_list_get_glist (page->selection_list);
+  LeptonPage*  page = w_current->toplevel->page_current;
+  GList* objs = lepton_list_get_glist (page->selection_list);
 
   /* lock selected objects:
   */
-  OBJECT* obj = NULL;
+  LeptonObject* obj = NULL;
   for (GList* iter = objs; iter != NULL; iter = g_list_next (iter))
   {
-    obj = (OBJECT*) iter->data;
-    geda_object_set_selectable (obj, FALSE);
+    obj = (LeptonObject*) iter->data;
+    lepton_object_set_selectable (obj, FALSE);
 
     /* for objects with attributes, also lock them:
     */
     if (obj->attribs != NULL)
     {
-      geda_object_list_set_selectable (obj->attribs, FALSE);
+      lepton_object_list_set_selectable (obj->attribs, FALSE);
     }
   }
 
@@ -155,22 +154,22 @@ void o_unlock(GschemToplevel *w_current)
   g_return_if_fail (w_current->toplevel != NULL);
   g_return_if_fail (w_current->toplevel->page_current != NULL);
 
-  PAGE*  page = w_current->toplevel->page_current;
-  GList* objs = geda_list_get_glist (page->selection_list);
+  LeptonPage*  page = w_current->toplevel->page_current;
+  GList* objs = lepton_list_get_glist (page->selection_list);
 
   /* unlock selected objects:
   */
-  OBJECT* obj = NULL;
+  LeptonObject* obj = NULL;
   for (GList* iter = objs; iter != NULL; iter = g_list_next (iter))
   {
-    obj = (OBJECT*) iter->data;
-    geda_object_set_selectable (obj, TRUE);
+    obj = (LeptonObject*) iter->data;
+    lepton_object_set_selectable (obj, TRUE);
 
     /* for objects with attributes, also unlock them:
     */
     if (obj->attribs != NULL)
     {
-      geda_object_list_set_selectable (obj->attribs, TRUE);
+      lepton_object_list_set_selectable (obj->attribs, TRUE);
     }
   }
 
@@ -202,8 +201,8 @@ void o_unlock(GschemToplevel *w_current)
 void o_rotate_world_update(GschemToplevel *w_current,
                            int centerx, int centery, int angle, GList *list)
 {
-  TOPLEVEL *toplevel = gschem_toplevel_get_toplevel (w_current);
-  OBJECT *o_current;
+  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
+  LeptonObject *o_current;
   GList *o_iter;
 
   /* this is okay if you just hit rotate and have nothing selected */
@@ -220,19 +219,19 @@ void o_rotate_world_update(GschemToplevel *w_current,
    * to the selection, not those within in it.
    */
   for (o_iter = list; o_iter != NULL; o_iter = g_list_next (o_iter)) {
-    o_current = (OBJECT*) o_iter->data;
+    o_current = (LeptonObject*) o_iter->data;
 
     s_conn_remove_object_connections (o_current);
   }
 
-  geda_object_list_rotate (list, centerx, centery, angle);
+  lepton_object_list_rotate (list, centerx, centery, angle);
 
   /* Find connected objects, adding each object in turn back to the
    * connection list. We only _really_ want those objects connected
    * to the selection, not those within in it.
    */
   for (o_iter = list; o_iter != NULL; o_iter = g_list_next (o_iter)) {
-    o_current = (OBJECT*) o_iter->data;
+    o_current = (LeptonObject*) o_iter->data;
 
     s_conn_update_object (o_current->page, o_current);
   }
@@ -261,8 +260,8 @@ void o_rotate_world_update(GschemToplevel *w_current,
  */
 void o_mirror_world_update(GschemToplevel *w_current, int centerx, int centery, GList *list)
 {
-  TOPLEVEL *toplevel = gschem_toplevel_get_toplevel (w_current);
-  OBJECT *o_current;
+  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
+  LeptonObject *o_current;
   GList *o_iter;
 
   if (list == NULL) {
@@ -278,19 +277,19 @@ void o_mirror_world_update(GschemToplevel *w_current, int centerx, int centery,
    * to the selection, not those within in it.
    */
   for (o_iter = list; o_iter != NULL; o_iter = g_list_next (o_iter)) {
-    o_current = (OBJECT*) o_iter->data;
+    o_current = (LeptonObject*) o_iter->data;
 
     s_conn_remove_object_connections (o_current);
   }
 
-  geda_object_list_mirror (list, centerx, centery);
+  lepton_object_list_mirror (list, centerx, centery);
 
   /* Find connected objects, adding each object in turn back to the
    * connection list. We only _really_ want those objects connected
    * to the selection, not those within in it.
    */
   for (o_iter = list; o_iter != NULL; o_iter = g_list_next (o_iter)) {
-    o_current = (OBJECT*) o_iter->data;
+    o_current = (LeptonObject*) o_iter->data;
 
     s_conn_update_object (o_current->page, o_current);
   }
@@ -316,19 +315,22 @@ void o_mirror_world_update(GschemToplevel *w_current, int centerx, int centery,
 void o_edit_show_hidden_lowlevel (GschemToplevel *w_current,
                                   const GList *o_list)
 {
-  OBJECT *o_current;
+  LeptonObject *o_current;
   const GList *iter;
 
   iter = o_list;
   while (iter != NULL) {
-    o_current = (OBJECT *)iter->data;
-    if (o_current->type == OBJ_TEXT && !o_is_visible (o_current)) {
+    o_current = (LeptonObject *)iter->data;
+    if (lepton_object_is_text (o_current) &&
+        !lepton_object_is_visible (o_current))
+    {
 
       /* don't toggle the visibility flag */
       o_text_recreate (o_current);
     }
 
-    if (o_current->type == OBJ_COMPONENT || o_current->type == OBJ_PLACEHOLDER) {
+    if (lepton_object_is_component (o_current))
+    {
       o_edit_show_hidden_lowlevel(w_current, o_current->component->prim_objs);
     }
 
@@ -372,19 +374,20 @@ void o_edit_hide_specific_text (GschemToplevel *w_current,
                                 const GList *o_list,
                                 const char *stext)
 {
-  TOPLEVEL *toplevel = gschem_toplevel_get_toplevel (w_current);
-  OBJECT *o_current;
+  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
+  LeptonObject *o_current;
   const GList *iter;
 
   iter = o_list;
   while (iter != NULL) {
-    o_current = (OBJECT *)iter->data;
+    o_current = (LeptonObject *)iter->data;
 
-    if (o_current->type == OBJ_TEXT) {
-      const gchar *str = geda_text_object_get_string (o_current);
+    if (lepton_object_is_text (o_current))
+    {
+      const gchar *str = lepton_text_object_get_string (o_current);
       if (!strncmp (stext, str, strlen (stext))) {
-        if (o_is_visible (o_current)) {
-          o_set_visibility (o_current, INVISIBLE);
+        if (lepton_object_is_visible (o_current)) {
+          lepton_object_set_visibility (o_current, INVISIBLE);
           o_text_recreate (o_current);
 
           gschem_toplevel_page_content_changed (w_current, toplevel->page_current);
@@ -406,19 +409,20 @@ void o_edit_show_specific_text (GschemToplevel *w_current,
                                 const GList *o_list,
                                 const char *stext)
 {
-  TOPLEVEL *toplevel = gschem_toplevel_get_toplevel (w_current);
-  OBJECT *o_current;
+  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
+  LeptonObject *o_current;
   const GList *iter;
 
   iter = o_list;
   while (iter != NULL) {
-    o_current = (OBJECT *)iter->data;
+    o_current = (LeptonObject *)iter->data;
 
-    if (o_current->type == OBJ_TEXT) {
-      const gchar *str = geda_text_object_get_string (o_current);
+    if (lepton_object_is_text (o_current))
+    {
+      const gchar *str = lepton_text_object_get_string (o_current);
       if (!strncmp (stext, str, strlen (stext))) {
-        if (!o_is_visible (o_current)) {
-          o_set_visibility (o_current, VISIBLE);
+        if (!lepton_object_is_visible (o_current)) {
+          lepton_object_set_visibility (o_current, VISIBLE);
           o_text_recreate (o_current);
 
           gschem_toplevel_page_content_changed (w_current, toplevel->page_current);
@@ -436,31 +440,30 @@ void o_edit_show_specific_text (GschemToplevel *w_current,
  * \par Function Description
  * Updates \a o_current to the latest version of the symbol available
  * in the symbol library, while preserving any attributes set in the
- * current schematic. On success, returns the new OBJECT which
+ * current schematic. On success, returns the new LeptonObject which
  * replaces \a o_current on the page; \a o_current is deleted. On
  * failure, returns NULL, and \a o_current is left unchanged.
  *
  * \param [in]     w_current The GschemToplevel object.
- * \param [in,out] o_current The OBJECT to be updated.
+ * \param [in,out] o_current The LeptonObject to be updated.
  *
- * \return the new OBJECT that replaces \a o_current.
+ * \return the new LeptonObject that replaces \a o_current.
  */
-OBJECT *
-o_update_component (GschemToplevel *w_current, OBJECT *o_current)
+LeptonObject *
+o_update_component (GschemToplevel *w_current, LeptonObject *o_current)
 {
-  TOPLEVEL *toplevel = gschem_toplevel_get_toplevel (w_current);
-  OBJECT *o_new;
-  PAGE *page;
+  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
+  LeptonObject *o_new;
+  LeptonPage *page;
   GList *new_attribs;
   GList *old_attribs;
   GList *iter;
   const CLibSymbol *clib;
 
-  g_return_val_if_fail (o_current != NULL, NULL);
-  g_return_val_if_fail (o_current->type == OBJ_COMPONENT, NULL);
+  g_return_val_if_fail (lepton_object_is_component (o_current), NULL);
   g_return_val_if_fail (o_current->component_basename != NULL, NULL);
 
-  page = o_get_page (o_current);
+  page = lepton_object_get_page (o_current);
 
   /* Force symbol data to be reloaded from source */
   clib = s_clib_get_symbol_by_name (o_current->component_basename);
@@ -486,31 +489,32 @@ o_update_component (GschemToplevel *w_current, OBJECT *o_current)
                            clib,
                            o_current->component_basename,
                            1);
-  if (o_component_is_embedded (o_current)) {
-    o_embed (o_new);
+  /* Embed new object if the old one is embedded. */
+  if (lepton_component_object_get_embedded (o_current)) {
+    lepton_component_object_embed (o_new);
   }
 
   new_attribs = o_component_promote_attribs (o_new);
 
   /* Cull any attributes from new COMPONENT that are already attached to
    * old COMPONENT. Note that the new_attribs list is kept consistent by
-   * setting GList data pointers to NULL if their OBJECTs are
+   * setting GList data pointers to NULL if their LeptonObjects are
    * culled. At the end, the new_attribs list is updated by removing
    * all list items with NULL data. This is slightly magic, but
    * works. */
   for (iter = new_attribs; iter != NULL; iter = g_list_next (iter)) {
-    OBJECT *attr_new = (OBJECT*) iter->data;
+    LeptonObject *attr_new = (LeptonObject*) iter->data;
     gchar *name;
     gchar *value;
 
-    g_assert (attr_new->type == OBJ_TEXT);
+    g_assert (lepton_object_is_text (attr_new));
 
     o_attrib_get_name_value (attr_new, &name, NULL);
 
     value = o_attrib_search_attached_attribs_by_name (o_current, name, 0);
     if (value != NULL) {
       o_attrib_remove (&o_new->attribs, attr_new);
-      s_delete_object (attr_new);
+      lepton_object_delete (attr_new);
       iter->data = NULL;
     }
 
@@ -519,7 +523,7 @@ o_update_component (GschemToplevel *w_current, OBJECT *o_current)
   }
   new_attribs = g_list_remove_all (new_attribs, NULL);
 
-  /* Detach attributes from old OBJECT and attach to new OBJECT */
+  /* Detach attributes from old LeptonObject and attach to new LeptonObject */
   old_attribs = g_list_copy (o_current->attribs);
   o_attrib_detach_all (o_current);
   o_attrib_attach_list (old_attribs, o_new, 1);
@@ -531,11 +535,11 @@ o_update_component (GschemToplevel *w_current, OBJECT *o_current)
   /* Update pinnumbers for current slot */
   s_slot_update_object (o_new);
 
-  /* Replace old OBJECT with new OBJECT */
+  /* Replace old LeptonObject with new LeptonObject */
   s_page_replace (page, o_current, o_new);
-  s_delete_object (o_current);
+  lepton_object_delete (o_current);
 
-  /* Select new OBJECT */
+  /* Select new LeptonObject */
   o_selection_add (page->selection_list, o_new);
 
   /* mark the page as modified */
@@ -554,9 +558,9 @@ o_update_component (GschemToplevel *w_current, OBJECT *o_current)
  */
 void o_autosave_backups(GschemToplevel *w_current)
 {
-  TOPLEVEL *toplevel = gschem_toplevel_get_toplevel (w_current);
+  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
   GList *iter;
-  PAGE *p_save, *p_current;
+  LeptonPage *p_save, *p_current;
   gchar *backup_filename;
   gchar *real_filename;
   gchar *only_filename;
@@ -568,11 +572,11 @@ void o_autosave_backups(GschemToplevel *w_current)
   /* save current page */
   p_save = toplevel->page_current;
 
-  for ( iter = geda_list_get_glist( toplevel->pages );
+  for ( iter = lepton_list_get_glist( toplevel->pages );
         iter != NULL;
         iter = g_list_next( iter ) ) {
 
-    p_current = (PAGE *)iter->data;
+    p_current = (LeptonPage *)iter->data;
 
     if (p_current->do_autosave_backup == 0) {
       continue;
