@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,22 +28,28 @@
 #define NUM_BEZIER_SEGMENTS 100
 
 
-static PATH *path_copy_modify (PATH *path, int dx, int dy,
-                               int new_x, int new_y, int whichone)
+static LeptonPath*
+path_copy_modify (LeptonPath *path,
+                  int dx,
+                  int dy,
+                  int new_x,
+                  int new_y,
+                  int whichone)
 {
-  PATH *new_path;
+  LeptonPath *new_path;
   int x1, y1, x2, y2, x3, y3;
   int i;
   int grip_no = 0;
 
-  new_path = (PATH*) g_malloc (sizeof (PATH));
-  new_path->sections = (PATH_SECTION*) g_malloc (path->num_sections * sizeof (PATH_SECTION));
+  new_path = (LeptonPath*) g_malloc (sizeof (LeptonPath));
+  new_path->sections =
+    (LeptonPathSection*) g_malloc (path->num_sections * sizeof (LeptonPathSection));
   new_path->num_sections = path->num_sections;
   new_path->num_sections_max = path->num_sections;
 
   for (i = 0; i <  path->num_sections; i++) {
-    PATH_SECTION *section     = &path->sections[i];
-    PATH_SECTION *new_section = &new_path->sections[i];
+    LeptonPathSection *section     = &path->sections[i];
+    LeptonPathSection *new_section = &new_path->sections[i];
 
     x1 = section->x1 + dx; y1 = section->y1 + dy;
     x2 = section->x2 + dx; y2 = section->y2 + dy;
@@ -82,12 +88,16 @@ static PATH *path_copy_modify (PATH *path, int dx, int dy,
  *  \par Function Description
  * Calculate the bounding box of \a path, returning its bounds in \a
  * min_x, \a max_y, \a max_x and \a min_y.  If \a path is NULL, the
- * PATH object currently being edited is used, with any required
+ * LeptonPath object currently being edited is used, with any required
  * control point changes applied.
  */
 static void
-path_rubber_bbox (GschemToplevel *w_current, PATH *path,
-                  int *min_x, int *max_y, int *max_x, int *min_y)
+path_rubber_bbox (GschemToplevel *w_current,
+                  LeptonPath *path,
+                  int *min_x,
+                  int *max_y,
+                  int *max_x,
+                  int *min_y)
 {
   int x1, y1, x2, y2, x3, y3;
   int new_x, new_y, whichone;
@@ -107,7 +117,7 @@ path_rubber_bbox (GschemToplevel *w_current, PATH *path,
   whichone = w_current->which_grip;
 
   for (i = 0; i <  path->num_sections; i++) {
-    PATH_SECTION *section = &path->sections[i];
+    LeptonPathSection *section = &path->sections[i];
 
     x1 = section->x1; y1 = section->y1;
     x2 = section->x2; y2 = section->y2;
@@ -146,19 +156,19 @@ path_rubber_bbox (GschemToplevel *w_current, PATH *path,
  * sections. */
 #define TEMP_PATH_DEFAULT_SIZE 8
 
-/*! \brief Add elements to the temporary PATH.
+/*! \brief Add elements to the temporary LeptonPath.
  * \par Function Description
- * Check if the temporary #PATH object used when interactively
+ * Check if the temporary #LeptonPath object used when interactively
  * creating paths has room for additional sections.  If not, doubles
  * its capacity.
  */
 static void
 path_expand (GschemToplevel *w_current)
 {
-  PATH *p = w_current->temp_path;
+  LeptonPath *p = w_current->temp_path;
   if (p->num_sections == p->num_sections_max) {
     p->num_sections_max *= 2;
-    p->sections = g_renew (PATH_SECTION, p->sections,
+    p->sections = g_renew (LeptonPathSection, p->sections,
                            p->num_sections_max);
   }
 }
@@ -174,7 +184,7 @@ path_expand (GschemToplevel *w_current)
  *     point's control point.
  *   - third_wx and third_wy contain the location of the previous
  *     point's control point.
- *   - temp_path is the new #PATH object (i.e. sequence of path
+ *   - temp_path is the new #LeptonPath object (i.e. sequence of path
  *     sections that comprise the path drawn so far).
  *
  * path_next_sections() adds up to two additional sections to the
@@ -190,8 +200,8 @@ static int
 path_next_sections (GschemToplevel *w_current)
 {
   gboolean cusp_point, cusp_prev, close_path, end_path, start_path;
-  PATH *p;
-  PATH_SECTION *section, *prev_section;
+  LeptonPath *p;
+  LeptonPathSection *section, *prev_section;
   int x1, y1, x2, y2, x3, y3;
   int save_num_sections;
 
@@ -352,8 +362,8 @@ o_path_start(GschemToplevel *w_current, int w_x, int w_y)
   if (w_current->temp_path != NULL) {
     w_current->temp_path->num_sections = 0;
   } else {
-    PATH *p = g_new0 (PATH, 1);
-    p->sections = g_new0 (PATH_SECTION, TEMP_PATH_DEFAULT_SIZE);
+    LeptonPath *p = g_new0 (LeptonPath, 1);
+    p->sections = g_new0 (LeptonPathSection, TEMP_PATH_DEFAULT_SIZE);
     p->num_sections = 0;
     p->num_sections_max = TEMP_PATH_DEFAULT_SIZE;
     w_current->temp_path = p;
@@ -439,8 +449,8 @@ void
 o_path_end(GschemToplevel *w_current, int w_x, int w_y)
 {
   gboolean close_path, end_path, start_path;
-  PATH *p;
-  PATH_SECTION *section, *prev_section;
+  LeptonPath *p;
+  LeptonPathSection *section, *prev_section;
   int x1, y1, x2, y2;
 
   g_assert (w_current);
@@ -451,7 +461,7 @@ o_path_end(GschemToplevel *w_current, int w_x, int w_y)
   GschemPageView *page_view = gschem_toplevel_get_current_page_view (w_current);
   g_return_if_fail (page_view != NULL);
 
-  PAGE *page = gschem_page_view_get_page (page_view);
+  LeptonPage *page = gschem_page_view_get_page (page_view);
   g_return_if_fail (page != NULL);
 
   o_path_invalidate_rubber (w_current);
@@ -489,8 +499,7 @@ o_path_end(GschemToplevel *w_current, int w_x, int w_y)
 
   if (end_path || close_path) {
     /* Add object to page and clean up path drawing state */
-    OBJECT *obj = geda_path_object_new_take_path (OBJ_PATH,
-                                                  GRAPHIC_COLOR, p);
+    LeptonObject *obj = lepton_path_object_new_take_path (GRAPHIC_COLOR, p);
     w_current->temp_path = NULL;
     w_current->first_wx = -1;
     w_current->first_wy = -1;
@@ -527,7 +536,7 @@ o_path_end(GschemToplevel *w_current, int w_x, int w_y)
 void
 o_path_draw_rubber (GschemToplevel *w_current, EdaRenderer *renderer)
 {
-  OBJECT object;
+  LeptonObject object;
   int added_sections = 0;
 
   /* Draw a helper for when we're dragging a control point */
@@ -551,10 +560,10 @@ o_path_draw_rubber (GschemToplevel *w_current, EdaRenderer *renderer)
   added_sections = path_next_sections (w_current);
 
   /* Setup a fake object to pass the drawing routine */
-  memset (&object, 0, sizeof (OBJECT));
-  object.type = OBJ_PATH;
-  object.color = SELECT_COLOR;
-  object.line_width = 0; /* clamped to 1 pixel in circle_path */
+  memset (&object, 0, sizeof (LeptonObject));
+  lepton_object_set_type (&object, OBJ_PATH);
+  lepton_object_set_color (&object, SELECT_COLOR);
+  lepton_object_set_stroke_width (&object, 0); /* clamped to 1 pixel in circle_path */
   object.path = w_current->temp_path;
 
   eda_renderer_draw (renderer, &object);
@@ -622,13 +631,13 @@ void o_path_motion_grips (GschemToplevel *w_current, int w_x, int w_y)
 void
 o_path_draw_rubber_grips (GschemToplevel *w_current, EdaRenderer *renderer)
 {
-  OBJECT object;
+  LeptonObject object;
 
   /* Setup a fake object to pass the drawing routine */
-  memset (&object, 0, sizeof (OBJECT));
-  object.type = OBJ_PATH;
-  object.color = SELECT_COLOR;
-  object.line_width = 0; /* clamped to 1 pixel in circle_path */
+  memset (&object, 0, sizeof (LeptonObject));
+  lepton_object_set_type (&object, OBJ_PATH);
+  lepton_object_set_color (&object, SELECT_COLOR);
+  lepton_object_set_stroke_width (&object, 0); /* clamped to 1 pixel in circle_path */
   object.path = path_copy_modify (w_current->which_object->path, 0, 0,
                                   w_current->second_wx,
                                   w_current->second_wy, w_current->which_grip);
