@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,17 +41,17 @@
  */
 void attrib_edit_dialog_ok(GtkWidget * w, GschemToplevel *w_current)
 {
-  TOPLEVEL *toplevel = gschem_toplevel_get_toplevel (w_current);
+  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
   const char *value, *label;
   char *newtext;
   GtkEntry *value_entry, *name_entry;
   GtkWidget *visbutton, *show_options;
   GtkWidget *addtocompsbutton, *addtonetsbutton, *addtoallbutton;
   GtkWidget *overwritebutton;
-  OBJECT *attribptr;
-  OBJECT *object;
+  LeptonObject *attribptr;
+  LeptonObject *object;
   GList *s_current = NULL;
-  OBJECT *a_current;
+  LeptonObject *a_current;
   GList *a_iter;
   int vis, show;
   int invocation_flag;
@@ -108,23 +108,23 @@ void attrib_edit_dialog_ok(GtkWidget * w, GschemToplevel *w_current)
   }
 
   attribptr =
-    (OBJECT*) g_object_get_data (G_OBJECT (w_current->aewindow), "attrib");
+    (LeptonObject*) g_object_get_data (G_OBJECT (w_current->aewindow), "attrib");
   if (!attribptr) {
-    OBJECT *new_object = NULL;
+    LeptonObject *new_object = NULL;
 
-    s_current = geda_list_get_glist( toplevel->page_current->selection_list );
+    s_current = lepton_list_get_glist( toplevel->page_current->selection_list );
     while (s_current != NULL) {
-      object = (OBJECT *)s_current->data;
+      object = (LeptonObject *)s_current->data;
       if (object == NULL) {
-	fprintf (stderr, "attrib_edit_dialog_ok: ERROR: Got an unexpected NULL\n");
-	exit(-1);
+        fprintf (stderr, "attrib_edit_dialog_ok: ERROR: Got an unexpected NULL\n");
+        exit(-1);
       }
       if (!object->attached_to) {
-	nsel++;
+        nsel++;
       }
       s_current = g_list_next(s_current);
     }
-    s_current = geda_list_get_glist( toplevel->page_current->selection_list );
+    s_current = lepton_list_get_glist( toplevel->page_current->selection_list );
     if (nsel > 1) {
 
       addtoallbutton =
@@ -144,31 +144,35 @@ void attrib_edit_dialog_ok(GtkWidget * w, GschemToplevel *w_current)
                                        "overwritebutton"));
 
       if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(overwritebutton))) {
-	replace = 1;
+        replace = 1;
       } else {
-	replace = 0;
+        replace = 0;
       }
 
       if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(addtoallbutton))) {
-	addto = 7;
+        addto = 7;
       }
       if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(addtocompsbutton))) {
-	addto = 2;
+        addto = 2;
       }
       if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(addtonetsbutton))) {
-	addto = 1;
+        addto = 1;
       }
 
       while (s_current != NULL) {
         gboolean replaced;
 
-        object = (OBJECT *) s_current->data;
-        if (object && !object->attached_to && object->type != OBJ_TEXT ) {
+        object = (LeptonObject *) s_current->data;
+        if (object &&
+            !object->attached_to &&
+            !lepton_object_is_text (object))
+        {
           addmask = 4;
-          if (object->type == OBJ_COMPONENT || object->type == OBJ_PLACEHOLDER) {
+          if (lepton_object_is_component (object))
+          {
             addmask = 2;
           }
-          if (object->type == OBJ_NET) {
+          if (lepton_object_is_net (object)) {
             addmask = 1;
           }
           replaced = FALSE;
@@ -176,8 +180,8 @@ void attrib_edit_dialog_ok(GtkWidget * w, GschemToplevel *w_current)
             a_iter = object->attribs;
             if (replace) {
               while (a_iter != NULL) {
-                a_current = (OBJECT*) a_iter->data;
-                const gchar *str = geda_text_object_get_string (a_current);
+                a_current = (LeptonObject*) a_iter->data;
+                const gchar *str = lepton_text_object_get_string (a_current);
                 if (str) {
                   if (!strncmp (str, newtext, strchr (newtext, '=') - newtext)) {
                     o_text_change(w_current, a_current, newtext, vis, show);
@@ -214,13 +218,13 @@ void attrib_edit_dialog_ok(GtkWidget * w, GschemToplevel *w_current)
       printf("invocation flag: %d\n", invocation_flag);
 #endif
       if (invocation_flag == FROM_HOTKEY
-	  && wx != -1 && wy != -1) {
-	o_invalidate (w_current, new_object);
-	new_object->text->x = wx;
-	new_object->text->y = wy;
-	o_text_recreate (new_object);
+          && wx != -1 && wy != -1) {
+        o_invalidate (w_current, new_object);
+        new_object->text->x = wx;
+        new_object->text->y = wy;
+        o_text_recreate (new_object);
     gschem_toplevel_page_content_changed (w_current, toplevel->page_current);
-	o_undo_savestate_old(w_current, UNDO_ALL);
+        o_undo_savestate_old(w_current, UNDO_ALL);
       }
     }
   } else {
@@ -240,7 +244,7 @@ void attrib_edit_dialog_ok(GtkWidget * w, GschemToplevel *w_current)
  *  attribute dialog.
  */
 void attribute_edit_dialog_response(GtkWidget *w, gint response,
-				 GschemToplevel *w_current)
+                                    GschemToplevel *w_current)
 {
   switch(response) {
   case GTK_RESPONSE_APPLY:
@@ -264,9 +268,9 @@ void attribute_edit_dialog_response(GtkWidget *w, gint response,
  *  \par Function Description
  *  This function creates the single attribute edit dialog.
  */
-void attrib_edit_dialog (GschemToplevel *w_current, OBJECT *attr_obj, int flag)
+void attrib_edit_dialog (GschemToplevel *w_current, LeptonObject *attr_obj, int flag)
 {
-  TOPLEVEL *toplevel = gschem_toplevel_get_toplevel (w_current);
+  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
   GtkWidget *aewindow;
   GtkWidget *vbox, *label, *table, *alignment;
   GtkWidget *show_options;
@@ -287,7 +291,7 @@ void attrib_edit_dialog (GschemToplevel *w_current, OBJECT *attr_obj, int flag)
   int nsel=0, i, len;
   char *name = NULL;
   char *val = NULL;
-  OBJECT *attrib = NULL;
+  LeptonObject *attrib = NULL;
   gint wx, wy;
 
   /* gschem specific */
@@ -295,10 +299,10 @@ void attrib_edit_dialog (GschemToplevel *w_current, OBJECT *attr_obj, int flag)
     return;
 
   /* gschem specific: What do we count here? (Werner)  */
-  for (s_current = geda_list_get_glist( toplevel->page_current->selection_list );
+  for (s_current = lepton_list_get_glist( toplevel->page_current->selection_list );
        s_current != NULL;
        s_current = g_list_next(s_current)) {
-    if (!((OBJECT *) s_current->data)->attached_to) {
+    if (!((LeptonObject *) s_current->data)->attached_to) {
       nsel++;
     }
   }
@@ -314,9 +318,9 @@ void attrib_edit_dialog (GschemToplevel *w_current, OBJECT *attr_obj, int flag)
                                             NULL);
   /* Set the alternative button order (ok, cancel, help) for other systems */
   gtk_dialog_set_alternative_button_order(GTK_DIALOG(aewindow),
-					  GTK_RESPONSE_APPLY,
-					  GTK_RESPONSE_REJECT,
-					  -1);
+                                          GTK_RESPONSE_APPLY,
+                                          GTK_RESPONSE_REJECT,
+                                          -1);
 
   g_signal_connect (G_OBJECT (aewindow), "response",
                     G_CALLBACK (attribute_edit_dialog_response),
@@ -329,7 +333,7 @@ void attrib_edit_dialog (GschemToplevel *w_current, OBJECT *attr_obj, int flag)
 
   vbox = gtk_dialog_get_content_area (GTK_DIALOG (aewindow));
   gtk_container_set_border_width(GTK_CONTAINER(aewindow),
-				 DIALOG_BORDER_SPACING);
+                                 DIALOG_BORDER_SPACING);
   gtk_box_set_spacing(GTK_BOX(vbox), DIALOG_V_SPACING);
 
   if (attr_obj != NULL)
@@ -343,7 +347,7 @@ void attrib_edit_dialog (GschemToplevel *w_current, OBJECT *attr_obj, int flag)
 
   alignment = gtk_alignment_new(0,0,1,1);
   gtk_alignment_set_padding(GTK_ALIGNMENT(alignment), 0, 0,
-			    DIALOG_INDENTATION, 0);
+                            DIALOG_INDENTATION, 0);
   gtk_box_pack_start(GTK_BOX(vbox), alignment, TRUE, TRUE, 0);
 
   table = gtk_table_new (3, 2, FALSE);
@@ -431,7 +435,7 @@ void attrib_edit_dialog (GschemToplevel *w_current, OBJECT *attr_obj, int flag)
 
     alignment = gtk_alignment_new(0,0,1,1);
     gtk_alignment_set_padding(GTK_ALIGNMENT(alignment), 0, 0,
-			    DIALOG_INDENTATION, 0);
+                              DIALOG_INDENTATION, 0);
     gtk_box_pack_start(GTK_BOX(vbox), alignment, TRUE, TRUE, 0);
 
     table = gtk_table_new (2, 3, FALSE);
@@ -508,7 +512,7 @@ void attrib_edit_dialog (GschemToplevel *w_current, OBJECT *attr_obj, int flag)
   if (attr_obj) {
     o_attrib_get_name_value (attr_obj, &name, &val);
     attrib = attr_obj;
-    if (o_is_visible (attrib)) {
+    if (lepton_object_is_visible (attrib)) {
       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(visbutton), TRUE);
     } else {
       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(visbutton), FALSE);
@@ -522,13 +526,13 @@ void attrib_edit_dialog (GschemToplevel *w_current, OBJECT *attr_obj, int flag)
       gtk_combo_box_set_active (GTK_COMBO_BOX (show_options), 2);
     }
   } else {
-    OBJECT *object;
+    LeptonObject *object;
 
     attrib = NULL;
 
     if ((object = o_select_return_first_object(w_current))) {
-      if (object->type == OBJ_NET)
-	name = g_strdup("netname");
+      if (lepton_object_is_net (object))
+        name = g_strdup("netname");
     }
 
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(visbutton), TRUE);
