@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -126,7 +126,7 @@ x_multiattrib_close (GschemToplevel *w_current)
  *  \par Function Description
  *
  *  If the GschemToplevel has an open multiattrib dialog, switch to
- *  watching the current page's SELECTION object for changes.
+ *  watching the current page's LeptonSelection object for changes.
  *
  *  \param [in] w_current  The GschemToplevel object.
  */
@@ -561,16 +561,16 @@ static void multiattrib_popup_menu (Multiattrib *multiattrib,
  *
  *  Returns TRUE/FALSE if the given object may have attributes attached.
  *
- *  \param [in] object  The OBJECT to test.
+ *  \param [in] object  The LeptonObject to test.
  *  \returns  TRUE/FALSE if the given object may have attributes attached.
  */
-static gboolean is_multiattrib_object (OBJECT *object)
+static gboolean is_multiattrib_object (LeptonObject *object)
 {
-  if (object->type == OBJ_COMPONENT ||
-      object->type == OBJ_PLACEHOLDER ||
-      object->type == OBJ_NET ||
-      object->type == OBJ_BUS ||
-      object->type == OBJ_PIN) {
+  if (lepton_object_is_component (object) ||
+      lepton_object_is_net (object) ||
+      lepton_object_is_bus (object) ||
+      lepton_object_is_pin (object))
+  {
     return TRUE;
   }
   return FALSE;
@@ -589,7 +589,7 @@ multiattrib_action_add_attribute (Multiattrib *multiattrib,
                                   gint visible,
                                   gint show_name_value)
 {
-  OBJECT *object;
+  LeptonObject *object;
   gchar *newtext;
   GList *iter;
   GschemToplevel *w_current = GSCHEM_DIALOG (multiattrib)->w_current;
@@ -601,10 +601,10 @@ multiattrib_action_add_attribute (Multiattrib *multiattrib,
     return;
   }
 
-  for (iter = geda_list_get_glist (multiattrib->object_list);
+  for (iter = lepton_list_get_glist (multiattrib->object_list);
        iter != NULL;
        iter = g_list_next (iter)) {
-    object = (OBJECT *)iter->data;
+    object = (LeptonObject *)iter->data;
 
     if (is_multiattrib_object (object)) {
 
@@ -635,12 +635,12 @@ multiattrib_action_duplicate_attributes (Multiattrib *multiattrib,
   for (iter = attr_list;
        iter != NULL;
        iter = g_list_next (iter)) {
-    OBJECT *o_attrib = (OBJECT *)iter->data;
+    LeptonObject *o_attrib = (LeptonObject *)iter->data;
 
     /* create a new attribute and link it */
     o_attrib_add_attrib (w_current,
-                         geda_text_object_get_string (o_attrib),
-                         o_is_visible (o_attrib),
+                         lepton_text_object_get_string (o_attrib),
+                         lepton_object_is_visible (o_attrib),
                          o_attrib->show_name_value,
                          o_attrib->attached_to);
   }
@@ -659,25 +659,25 @@ multiattrib_action_promote_attributes (Multiattrib *multiattrib,
                                        GList *attr_list)
 {
   GschemToplevel *w_current = GSCHEM_DIALOG (multiattrib)->w_current;
-  TOPLEVEL *toplevel = w_current->toplevel;
-  OBJECT *o_new;
+  LeptonToplevel *toplevel = w_current->toplevel;
+  LeptonObject *o_new;
   GList *iter;
 
   for (iter = attr_list;
        iter != NULL;
        iter = g_list_next (iter)) {
-    OBJECT *o_attrib = (OBJECT *)iter->data;
+    LeptonObject *o_attrib = (LeptonObject *)iter->data;
 
-    if (o_is_visible (o_attrib)) {
+    if (lepton_object_is_visible (o_attrib)) {
       /* If the attribute we're promoting is visible, don't clone its location */
       o_attrib_add_attrib (w_current,
-                           geda_text_object_get_string (o_attrib),
+                           lepton_text_object_get_string (o_attrib),
                            VISIBLE,
                            o_attrib->show_name_value,
                            o_attrib->parent);
     } else {
         /* make a copy of the attribute object */
-        o_new = o_object_copy (o_attrib);
+        o_new = lepton_object_copy (o_attrib);
         s_page_append (toplevel->page_current, o_new);
         /* add the attribute its parent */
         o_attrib_attach (o_new, o_attrib->parent, TRUE);
@@ -703,10 +703,10 @@ multiattrib_action_delete_attributes (Multiattrib *multiattrib,
 {
   GschemToplevel *w_current = GSCHEM_DIALOG (multiattrib)->w_current;
   GList *a_iter;
-  OBJECT *o_attrib;
+  LeptonObject *o_attrib;
 
   for (a_iter = attr_list; a_iter != NULL; a_iter = g_list_next (a_iter)) {
-    o_attrib = (OBJECT*) a_iter->data;
+    o_attrib = (LeptonObject*) a_iter->data;
     /* actually deletes the attribute */
     o_delete (w_current, o_attrib);
   }
@@ -728,31 +728,31 @@ multiattrib_action_copy_attribute_to_all (Multiattrib *multiattrib,
   GList *iter;
   GList *objects_needing_add;
 
-  objects_needing_add = g_list_copy (geda_list_get_glist (multiattrib->object_list));
+  objects_needing_add = g_list_copy (lepton_list_get_glist (multiattrib->object_list));
 
   /* Remove objects which already have this attribute from the list */
   for (iter = attr_list;
        iter != NULL;
        iter = g_list_next (iter)) {
-    OBJECT *o_attrib = (OBJECT *)iter->data;
+    LeptonObject *o_attrib = (LeptonObject *)iter->data;
 
     objects_needing_add = g_list_remove (objects_needing_add, o_attrib->attached_to);
   }
 
   for (iter = objects_needing_add; iter != NULL; iter = g_list_next (iter)) {
-    OBJECT *object = (OBJECT*) iter->data;
+    LeptonObject *object = (LeptonObject*) iter->data;
 
     if (is_multiattrib_object (object)) {
 
       /* Pick the first instance to copy from */
-      OBJECT *attrib_to_copy = (OBJECT*) attr_list->data;
+      LeptonObject *attrib_to_copy = (LeptonObject*) attr_list->data;
 
-      int visibility = o_is_visible (attrib_to_copy)
+      int visibility = lepton_object_is_visible (attrib_to_copy)
           ? VISIBLE : INVISIBLE;
 
       /* create a new attribute and link it */
       o_attrib_add_attrib (w_current,
-                           geda_text_object_get_string (attrib_to_copy),
+                           lepton_text_object_get_string (attrib_to_copy),
                            visibility,
                            attrib_to_copy->show_name_value,
                            object);
@@ -945,9 +945,9 @@ multiattrib_callback_edited_name (GtkCellRendererText *cellrenderertext,
   Multiattrib *multiattrib = (Multiattrib*)user_data;
   GtkTreeModel *model;
   GtkTreeIter iter;
-  GedaList *attr_list;
+  LeptonList *attr_list;
   GList *a_iter;
-  OBJECT *o_attrib;
+  LeptonObject *o_attrib;
   GschemToplevel *w_current;
   gchar *value, *newtext;
   int visibility;
@@ -998,12 +998,12 @@ multiattrib_callback_edited_name (GtkCellRendererText *cellrenderertext,
     return;
   }
 
-  for (a_iter = geda_list_get_glist (attr_list);
+  for (a_iter = lepton_list_get_glist (attr_list);
        a_iter != NULL;
        a_iter = g_list_next (a_iter)) {
-    o_attrib = (OBJECT*) a_iter->data;
+    o_attrib = (LeptonObject*) a_iter->data;
 
-    visibility = o_is_visible (o_attrib)
+    visibility = lepton_object_is_visible (o_attrib)
         ? VISIBLE : INVISIBLE;
 
     /* actually modifies the attribute */
@@ -1038,9 +1038,9 @@ multiattrib_callback_edited_value (GtkCellRendererText *cell_renderer,
   Multiattrib *multiattrib = (Multiattrib*)user_data;
   GtkTreeModel *model;
   GtkTreeIter iter;
-  GedaList *attr_list;
+  LeptonList *attr_list;
   GList *a_iter;
-  OBJECT *o_attrib;
+  LeptonObject *o_attrib;
   GschemToplevel *w_current;
   char *name;
   char *old_value;
@@ -1085,12 +1085,12 @@ multiattrib_callback_edited_value (GtkCellRendererText *cell_renderer,
     return;
   }
 
-  for (a_iter = geda_list_get_glist (attr_list);
+  for (a_iter = lepton_list_get_glist (attr_list);
        a_iter != NULL;
        a_iter = g_list_next (a_iter)) {
-    o_attrib = (OBJECT *)a_iter->data;
+    o_attrib = (LeptonObject *)a_iter->data;
 
-    visibility = o_is_visible (o_attrib)
+    visibility = lepton_object_is_visible (o_attrib)
         ? VISIBLE : INVISIBLE;
 
     /* actually modifies the attribute */
@@ -1126,10 +1126,10 @@ multiattrib_callback_toggled_visible (GtkCellRendererToggle *cell_renderer,
   Multiattrib *multiattrib = (Multiattrib*)user_data;
   GtkTreeModel *model;
   GtkTreeIter iter;
-  OBJECT *o_attrib;
+  LeptonObject *o_attrib;
   GschemToplevel *w_current;
   gboolean new_visibility;
-  GedaList *attr_list;
+  LeptonList *attr_list;
   GList *a_iter;
 
   model = gtk_tree_view_get_model (multiattrib->treeview);
@@ -1145,14 +1145,14 @@ multiattrib_callback_toggled_visible (GtkCellRendererToggle *cell_renderer,
 
   new_visibility = !gtk_cell_renderer_toggle_get_active (cell_renderer);
 
-  for (a_iter = geda_list_get_glist (attr_list);
+  for (a_iter = lepton_list_get_glist (attr_list);
        a_iter != NULL;
        a_iter = g_list_next (a_iter)) {
-    o_attrib = (OBJECT *)a_iter->data;
+    o_attrib = (LeptonObject *)a_iter->data;
 
     /* actually modifies the attribute */
     o_invalidate (w_current, o_attrib);
-    o_set_visibility (o_attrib, new_visibility ? VISIBLE : INVISIBLE);
+    lepton_object_set_visibility (o_attrib, new_visibility ? VISIBLE : INVISIBLE);
     o_text_recreate (o_attrib);
   }
 
@@ -1183,7 +1183,7 @@ multiattrib_callback_toggled_show_name (GtkCellRendererToggle *cell_renderer,
   GtkTreeIter iter;
   GschemToplevel *w_current;
   gboolean new_name_visible;
-  GedaList *attr_list;
+  LeptonList *attr_list;
   GList *a_iter;
   gint new_snv;
 
@@ -1200,10 +1200,10 @@ multiattrib_callback_toggled_show_name (GtkCellRendererToggle *cell_renderer,
 
   new_name_visible = !gtk_cell_renderer_toggle_get_active (cell_renderer);
 
-  for (a_iter = geda_list_get_glist (attr_list);
+  for (a_iter = lepton_list_get_glist (attr_list);
        a_iter != NULL;
        a_iter = g_list_next (a_iter)) {
-    OBJECT *o_attrib = (OBJECT *)a_iter->data;
+    LeptonObject *o_attrib = (LeptonObject *)a_iter->data;
 
     gboolean value_visible = snv_shows_value (o_attrib->show_name_value);
 
@@ -1247,7 +1247,7 @@ multiattrib_callback_toggled_show_value (GtkCellRendererToggle *cell_renderer,
   GtkTreeIter iter;
   GschemToplevel *w_current;
   gboolean new_value_visible;
-  GedaList *attr_list;
+  LeptonList *attr_list;
   GList *a_iter;
   gint new_snv;
 
@@ -1264,10 +1264,10 @@ multiattrib_callback_toggled_show_value (GtkCellRendererToggle *cell_renderer,
 
   new_value_visible = !gtk_cell_renderer_toggle_get_active (cell_renderer);
 
-  for (a_iter = geda_list_get_glist (attr_list);
+  for (a_iter = lepton_list_get_glist (attr_list);
        a_iter != NULL;
        a_iter = g_list_next (a_iter)) {
-    OBJECT *o_attrib = (OBJECT *)a_iter->data;
+    LeptonObject *o_attrib = (LeptonObject *)a_iter->data;
 
     gboolean name_visible = snv_shows_name (o_attrib->show_name_value);
 
@@ -1312,7 +1312,7 @@ multiattrib_callback_key_pressed (GtkWidget *widget,
       (event->keyval == GDK_KEY_Delete || event->keyval == GDK_KEY_KP_Delete)) {
     GtkTreeModel *model;
     GtkTreeIter iter;
-    GedaList *attr_list;
+    LeptonList *attr_list;
     int inherited;
     /* delete the currently selected attribute */
 
@@ -1333,7 +1333,7 @@ multiattrib_callback_key_pressed (GtkWidget *widget,
       return FALSE;
 
     multiattrib_action_delete_attributes (multiattrib,
-                                          geda_list_get_glist (attr_list));
+                                          lepton_list_get_glist (attr_list));
 
     g_object_unref (attr_list);
 
@@ -1433,7 +1433,7 @@ multiattrib_callback_popup_duplicate (GtkMenuItem *menuitem,
   Multiattrib *multiattrib = (Multiattrib*)user_data;
   GtkTreeModel *model;
   GtkTreeIter iter;
-  GedaList *attr_list;
+  LeptonList *attr_list;
 
   if (!gtk_tree_selection_get_selected (
         gtk_tree_view_get_selection (multiattrib->treeview),
@@ -1445,7 +1445,7 @@ multiattrib_callback_popup_duplicate (GtkMenuItem *menuitem,
   gtk_tree_model_get (model, &iter,
                       COLUMN_ATTRIBUTE_GEDALIST, &attr_list,
                       -1);
-  multiattrib_action_duplicate_attributes (multiattrib, geda_list_get_glist (attr_list));
+  multiattrib_action_duplicate_attributes (multiattrib, lepton_list_get_glist (attr_list));
   g_object_unref (attr_list);
 
   /* update the treeview contents */
@@ -1464,7 +1464,7 @@ multiattrib_callback_popup_promote (GtkMenuItem *menuitem,
   Multiattrib *multiattrib = MULTIATTRIB (user_data);
   GtkTreeModel *model;
   GtkTreeIter iter;
-  GedaList *attr_list;
+  LeptonList *attr_list;
 
   if (!gtk_tree_selection_get_selected (
          gtk_tree_view_get_selection (multiattrib->treeview),
@@ -1476,7 +1476,7 @@ multiattrib_callback_popup_promote (GtkMenuItem *menuitem,
   gtk_tree_model_get (model, &iter,
                       COLUMN_ATTRIBUTE_GEDALIST, &attr_list,
                       -1);
-  multiattrib_action_promote_attributes (multiattrib, geda_list_get_glist (attr_list));
+  multiattrib_action_promote_attributes (multiattrib, lepton_list_get_glist (attr_list));
   g_object_unref (attr_list);
 
   /* update the treeview contents */
@@ -1495,7 +1495,7 @@ multiattrib_callback_popup_delete (GtkMenuItem *menuitem,
   Multiattrib *multiattrib = (Multiattrib*)user_data;
   GtkTreeModel *model;
   GtkTreeIter iter;
-  GedaList *attr_list;
+  LeptonList *attr_list;
 
   if (!gtk_tree_selection_get_selected (
         gtk_tree_view_get_selection (multiattrib->treeview),
@@ -1507,7 +1507,7 @@ multiattrib_callback_popup_delete (GtkMenuItem *menuitem,
   gtk_tree_model_get (model, &iter,
                       COLUMN_ATTRIBUTE_GEDALIST, &attr_list,
                       -1);
-  multiattrib_action_delete_attributes (multiattrib, geda_list_get_glist (attr_list));
+  multiattrib_action_delete_attributes (multiattrib, lepton_list_get_glist (attr_list));
   g_object_unref (attr_list);
 
   /* update the treeview contents */
@@ -1526,7 +1526,7 @@ multiattrib_callback_popup_copy_to_all (GtkMenuItem *menuitem,
   Multiattrib *multiattrib = MULTIATTRIB (user_data);
   GtkTreeModel *model;
   GtkTreeIter iter;
-  GedaList *attr_list;
+  LeptonList *attr_list;
 
   if (!gtk_tree_selection_get_selected (
          gtk_tree_view_get_selection (multiattrib->treeview),
@@ -1538,7 +1538,7 @@ multiattrib_callback_popup_copy_to_all (GtkMenuItem *menuitem,
   gtk_tree_model_get (model, &iter,
                       COLUMN_ATTRIBUTE_GEDALIST, &attr_list,
                       -1);
-  multiattrib_action_copy_attribute_to_all (multiattrib, geda_list_get_glist (attr_list));
+  multiattrib_action_copy_attribute_to_all (multiattrib, lepton_list_get_glist (attr_list));
   g_object_unref (attr_list);
 
   /* update the treeview contents */
@@ -1786,6 +1786,12 @@ multiattrib_geometry_save (GschemDialog *dialog, EdaConfig *cfg, gchar *group_na
   show_inherited =
     gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (MULTIATTRIB (dialog)->show_inherited));
   eda_config_set_boolean (cfg, group_name, "show_inherited", show_inherited);
+
+
+  gboolean expand_add_attr =
+      gtk_expander_get_expanded (GTK_EXPANDER (MULTIATTRIB (dialog)->add_frame));
+
+  eda_config_set_boolean (cfg, group_name, "expand_add_attr", expand_add_attr);
 }
 
 
@@ -1812,9 +1818,22 @@ multiattrib_geometry_restore (GschemDialog *dialog, EdaConfig *cfg, gchar *group
   show_inherited = eda_config_get_boolean (cfg, group_name, "show_inherited", &error);
   if (error != NULL) {
     show_inherited = TRUE;
-    g_error_free (error);
   }
+  g_clear_error (&error);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (MULTIATTRIB (dialog)->show_inherited), show_inherited);
+
+
+  gboolean expand_add_attr =
+    eda_config_get_boolean (cfg, group_name, "expand_add_attr", &error);
+
+  if (error != NULL)
+  {
+    expand_add_attr = TRUE;
+  }
+
+  g_clear_error (&error);
+  gtk_expander_set_expanded (GTK_EXPANDER (MULTIATTRIB (dialog)->add_frame),
+                             expand_add_attr);
 }
 
 
@@ -1860,21 +1879,21 @@ multiattrib_get_type ()
  *
  *  \par Function Description
  *
- *  \param [in] selection    The GedaList object of we are watching/
+ *  \param [in] selection    The LeptonList object of we are watching/
  *  \param [in] multiattrib  The multi-attribute editor dialog.
  */
 static void
-object_list_changed_cb (GedaList *object_list, Multiattrib *multiattrib)
+object_list_changed_cb (LeptonList *object_list, Multiattrib *multiattrib)
 {
   multiattrib_update (multiattrib);
 }
 
 
-/*! \brief Update the dialog when the current object GedaList object is destroyed
+/*! \brief Update the dialog when the current object LeptonList object is destroyed
  *
  *  \par Function Description
  *
- *  This handler is called when the g_object_weak_ref() on the GedaList object
+ *  This handler is called when the g_object_weak_ref() on the LeptonList object
  *  we're watching expires. We reset our multiattrib->object_list pointer to NULL
  *  to avoid attempting to access the destroyed object. NB: Our signal handlers
  *  were automatically disconnected during the destruction process.
@@ -1892,18 +1911,18 @@ object_list_weak_ref_cb (gpointer data, GObject *where_the_object_was)
 }
 
 
-/*! \brief Connect signal handler and weak_ref on the GedaList object
+/*! \brief Connect signal handler and weak_ref on the LeptonList object
  *
  *  \par Function Description
  *
  *  Connect the "changed" signal and add a weak reference
- *  on the GedaList object we are going to watch.
+ *  on the LeptonList object we are going to watch.
  *
  *  \param [in] multiattrib  The Multiattrib dialog.
- *  \param [in] object_list  The GedaList object to watch.
+ *  \param [in] object_list  The LeptonList object to watch.
  */
 static void
-connect_object_list (Multiattrib *multiattrib, GedaList *object_list)
+connect_object_list (Multiattrib *multiattrib, LeptonList *object_list)
 {
   multiattrib->object_list = object_list;
   if (multiattrib->object_list != NULL) {
@@ -1924,11 +1943,11 @@ connect_object_list (Multiattrib *multiattrib, GedaList *object_list)
 }
 
 
-/*! \brief Disconnect signal handler and weak_ref on the GedaList object
+/*! \brief Disconnect signal handler and weak_ref on the LeptonList object
  *
  *  \par Function Description
  *
- *  If the dialog is watching a GedaList object, disconnect the
+ *  If the dialog is watching a LeptonList object, disconnect the
  *  "changed" signal and remove our weak reference on the object.
  *
  *  \param [in] multiattrib  The Multiattrib dialog.
@@ -1951,7 +1970,7 @@ disconnect_object_list (Multiattrib *multiattrib)
  *  \par Function Description
  *
  *  Just before the Multiattrib GObject is finalized, disconnect from
- *  the GedaList object being watched and then chain up to the parent
+ *  the LeptonList object being watched and then chain up to the parent
  *  class's finalize handler.
  *
  *  \param [in] object  The GObject being finalized.
@@ -2012,6 +2031,19 @@ multiattrib_show_inherited_toggled (GtkToggleButton *button,
 }
 
 
+/*! \brief Remember "expanded" state of the "Add Attribute" section.
+ */
+static void
+multiattrib_callback_expander_activate (GtkExpander* expander,
+                                        gpointer     data)
+{
+  Multiattrib* multiattrib = (Multiattrib*) data;
+
+  multiattrib->add_attr_section_expanded =
+    gtk_expander_get_expanded (expander);
+}
+
+
 /*! \brief GType instance initialiser for Multiattrib
  *
  *  \par Function Description
@@ -2245,10 +2277,7 @@ multiattrib_init (Multiattrib *multiattrib)
                       TRUE, TRUE, 1);
   gtk_widget_show_all (multiattrib->list_frame);
 
-  /* create the add/edit frame */
-  multiattrib->add_frame = GTK_WIDGET (g_object_new (GTK_TYPE_FRAME,
-                                       "label", _("Add Attribute"),
-                                       NULL));
+
   table = GTK_WIDGET (g_object_new (GTK_TYPE_TABLE,
                                     /* GtkTable */
                                     "n-rows",      4,
@@ -2372,8 +2401,17 @@ multiattrib_init (Multiattrib *multiattrib)
                     (GtkAttachOptions) 0,
                     6, 3);
 
-  /* add the table to the frame */
-  gtk_container_add (GTK_CONTAINER (multiattrib->add_frame), table);
+
+  multiattrib->add_frame =
+    gschem_dialog_misc_create_section_widget(
+      _("<b>Add Attribute</b>"), table);
+
+  g_signal_connect (multiattrib->add_frame,
+                    "activate",
+                    G_CALLBACK (multiattrib_callback_expander_activate),
+                    multiattrib);
+
+
   /* pack the frame in the dialog */
   gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (multiattrib))),
                       multiattrib->add_frame,
@@ -2412,7 +2450,7 @@ multiattrib_set_property (GObject *object,
   switch(property_id) {
       case PROP_OBJECT_LIST:
         disconnect_object_list (multiattrib);
-        connect_object_list (multiattrib, GEDA_LIST (g_value_get_pointer (value)));
+        connect_object_list (multiattrib, LEPTON_LIST (g_value_get_pointer (value)));
         break;
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -2462,10 +2500,10 @@ typedef struct {
   gboolean identical_show_name;
   gboolean identical_show_value;
 
-  GedaList *attribute_gedalist;
+  LeptonList *attribute_gedalist;
 } MODEL_ROW;
 
-/*! \brief For a given OBJECT, produce a GList of MODEL_ROW records
+/*! \brief For a given LeptonObject, produce a GList of MODEL_ROW records
  *
  *  \par Function Description
  *
@@ -2474,11 +2512,11 @@ typedef struct {
  *  together.
  *
  *  \param [in] multiattrib  The multi-attribute editor dialog
- *  \param [in] object       The OBJECT * whos attributes we are processing
+ *  \param [in] object       The LeptonObject * whos attributes we are processing
  *  \returns  A GList of MODEL_ROW records detailing object's attributes.
  */
 static GList *
-object_attributes_to_model_rows (Multiattrib *multiattrib, OBJECT *object)
+object_attributes_to_model_rows (Multiattrib *multiattrib, LeptonObject *object)
 {
   GList *model_rows = NULL;
   GList *a_iter;
@@ -2487,25 +2525,25 @@ object_attributes_to_model_rows (Multiattrib *multiattrib, OBJECT *object)
   for (a_iter = object_attribs; a_iter != NULL;
        a_iter = g_list_next (a_iter)) {
 
-    OBJECT *a_current = (OBJECT*) a_iter->data;
+    LeptonObject *a_current = (LeptonObject*) a_iter->data;
     MODEL_ROW *m_row = g_new0 (MODEL_ROW, 1);
     GList *m_iter;
 
     m_row->inherited = o_attrib_is_inherited (a_current);
     o_attrib_get_name_value (a_current, &m_row->name, &m_row->value);
-    m_row->visibility = o_is_visible (a_current);
+    m_row->visibility = lepton_object_is_visible (a_current);
     m_row->show_name_value = a_current->show_name_value;
     m_row->nth_with_name = 0; /* Provisional value until we check below */
 
-    /* The following fields are always true for a single OBJECT */
+    /* The following fields are always true for a single LeptonObject */
     m_row->present_in_all = TRUE;
     m_row->identical_value = TRUE;
     m_row->identical_visibility = TRUE;
     m_row->identical_show_name = TRUE;
     m_row->identical_show_value = TRUE;
 
-    m_row->attribute_gedalist = geda_list_new ();
-    geda_list_add (m_row->attribute_gedalist, a_current);
+    m_row->attribute_gedalist = lepton_list_new ();
+    lepton_list_add (m_row->attribute_gedalist, a_current);
 
     /* Search already processed attributes to see if we need to bump m_row->nth_with_name */
     for (m_iter = model_rows;
@@ -2526,7 +2564,7 @@ object_attributes_to_model_rows (Multiattrib *multiattrib, OBJECT *object)
   return model_rows;
 }
 
-/*! \brief Produce a GList of MODEL_ROW records for all attribute objects in our GedaList
+/*! \brief Produce a GList of MODEL_ROW records for all attribute objects in our LeptonList
  *
  *  \par Function Description
  *
@@ -2534,7 +2572,7 @@ object_attributes_to_model_rows (Multiattrib *multiattrib, OBJECT *object)
  *  attributes, or attributes which are selected separately from their owning
  *  object.
  *
- *  It is not expected this will be called when the GedaList the dialog is watching
+ *  It is not expected this will be called when the LeptonList the dialog is watching
  *  contains any higher level objects on which we could edit attributes.
  *
  *  \param [in] multiattrib  The multi-attribute editor dialog
@@ -2547,14 +2585,15 @@ lone_attributes_to_model_rows (Multiattrib *multiattrib)
   GList *model_rows = NULL;
 
   /* populate the store with attributes */
-  for (o_iter = multiattrib->object_list == NULL ? NULL : geda_list_get_glist (multiattrib->object_list);
+  for (o_iter = multiattrib->object_list == NULL ? NULL : lepton_list_get_glist (multiattrib->object_list);
        o_iter != NULL;
        o_iter = g_list_next (o_iter)) {
-    OBJECT *object = (OBJECT*) o_iter->data;
+    LeptonObject *object = (LeptonObject*) o_iter->data;
     MODEL_ROW *m_row;
 
     /* Consider a selected text object might be an attribute */
-    if (object->type != OBJ_TEXT || !o_attrib_is_attrib (object))
+    if (!lepton_object_is_text (object) ||
+        !o_attrib_is_attrib (object))
       continue;
 
     /* We have an OBJ_TEXT which libgeda can parse as an attribute */
@@ -2564,7 +2603,7 @@ lone_attributes_to_model_rows (Multiattrib *multiattrib)
     m_row = g_new0 (MODEL_ROW, 1);
     m_row->inherited = o_attrib_is_inherited (object);
     o_attrib_get_name_value (object, &m_row->name, &m_row->value);
-    m_row->visibility = o_is_visible (object);
+    m_row->visibility = lepton_object_is_visible (object);
     m_row->show_name_value = object->show_name_value;
     m_row->nth_with_name = 0; /* All selected attributes are treated individually */
 
@@ -2575,8 +2614,8 @@ lone_attributes_to_model_rows (Multiattrib *multiattrib)
     m_row->identical_show_name = TRUE;
     m_row->identical_show_value = TRUE;
 
-    m_row->attribute_gedalist = geda_list_new ();
-    geda_list_add (m_row->attribute_gedalist, object);
+    m_row->attribute_gedalist = lepton_list_new ();
+    lepton_list_add (m_row->attribute_gedalist, object);
 
     model_rows = g_list_append (model_rows, m_row);
   }
@@ -2613,7 +2652,7 @@ multiattrib_populate_liststore (Multiattrib *multiattrib,
     MODEL_ROW *model_row = (MODEL_ROW*) m_iter->data;
 
     model_row->present_in_all =
-      ((int) g_list_length (geda_list_get_glist (model_row->attribute_gedalist))
+      ((int) g_list_length (lepton_list_get_glist (model_row->attribute_gedalist))
        == multiattrib->total_num_in_list);
 
     gtk_list_store_append (liststore, &tree_iter);
@@ -2632,7 +2671,7 @@ multiattrib_populate_liststore (Multiattrib *multiattrib,
                         COLUMN_ATTRIBUTE_GEDALIST,   model_row->attribute_gedalist,
                         -1);
 
-    /* Drop our ref on the GedaList so it is freed when the model has done with it */
+    /* Drop our ref on the LeptonList so it is freed when the model has done with it */
     g_object_unref (model_row->attribute_gedalist);
   }
 
@@ -2738,10 +2777,10 @@ multiattrib_update (Multiattrib *multiattrib)
   multiattrib->num_lone_attribs_in_list = 0;
 
   /* populate the store with attributes */
-  for (o_iter = multiattrib->object_list == NULL ? NULL : geda_list_get_glist (multiattrib->object_list);
+  for (o_iter = multiattrib->object_list == NULL ? NULL : lepton_list_get_glist (multiattrib->object_list);
        o_iter != NULL;
        o_iter = g_list_next (o_iter)) {
-    OBJECT *object = (OBJECT*) o_iter->data;
+    LeptonObject *object = (LeptonObject*) o_iter->data;
 
     GList *object_rows;
     GList *or_iter;
@@ -2752,8 +2791,8 @@ multiattrib_update (Multiattrib *multiattrib)
     /* Count the different objects we are editing */
     multiattrib->total_num_in_list++;
 
-    if (object->type == OBJ_COMPONENT ||
-        object->type == OBJ_PLACEHOLDER) {
+    if (lepton_object_is_component (object))
+    {
       multiattrib->num_comp_in_list++;
 
       if (component_title_name == NULL)
@@ -2762,13 +2801,13 @@ multiattrib_update (Multiattrib *multiattrib)
         component_title_name = _("<various>");
     }
 
-    if (object->type == OBJ_PIN)
+    if (lepton_object_is_pin (object))
       multiattrib->num_pins_in_list++;
 
-    if (object->type == OBJ_NET)
+    if (lepton_object_is_net (object))
       multiattrib->num_nets_in_list++;
 
-    if (object->type == OBJ_BUS)
+    if (lepton_object_is_bus (object))
       multiattrib->num_buses_in_list++;
 
     /* populate the store with any attributes from this object */
@@ -2816,9 +2855,9 @@ multiattrib_update (Multiattrib *multiattrib)
             snv_shows_value (object_row->show_name_value))
           model_row->identical_show_value = FALSE;
 
-        /* Add the underlying attribute to the row's GedaList of attributes */
-        geda_list_add_glist (model_row->attribute_gedalist,
-                             geda_list_get_glist (object_row->attribute_gedalist));
+        /* Add the underlying attribute to the row's LeptonList of attributes */
+        lepton_list_add_glist (model_row->attribute_gedalist,
+                             lepton_list_get_glist (object_row->attribute_gedalist));
 
         g_object_unref (object_row->attribute_gedalist);
         g_free (object_row);
