@@ -1,6 +1,6 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 2018 dmn <graahnul.grom@gmail.com>
- * Copyright (C) 2018-2020 Lepton EDA Contributors
+ * Copyright (C) 2018-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -166,7 +166,7 @@ struct _TabInfo
 
   gint            ndx_;   /* just for debugging; will be removed */
 
-  PAGE*           page_;
+  LeptonPage*     page_;
   GschemPageView* pview_;
   GtkWidget*      wtab_;  /* tab widget, i.e. scrolled wnd, parent of pview_ */
 
@@ -193,7 +193,7 @@ x_tabs_info_cur (GschemToplevel* w_current);
 static TabInfo*
 x_tabs_info_add (GschemToplevel* w_current,
                  gint            ndx,
-                 PAGE*           page,
+                 LeptonPage*     page,
                  GschemPageView* pview,
                  GtkWidget*      wtab);
 
@@ -210,8 +210,8 @@ static gint
 x_tabs_info_cmp_wtab (gconstpointer elem, gconstpointer data);
 
 static TabInfo*
-x_tabs_info_find_by_page (GList* nfos, PAGE* page);
-
+x_tabs_info_find_by_page (GList* nfos,
+                          LeptonPage* page);
 static TabInfo*
 x_tabs_info_find_by_pview (GList* nfos, GschemPageView* pview);
 
@@ -222,12 +222,12 @@ x_tabs_info_find_by_wtab (GList* nfos, GtkWidget* wtab);
 
 /* GschemToplevel accessors: */
 
-static PAGE*
+static LeptonPage*
 x_tabs_tl_page_cur (GschemToplevel* w_current);
 
 static void
-x_tabs_tl_page_cur_set (GschemToplevel* w_current, PAGE* page);
-
+x_tabs_tl_page_cur_set (GschemToplevel* w_current,
+                        LeptonPage* page);
 static GschemPageView*
 x_tabs_tl_pview_cur (GschemToplevel* w_current);
 
@@ -235,8 +235,8 @@ static void
 x_tabs_tl_pview_cur_set (GschemToplevel* w_current, GschemPageView* pview);
 
 static gboolean
-x_tabs_tl_page_find (GschemToplevel* w_current, PAGE* page);
-
+x_tabs_tl_page_find (GschemToplevel* w_current,
+                     LeptonPage* page);
 
 
 /* notebook: */
@@ -246,13 +246,13 @@ x_tabs_nbook_create (GschemToplevel* w_current, GtkWidget* work_box);
 
 static gint
 x_tabs_nbook_page_add (GschemToplevel* w_current,
-                       PAGE*           page,
+                       LeptonPage*     page,
                        GschemPageView* pview,
                        GtkWidget*      wtab);
 
 static void
-x_tabs_nbook_page_close (GschemToplevel* w_current, PAGE* page);
-
+x_tabs_nbook_page_close (GschemToplevel* w_current,
+                         LeptonPage* page);
 static void
 x_tabs_page_on_sel (GtkNotebook* nbook,
                     GtkWidget*   wtab,
@@ -287,7 +287,7 @@ x_tabs_menu_item_on_activate (GtkAction* action, gpointer data);
 
 static GschemPageView*
 x_tabs_pview_create (GschemToplevel* w_current,
-                     PAGE*           page,
+                     LeptonPage*     page,
                      GtkWidget**     ppwtab);
 
 /*
@@ -315,6 +315,9 @@ x_tabs_hdr_on_btn_close (GtkToolButton* btn, gpointer p);
 static void
 x_tabs_hdr_on_btn_up (GtkToolButton* btn, gpointer p);
 
+static void
+x_tabs_hdr_on_btn_save (GtkToolButton* btn, gpointer p);
+
 
 
 /* helpers: */
@@ -388,13 +391,13 @@ x_tabs_dbg_infos_dump (GschemToplevel* w_current)
 void
 x_tabs_dbg_pages_dump (GschemToplevel* w_current)
 {
-  GList* ptr = geda_list_get_glist( w_current->toplevel->pages );
+  GList* ptr = lepton_list_get_glist( w_current->toplevel->pages );
 
   printf( "\n vvvvvvvvvvvvvv pages vvvvvvvvvvvvvvvvvv\n" );
 
   for ( ; ptr != NULL; ptr = g_list_next( ptr ) )
   {
-    PAGE* page = (PAGE*) ptr->data;
+    LeptonPage* page = (LeptonPage*) ptr->data;
     printf( "\n" );
     printf( "    page:  [%p]\n", (void*) page );
     printf( "    fname: [%s]\n", page->_filename );
@@ -416,7 +419,7 @@ x_tabs_dbg_pages_dump_simple (GschemToplevel* w_current)
         node != NULL;
         node = g_list_next( node ) )
   {
-    PAGE* p = node->data;
+    LeptonPage* p = node->data;
     printf( "    p: [%s]\n", g_path_get_basename( s_page_get_filename(p) ) );
   }
 
@@ -449,7 +452,7 @@ x_tabs_info_cur (GschemToplevel* w_current)
 static TabInfo*
 x_tabs_info_add (GschemToplevel* w_current,
                  gint            ndx,
-                 PAGE*           page,
+                 LeptonPage*     page,
                  GschemPageView* pview,
                  GtkWidget*      wtab)
 {
@@ -489,8 +492,8 @@ x_tabs_info_rm (GschemToplevel* w_current, TabInfo* nfo)
 static gint
 x_tabs_info_cmp_page (gconstpointer elem, gconstpointer data)
 {
-  TabInfo* nfo  = (TabInfo*) elem;
-  PAGE*    page = (PAGE*)    data;
+  TabInfo*    nfo  = (TabInfo*)    elem;
+  LeptonPage* page = (LeptonPage*) data;
 
   if (nfo->page_ == page)
     return 0;
@@ -529,7 +532,8 @@ x_tabs_info_cmp_wtab (gconstpointer elem, gconstpointer data)
 
 
 static TabInfo*
-x_tabs_info_find_by_page (GList* nfos, PAGE* page)
+x_tabs_info_find_by_page (GList* nfos,
+                          LeptonPage* page)
 {
   GList* ptr = g_list_find_custom (nfos,
                                    (gconstpointer) page,
@@ -568,7 +572,7 @@ x_tabs_info_find_by_wtab (GList* nfos, GtkWidget* wtab)
  *
  */
 
-static PAGE*
+static LeptonPage*
 x_tabs_tl_page_cur (GschemToplevel* w_current)
 {
   return w_current->toplevel->page_current;
@@ -577,7 +581,8 @@ x_tabs_tl_page_cur (GschemToplevel* w_current)
 
 
 static void
-x_tabs_tl_page_cur_set (GschemToplevel* w_current, PAGE* page)
+x_tabs_tl_page_cur_set (GschemToplevel* w_current,
+                        LeptonPage* page)
 {
   s_page_goto (w_current->toplevel, page);
 
@@ -613,13 +618,14 @@ x_tabs_tl_pview_cur_set (GschemToplevel* w_current, GschemPageView* pview)
  *
  */
 static gboolean
-x_tabs_tl_page_find (GschemToplevel* w_current, PAGE* page)
+x_tabs_tl_page_find (GschemToplevel* w_current,
+                     LeptonPage* page)
 {
-  GList* ptr = geda_list_get_glist (w_current->toplevel->pages);
+  GList* ptr = lepton_list_get_glist (w_current->toplevel->pages);
 
   for ( ; ptr != NULL; ptr = g_list_next (ptr) )
   {
-    PAGE* pg = (PAGE*) ptr->data;
+    LeptonPage* pg = (LeptonPage*) ptr->data;
     if (pg == page)
       return TRUE;
   }
@@ -683,7 +689,7 @@ x_tabs_nbook_create (GschemToplevel* w_current, GtkWidget* work_box)
 
 static gint
 x_tabs_nbook_page_add (GschemToplevel* w_current,
-                       PAGE*           page,
+                       LeptonPage*     page,
                        GschemPageView* pview,
                        GtkWidget*      wtab)
 {
@@ -702,7 +708,8 @@ x_tabs_nbook_page_add (GschemToplevel* w_current,
 
 
 static void
-x_tabs_nbook_page_close (GschemToplevel* w_current, PAGE* page)
+x_tabs_nbook_page_close (GschemToplevel* w_current,
+                         LeptonPage* page)
 {
   TabInfo* nfo = x_tabs_info_find_by_page (w_current->xtabs_info_list, page);
   if (!nfo)
@@ -728,7 +735,7 @@ x_tabs_nbook_page_close (GschemToplevel* w_current, PAGE* page)
 
 static GschemPageView*
 x_tabs_pview_create (GschemToplevel* w_current,
-                     PAGE*           page,
+                     LeptonPage*     page,
                      GtkWidget**     ppwtab)
 {
 #ifdef DEBUG
@@ -808,7 +815,7 @@ x_tabs_hdr_create (TabInfo* nfo)
   gchar* lab_txt = NULL;
 
   if (nfo->page_->CHANGED)
-    lab_txt = g_strdup_printf ("* <b>%s</b>", bname);
+    lab_txt = g_strdup_printf ("<b>%s</b>", bname);
   else
     lab_txt = g_strdup (bname);
 
@@ -856,6 +863,7 @@ x_tabs_hdr_create (TabInfo* nfo)
   GtkWidget* img_close = gtk_image_new_from_stock (GTK_STOCK_CLOSE,
                                                    GTK_ICON_SIZE_MENU);
   gtk_container_add (GTK_CONTAINER (btn_close), img_close);
+  gtk_widget_set_tooltip_text (btn_close, _("Close"));
 
 
   /* "up" btn:
@@ -870,6 +878,19 @@ x_tabs_hdr_create (TabInfo* nfo)
   gtk_container_add (GTK_CONTAINER (btn_up), img_up);
 
 
+  /* "save" btn:
+  */
+  GtkWidget* btn_save = gtk_button_new();
+  gtk_widget_set_name (btn_save, "lepton-tab-btn");
+  gtk_button_set_relief (GTK_BUTTON (btn_save), GTK_RELIEF_NONE);
+  gtk_button_set_focus_on_click (GTK_BUTTON (btn_save), FALSE);
+
+  GtkWidget* img_save = gtk_image_new_from_stock (GTK_STOCK_SAVE,
+                                                  GTK_ICON_SIZE_MENU);
+  gtk_container_add (GTK_CONTAINER (btn_save), img_save);
+  gtk_widget_set_tooltip_text (btn_save, _("Save"));
+
+
   /* pack button boxes and label box to hdr box:
   */
   gtk_box_pack_start (GTK_BOX (box_hdr), box_btns_left,  FALSE, FALSE, 0);
@@ -877,10 +898,23 @@ x_tabs_hdr_create (TabInfo* nfo)
   gtk_box_pack_start (GTK_BOX (box_hdr), box_btns_right, FALSE, FALSE, 0);
 
 
+  /* setup "save" btn:
+  */
+  if (nfo->page_->CHANGED)
+  {
+    gtk_box_pack_end (GTK_BOX (box_btns_left), btn_save, FALSE, FALSE, 0);
+
+    g_signal_connect (btn_save,
+                      "clicked",
+                      G_CALLBACK (&x_tabs_hdr_on_btn_save),
+                      nfo);
+  }
+
+
   /* setup "up" btn:
   */
-  TOPLEVEL* toplevel = gschem_toplevel_get_toplevel (nfo->tl_);
-  PAGE* parent = s_hierarchy_find_up_page (toplevel->pages, nfo->page_);
+  LeptonToplevel* toplevel = gschem_toplevel_get_toplevel (nfo->tl_);
+  LeptonPage* parent = s_hierarchy_find_up_page (toplevel->pages, nfo->page_);
 
   if (x_tabs_show_up_button() && parent != NULL)
   {
@@ -963,7 +997,8 @@ x_tabs_hdr_set (GtkNotebook* nbook, TabInfo* nfo)
  *  For now, it simply recreates the header.
  */
 void
-x_tabs_hdr_update (GschemToplevel* w_current, PAGE* page)
+x_tabs_hdr_update (GschemToplevel* w_current,
+                   LeptonPage* page)
 {
   g_return_if_fail (w_current != NULL);
   g_return_if_fail (page != NULL);
@@ -1018,6 +1053,19 @@ x_tabs_hdr_on_btn_up (GtkToolButton* btn, gpointer p)
 
 
 
+static void
+x_tabs_hdr_on_btn_save (GtkToolButton* btn, gpointer p)
+{
+  TabInfo* nfo = (TabInfo*) p;
+  g_return_if_fail (nfo != NULL);
+
+  x_tabs_page_set_cur (nfo->tl_, nfo->page_);
+  g_action_eval_by_name (nfo->tl_, "&file-save");
+
+} /* x_tabs_hdr_on_btn_save() */
+
+
+
 
 /* --------------------------------------------------------
  *
@@ -1062,10 +1110,10 @@ x_tabs_cancel_all (GschemToplevel* w_current)
     o_grips_cancel (w_current);
   }
 
-  TOPLEVEL* toplevel = gschem_toplevel_get_toplevel (w_current);
+  LeptonToplevel* toplevel = gschem_toplevel_get_toplevel (w_current);
   if (toplevel->page_current != NULL)
   {
-    geda_object_list_delete (toplevel->page_current->place_list);
+    lepton_object_list_delete (toplevel->page_current->place_list);
     toplevel->page_current->place_list = NULL;
   }
 
@@ -1091,15 +1139,15 @@ x_tabs_cancel_all (GschemToplevel* w_current)
 static void
 x_tabs_hier_up (GschemToplevel* w_current)
 {
-  TOPLEVEL* toplevel = gschem_toplevel_get_toplevel (w_current);
-  PAGE* page = toplevel->page_current;
+  LeptonToplevel* toplevel = gschem_toplevel_get_toplevel (w_current);
+  LeptonPage* page = toplevel->page_current;
 
   if (page == NULL)
   {
     return;
   }
 
-  PAGE* parent = s_hierarchy_find_up_page (toplevel->pages, page);
+  LeptonPage* parent = s_hierarchy_find_up_page (toplevel->pages, page);
 
   if (parent == NULL)
   {
@@ -1187,7 +1235,8 @@ x_tabs_prev (GschemToplevel* w_current)
  *  \return                 A pointer to the new TabInfo structure.
  */
 static TabInfo*
-x_tabs_page_new (GschemToplevel* w_current, PAGE* page)
+x_tabs_page_new (GschemToplevel* w_current,
+                 LeptonPage* page)
 {
 #ifdef DEBUG
   printf( "x_tabs_new_page(): page: %p\n", page);
@@ -1241,7 +1290,7 @@ x_tabs_create (GschemToplevel* w_current, GtkWidget* work_box)
  *  \return                The page opened.
  *
  */
-PAGE*
+LeptonPage*
 x_tabs_page_open (GschemToplevel* w_current, const gchar* filename)
 {
   g_return_val_if_fail (w_current != NULL, NULL);
@@ -1278,7 +1327,7 @@ x_tabs_page_open (GschemToplevel* w_current, const gchar* filename)
   }
 
 
-  PAGE* page = NULL;
+  LeptonPage* page = NULL;
   if (filename != NULL)
     page = s_page_search (w_current->toplevel, filename);
 
@@ -1360,7 +1409,8 @@ x_tabs_page_open (GschemToplevel* w_current, const gchar* filename)
  *
  */
 void
-x_tabs_page_set_cur (GschemToplevel* w_current, PAGE* page)
+x_tabs_page_set_cur (GschemToplevel* w_current,
+                     LeptonPage* page)
 {
   g_return_if_fail (w_current != NULL);
 
@@ -1432,7 +1482,8 @@ x_tabs_page_set_cur (GschemToplevel* w_current, PAGE* page)
  *
  */
 void
-x_tabs_page_close (GschemToplevel* w_current, PAGE* page)
+x_tabs_page_close (GschemToplevel* w_current,
+                   LeptonPage* page)
 {
   g_return_if_fail (w_current != NULL);
 
@@ -1449,7 +1500,7 @@ x_tabs_page_close (GschemToplevel* w_current, PAGE* page)
 
   /* page to be set as current after the [page] is closed:
   */
-  PAGE* new_cur_page = x_window_close_page_impl (w_current, nfo_cur->page_);
+  LeptonPage* new_cur_page = x_window_close_page_impl (w_current, nfo_cur->page_);
 
   x_tabs_nbook_page_close (w_current, nfo_cur->page_);
 
@@ -1464,7 +1515,7 @@ x_tabs_page_close (GschemToplevel* w_current, PAGE* page)
   else
   {
 #ifdef DEBUG
-    printf( "x_tabs_page_close(): NEW PAGE\n" );
+    printf( "x_tabs_page_close(): NEW LeptonPage\n" );
 #endif
 
     x_tabs_page_new  (w_current, NULL);
@@ -1498,7 +1549,7 @@ x_tabs_page_on_sel (GtkNotebook* nbook,
 {
   GschemToplevel* w_current = (GschemToplevel*) data;
 
-  PAGE*           p_cur  = x_tabs_tl_page_cur  (w_current);
+  LeptonPage*     p_cur  = x_tabs_tl_page_cur  (w_current);
   GschemPageView* pv_cur = x_tabs_tl_pview_cur (w_current);
 
   if (p_cur == NULL && pv_cur == NULL)
@@ -1543,8 +1594,8 @@ x_tabs_page_on_reordered (GtkNotebook* nbook,
   TabInfo* nfo = x_tabs_info_find_by_wtab (w_current->xtabs_info_list, wtab);
   g_return_if_fail (nfo != NULL);
 
-  GedaPageList* pages = w_current->toplevel->pages;
-  geda_list_move_item (pages, nfo->page_, newindex);
+  LeptonPageList* pages = w_current->toplevel->pages;
+  lepton_list_move_item (pages, nfo->page_, newindex);
 
   gtk_widget_grab_focus (GTK_WIDGET (nfo->pview_));
   page_select_widget_update (w_current);
@@ -1568,15 +1619,15 @@ x_tabs_menu_create (TabInfo* nfo)
   g_return_val_if_fail (tl != NULL, NULL);
 
   GtkWidget* menu = gtk_menu_new();
-  x_tabs_menu_create_item (tl, menu, "file-new", _("_New"), GTK_STOCK_NEW);
-  x_tabs_menu_create_item (tl, menu, "file-open", _("_Open..."), GTK_STOCK_OPEN);
+  x_tabs_menu_create_item (tl, menu, "&file-new", _("_New"), GTK_STOCK_NEW);
+  x_tabs_menu_create_item (tl, menu, "&file-open", _("_Open..."), GTK_STOCK_OPEN);
   x_tabs_menu_create_item_separ (menu);
-  x_tabs_menu_create_item (tl, menu, "file-save", _("_Save"), GTK_STOCK_SAVE);
-  x_tabs_menu_create_item (tl, menu, "file-save-as", _("Save _As..."), GTK_STOCK_SAVE_AS);
+  x_tabs_menu_create_item (tl, menu, "&file-save", _("_Save"), GTK_STOCK_SAVE);
+  x_tabs_menu_create_item (tl, menu, "&file-save-as", _("Save _As..."), GTK_STOCK_SAVE_AS);
   x_tabs_menu_create_item_separ (menu);
-  x_tabs_menu_create_item (tl, menu, "page-manager", _("Page _Manager..."), NULL);
+  x_tabs_menu_create_item (tl, menu, "&page-manager", _("Page _Manager..."), NULL);
   x_tabs_menu_create_item_separ (menu);
-  x_tabs_menu_create_item (tl, menu, "page-close", _("_Close"), GTK_STOCK_CLOSE);
+  x_tabs_menu_create_item (tl, menu, "&page-close", _("_Close"), GTK_STOCK_CLOSE);
 
   gtk_widget_show_all (menu);
   return GTK_MENU (menu);
