@@ -2,7 +2,7 @@
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
  * Copyright (C) 2016 Peter Brett <peter@peter-b.co.uk>
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,13 +23,10 @@
 #include "gschem.h"
 
 
-#define GSCHEM_THEME_ICON_NAME "lepton-schematic"
-
-
-
 static void
-create_menubar (GschemToplevel *w_current, GtkWidget *main_box);
-
+create_menubar (GschemToplevel *w_current,
+                GtkWidget *main_box,
+                GtkWidget *menubar);
 
 static void
 create_toolbar_button (GschemToplevel *w_current,
@@ -105,7 +102,7 @@ untitled_next_index (GschemToplevel* w_current);
 static gchar*
 untitled_filename (GschemToplevel* w_current, gboolean log_skipped);
 
-static PAGE*
+static LeptonPage*
 x_window_new_page (GschemToplevel* w_current);
 
 
@@ -115,9 +112,10 @@ x_window_new_page (GschemToplevel* w_current);
  *  \par Function Description
  *
  */
-void x_window_setup (GschemToplevel *w_current)
+GschemToplevel*
+x_window_setup (GschemToplevel *w_current)
 {
-  TOPLEVEL *toplevel = gschem_toplevel_get_toplevel (w_current);
+  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
 
   /* immediately setup user params */
   i_vars_set(w_current);
@@ -131,8 +129,7 @@ void x_window_setup (GschemToplevel *w_current)
   /* Add to the list of windows */
   global_window_list = g_list_append (global_window_list, w_current);
 
-  /* X related stuff */
-  x_window_create_main (w_current);
+  return w_current;
 }
 
 /*! \todo Finish function documentation!!!
@@ -142,7 +139,7 @@ void x_window_setup (GschemToplevel *w_current)
  */
 void x_window_create_drawing(GtkWidget *scrolled, GschemToplevel *w_current)
 {
-  PAGE* page = w_current->toplevel->page_current;
+  LeptonPage* page = w_current->toplevel->page_current;
   GschemPageView* view = gschem_page_view_new_with_page (page);
 
 #ifdef ENABLE_GTK3
@@ -322,7 +319,7 @@ x_window_find_text (GtkWidget *widget, gint response, GschemToplevel *w_current)
     count = gschem_find_text_state_find (
         w_current,
         GSCHEM_FIND_TEXT_STATE (w_current->find_text_state),
-        geda_list_get_glist (w_current->toplevel->pages),
+        lepton_list_get_glist (w_current->toplevel->pages),
         gschem_find_text_widget_get_find_type (GSCHEM_FIND_TEXT_WIDGET (w_current->find_text_widget)),
         gschem_find_text_widget_get_find_text_string (GSCHEM_FIND_TEXT_WIDGET (w_current->find_text_widget)),
         gschem_find_text_widget_get_descend (GSCHEM_FIND_TEXT_WIDGET (w_current->find_text_widget)),
@@ -387,12 +384,14 @@ x_window_show_text (GtkWidget *widget, gint response, GschemToplevel *w_current)
 
 
 void
-x_window_select_object (GschemFindTextState *state, OBJECT *object, GschemToplevel *w_current)
+x_window_select_object (GschemFindTextState *state,
+                        LeptonObject *object,
+                        GschemToplevel *w_current)
 {
   GschemPageView *view = gschem_toplevel_get_current_page_view (w_current);
   g_return_if_fail (view != NULL);
 
-  PAGE *page = gschem_page_view_get_page (view);
+  LeptonPage *page = gschem_page_view_get_page (view);
   g_return_if_fail (page != NULL);
 
   g_return_if_fail (object != NULL);
@@ -430,7 +429,8 @@ x_window_translate_response (GschemTranslateWidget *widget, gint response, Gsche
  *  \par Function Description
  *
  */
-void x_window_create_main(GschemToplevel *w_current)
+GschemToplevel*
+x_window_create_main (GschemToplevel *w_current, GtkWidget *menubar)
 {
   GtkWidget *main_box = NULL;
   GtkWidget *hpaned = NULL;
@@ -469,7 +469,7 @@ void x_window_create_main(GschemToplevel *w_current)
   /*
   *  main menu:
   */
-  create_menubar (w_current, main_box);
+  create_menubar (w_current, main_box, menubar);
 
 
   gtk_widget_realize (w_current->main_window);
@@ -586,6 +586,7 @@ void x_window_create_main(GschemToplevel *w_current)
   /* focus page view: */
   gtk_widget_grab_focus (w_current->drawing_area);
 
+  return w_current;
 } /* x_window_create_main() */
 
 
@@ -602,7 +603,7 @@ void x_window_close(GschemToplevel *w_current)
   /* If we're closing whilst inside an action, re-wind the
    * page contents back to their state before we started */
   if (w_current->inside_action) {
-    i_callback_cancel (w_current, 0, NULL);
+    i_callback_cancel (NULL, w_current);
   }
 
   /* last chance to save possible unsaved pages */
@@ -702,12 +703,12 @@ void x_window_close_all(GschemToplevel *w_current)
  *  \private
  *  \par Function Description
  *  This function opens the file whose name is <B>filename</B> in a
- *  new PAGE of <B>toplevel</B>.
+ *  new LeptonPage of <B>toplevel</B>.
  *
- *  If there is no page for <B>filename</B> in <B>toplevel</B>'s list
- *  of pages, it creates a new PAGE, loads the file in it and returns
- *  a pointer on the new page. Otherwise it returns a pointer on the
- *  existing page.
+ *  If there is no page for <B>filename</B> in <B>toplevel</B>'s
+ *  list of pages, it creates a new LeptonPage, loads the file in
+ *  it and returns a pointer on the new page. Otherwise it returns
+ *  a pointer on the existing page.
  *
  *  If the filename passed is NULL, this function creates an empty,
  *  untitled page.  The name of the untitled page is build from
@@ -722,10 +723,11 @@ void x_window_close_all(GschemToplevel *w_current)
  *  \bug This code should check to make sure any untitled filename
  *  does not conflict with a file on disk.
  */
-PAGE*
-x_window_open_page_impl (GschemToplevel *w_current, const gchar *filename)
+LeptonPage*
+x_window_open_page_impl (GschemToplevel *w_current,
+                         const gchar *filename)
 {
-  TOPLEVEL *toplevel = gschem_toplevel_get_toplevel (w_current);
+  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
   g_return_val_if_fail (toplevel != NULL, NULL);
 
   /* New blank page requested: */
@@ -734,7 +736,7 @@ x_window_open_page_impl (GschemToplevel *w_current, const gchar *filename)
 
 
   /* Return existing page if it is already loaded: */
-  PAGE* page = s_page_search (toplevel, filename);
+  LeptonPage* page = s_page_search (toplevel, filename);
   if (page != NULL)
     return page;
 
@@ -794,7 +796,8 @@ x_window_open_page_impl (GschemToplevel *w_current, const gchar *filename)
  *  \param [in] page      The page to become current page.
  */
 void
-x_window_set_current_page_impl (GschemToplevel *w_current, PAGE *page)
+x_window_set_current_page_impl (GschemToplevel *w_current,
+                                LeptonPage *page)
 {
   GschemPageView *page_view = gschem_toplevel_get_current_page_view (w_current);
   g_return_if_fail (page_view != NULL);
@@ -829,7 +832,9 @@ x_window_set_current_page_impl (GschemToplevel *w_current, PAGE *page)
  *  \returns 1 on success, 0 otherwise.
  */
 gint
-x_window_save_page (GschemToplevel *w_current, PAGE *page, const gchar *filename)
+x_window_save_page (GschemToplevel *w_current,
+                    LeptonPage *page,
+                    const gchar *filename)
 {
   const gchar *log_msg, *state_msg;
   gint ret;
@@ -902,13 +907,14 @@ x_window_save_page (GschemToplevel *w_current, PAGE *page, const gchar *filename
  *
  *  \param [in] w_current The toplevel environment.
  *  \param [in] page      The page to close.
- *  \return               Pointer to a new current PAGE object.
+ *  \return               Pointer to a new current LeptonPage object.
  */
-PAGE*
-x_window_close_page_impl (GschemToplevel *w_current, PAGE *page)
+LeptonPage*
+x_window_close_page_impl (GschemToplevel *w_current,
+                          LeptonPage *page)
 {
-  TOPLEVEL *toplevel = gschem_toplevel_get_toplevel (w_current);
-  PAGE *new_current = NULL;
+  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
+  LeptonPage *new_current = NULL;
   GList *iter;
 
   g_return_val_if_fail (toplevel != NULL, NULL);
@@ -919,7 +925,7 @@ x_window_close_page_impl (GschemToplevel *w_current, PAGE *page)
   /* If we're closing whilst inside an action, re-wind the
    * page contents back to their state before we started */
   if (w_current->inside_action) {
-    i_callback_cancel (w_current, 0, NULL);
+    i_callback_cancel (NULL, w_current);
   }
 
   if (page == toplevel->page_current) {
@@ -929,12 +935,12 @@ x_window_close_page_impl (GschemToplevel *w_current, PAGE *page)
 
     if (new_current == NULL) {
       /* no up in hierarchy, choice is prev, next, new page */
-      iter = g_list_find( geda_list_get_glist( toplevel->pages ), page );
+      iter = g_list_find( lepton_list_get_glist( toplevel->pages ), page );
 
       if ( g_list_previous( iter ) ) {
-        new_current = (PAGE *)g_list_previous( iter )->data;
+        new_current = (LeptonPage *)g_list_previous( iter )->data;
       } else if ( g_list_next( iter ) ) {
-        new_current = (PAGE *)g_list_next( iter )->data;
+        new_current = (LeptonPage *)g_list_next( iter )->data;
       } else {
         /* need to add a new untitled page */
         new_current = NULL;
@@ -973,47 +979,13 @@ x_window_close_page_impl (GschemToplevel *w_current, PAGE *page)
 } /* x_window_close_page_impl() */
 
 
-
-/*! \brief Setup default icon for GTK windows
- *
- *  \par Function Description
- *  Sets the default window icon by name, to be found in the current icon
- *  theme. The name used is \#defined above as GSCHEM_THEME_ICON_NAME.
- */
-void x_window_set_default_icon( void )
-{
-  gtk_window_set_default_icon_name( GSCHEM_THEME_ICON_NAME );
-}
-
-/*! \brief Setup icon search paths.
- * \par Function Description
- * Add the icons installed by gschem to the search path for the
- * default icon theme, so that they can be automatically found by GTK.
- */
-void
-x_window_init_icons (void)
-{
-	/* System icons */
-	/* FIXME this shouldn't be necessary; gschem should just install its
-	 * icons in the system hicolor icon theme and they'll be picked up
-	 * automatically. */
-	const gchar * const * sys_dirs = eda_get_system_data_dirs();
-	for (gint i = 0; sys_dirs[i]; ++i) {
-		gchar *icon_dir;
-		icon_dir = g_build_filename (sys_dirs[i], "icons", NULL);
-		gtk_icon_theme_append_search_path (gtk_icon_theme_get_default(),
-		                                   icon_dir);
-		g_free (icon_dir);
-	}
-}
-
 /*! \brief Creates and initializes a new lepton-schematic window.
  *
  * \return Pointer to the new GschemToplevel object.
  */
 GschemToplevel* x_window_new ()
 {
-  TOPLEVEL *toplevel = s_toplevel_new ();
+  LeptonToplevel *toplevel = s_toplevel_new ();
 
   /* Load old (*rc files) and new (*.conf) configuration: */
   x_rc_parse_gschem (toplevel, NULL);
@@ -1022,24 +994,22 @@ GschemToplevel* x_window_new ()
   gschem_toplevel_set_toplevel (w_current, toplevel);
 
   /* Damage notifications should invalidate the object on screen */
-  o_add_change_notify (toplevel,
-                       (ChangeNotifyFunc) o_invalidate,
-                       (ChangeNotifyFunc) o_invalidate, w_current);
+  lepton_object_add_change_notify (toplevel,
+                                   (ChangeNotifyFunc) o_invalidate,
+                                   (ChangeNotifyFunc) o_invalidate,
+                                   w_current);
 
   /* Initialize tabbed GUI: */
   x_tabs_init();
 
-  x_window_setup (w_current);
-
   return w_current;
 }
 
 
 
 static void
-create_menubar (GschemToplevel *w_current, GtkWidget *main_box)
+create_menubar (GschemToplevel *w_current, GtkWidget *main_box, GtkWidget *menubar)
 {
-  GtkWidget *menubar = get_main_menu (w_current);
 
 #ifdef ENABLE_GTK3
   gtk_box_pack_start (GTK_BOX (main_box), menubar, FALSE, FALSE, 0);
@@ -1153,25 +1123,25 @@ create_toolbar( GschemToplevel *w_current, GtkWidget *main_box )
 
   create_toolbar_button (w_current, toolbar,
                          "new", _("New"), _("New file"),
-                         G_CALLBACK (&i_callback_toolbar_file_new), 0);
+                         G_CALLBACK (&i_callback_file_new), 0);
 
   create_toolbar_button (w_current, toolbar,
                          "open", _("Open"), _("Open file"),
-                         G_CALLBACK (&i_callback_toolbar_file_open), 1);
+                         G_CALLBACK (&i_callback_file_open), 1);
 
   create_toolbar_button (w_current, toolbar,
                          "save", _("Save"), _("Save file"),
-                         G_CALLBACK (&i_callback_toolbar_file_save), 2);
+                         G_CALLBACK (&i_callback_file_save), 2);
 
   create_toolbar_separator (toolbar, 3);
 
   create_toolbar_button (w_current, toolbar,
                          "undo", _("Undo"), _("Undo last operation"),
-                         G_CALLBACK (&i_callback_toolbar_edit_undo), 4);
+                         G_CALLBACK (&i_callback_edit_undo), 4);
 
   create_toolbar_button (w_current, toolbar,
                          "redo", _("Redo"), _("Redo last undo"),
-                         G_CALLBACK (&i_callback_toolbar_edit_redo), 5);
+                         G_CALLBACK (&i_callback_edit_redo), 5);
 
   create_toolbar_separator (toolbar, 6);
 
@@ -1181,7 +1151,7 @@ create_toolbar( GschemToplevel *w_current, GtkWidget *main_box )
 
   create_toolbar_button (w_current, toolbar,
                          "insert-symbol", _("Component"), text,
-                         G_CALLBACK (&i_callback_toolbar_add_component), 7);
+                         G_CALLBACK (&i_callback_add_component), 7);
 
 
   GSList *radio_group = NULL;
@@ -1204,7 +1174,7 @@ create_toolbar( GschemToplevel *w_current, GtkWidget *main_box )
 
   create_toolbar_button (w_current, toolbar,
                          "insert-text", _("Text"), _("Add Text..."),
-                         G_CALLBACK (&i_callback_toolbar_add_text), 10);
+                         G_CALLBACK (&i_callback_add_text), 10);
 
   create_toolbar_separator (toolbar, 11);
 
@@ -1497,10 +1467,10 @@ create_notebook_bottom (GschemToplevel* w_current)
  *  \see x_window_open_page_impl()
  *  \see x_tabs_page_open()
  */
-PAGE*
+LeptonPage*
 x_window_open_page (GschemToplevel* w_current, const gchar* filename)
 {
-  PAGE* page = NULL;
+  LeptonPage* page = NULL;
 
   if (x_tabs_enabled())
   {
@@ -1530,7 +1500,8 @@ x_window_open_page (GschemToplevel* w_current, const gchar* filename)
  *  \see x_tabs_page_set_cur()
  */
 void
-x_window_set_current_page (GschemToplevel* w_current, PAGE* page)
+x_window_set_current_page (GschemToplevel* w_current,
+                           LeptonPage* page)
 {
   if (x_tabs_enabled())
   {
@@ -1550,7 +1521,8 @@ x_window_set_current_page (GschemToplevel* w_current, PAGE* page)
  *  \see x_tabs_page_close()
  */
 void
-x_window_close_page (GschemToplevel* w_current, PAGE* page)
+x_window_close_page (GschemToplevel* w_current,
+                     LeptonPage* page)
 {
   if (x_tabs_enabled())
   {
@@ -1571,19 +1543,19 @@ x_window_close_page (GschemToplevel* w_current, PAGE* page)
  *
  *  \param w_current The toplevel environment.
  */
-static PAGE*
+static LeptonPage*
 x_window_new_page (GschemToplevel* w_current)
 {
   g_return_val_if_fail (w_current != NULL, NULL);
 
-  TOPLEVEL* toplevel = gschem_toplevel_get_toplevel (w_current);
+  LeptonToplevel* toplevel = gschem_toplevel_get_toplevel (w_current);
   g_return_val_if_fail (toplevel != NULL, NULL);
 
   /* New page file name: */
   gchar* filename = untitled_filename (w_current, TRUE);
 
   /* Create a new page: */
-  PAGE* page = s_page_new (toplevel, filename);
+  LeptonPage* page = s_page_new (toplevel, filename);
 
   /* Switch to a new page: */
   s_page_goto (toplevel, page);
@@ -1716,7 +1688,7 @@ untitled_filename (GschemToplevel* w_current, gboolean log_skipped)
   gchar* fname = NULL;
   gchar* fpath = NULL;
 
-  TOPLEVEL* toplevel = gschem_toplevel_get_toplevel (w_current);
+  LeptonToplevel* toplevel = gschem_toplevel_get_toplevel (w_current);
 
   for (;;)
   {
@@ -1771,7 +1743,7 @@ untitled_filename (GschemToplevel* w_current, gboolean log_skipped)
  *  \return           TRUE if a \a page looks like "untitled" one.
  */
 gboolean
-x_window_untitled_page (PAGE* page)
+x_window_untitled_page (LeptonPage* page)
 {
   g_return_val_if_fail (page != NULL, TRUE);
 
