@@ -1,11 +1,12 @@
 #!/usr/bin/env sh
 export GUILE_LOAD_COMPILED_PATH="@ccachedir@:${GUILE_LOAD_COMPILED_PATH}"
+export GUILE_LOAD_PATH="@LEPTON_SCHEME_MODULE_DIRECTORY@:${GUILE_LOAD_PATH}"
 exec @GUILE@ -s "$0" "$@"
 !#
 
 ;;; Lepton EDA attribute editor
 ;;; Copyright (C) 1998-2016 gEDA Contributors
-;;; Copyright (C) 2017-2020 Lepton EDA Contributors
+;;; Copyright (C) 2017-2021 Lepton EDA Contributors
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -23,7 +24,8 @@ exec @GUILE@ -s "$0" "$@"
 
 
 (use-modules (ice-9 match)
-             (srfi srfi-37)
+             (srfi srfi-1)
+             (lepton srfi-37)
              (system foreign))
 
 ;;; Load and initialize liblepton library.
@@ -31,102 +33,17 @@ exec @GUILE@ -s "$0" "$@"
                 "liblepton_init")
 
 (primitive-eval '(use-modules (lepton color-map)
+                              (lepton config)
                               (lepton eval)
+                              (lepton ffi)
+                              (lepton file-system)
                               (lepton log)
+                              (lepton os)
                               (lepton version)
                               (schematic core gettext)
                               (schematic ffi)
-                              (schematic ffi gtk)))
-
-(define register-funcs
-  (pointer->procedure
-   void
-   (dynamic-func "g_register_funcs" libleptongui)
-   '()))
-
-(define init-window
-  (pointer->procedure
-   void
-   (dynamic-func "g_init_window" libleptongui)
-   '()))
-
-(define init-select
-  (pointer->procedure
-   void
-   (dynamic-func "g_init_select" libleptongui)
-   '()))
-
-(define init-hook
-  (pointer->procedure
-   void
-   (dynamic-func "g_init_hook" libleptongui)
-   '()))
-
-(define init-action
-  (pointer->procedure
-   void
-   (dynamic-func "g_init_action" libleptongui)
-   '()))
-
-(define init-attrib
-  (pointer->procedure
-   void
-   (dynamic-func "g_init_attrib" libleptongui)
-   '()))
-
-(define init-keys
-  (pointer->procedure
-   void
-   (dynamic-func "g_init_keys" libleptongui)
-   '()))
-
-(define init-builtins
-  (pointer->procedure
-   void
-   (dynamic-func "g_init_builtins" libleptongui)
-   '()))
-
-(define init-util
-  (pointer->procedure
-   void
-   (dynamic-func "g_init_util" libleptongui)
-   '()))
-
-(define init-undo
-  (pointer->procedure
-   void
-   (dynamic-func "scheme_init_undo" libleptongui)
-   '()))
-
-(define init-buffers
-  (pointer->procedure
-   void
-   (dynamic-func "o_buffer_init" libleptongui)
-   '()))
-
-(define init-color
-  (pointer->procedure
-   void
-   (dynamic-func "x_color_init" libleptongui)
-   '()))
-
-(define init-undo*
-  (pointer->procedure
-   void
-   (dynamic-func "o_undo_init" libleptongui)
-   '()))
-
-(define set-quiet-mode!
-  (pointer->procedure
-   void
-   (dynamic-func "set_quiet_mode" libleptongui)
-   '()))
-
-(define set-verbose-mode!
-  (pointer->procedure
-   void
-   (dynamic-func "set_verbose_mode" libleptongui)
-   '()))
+                              (schematic ffi gtk)
+                              (schematic menu)))
 
 
 ;;; Localization.
@@ -149,16 +66,15 @@ exec @GUILE@ -s "$0" "$@"
   (set! %load-compiled-path (cons "@ccachedir@"
                                   %load-compiled-path)))
 (define (register-guile-funcs)
-  (register-funcs)
-  (init-window)
-  (init-select)
-  (init-hook)
-  (init-action)
-  (init-attrib)
-  (init-keys)
-  (init-builtins)
-  (init-util)
-  (init-undo))
+  (g_register_funcs)
+  (g_init_window)
+  (g_init_select)
+  (g_init_hook)
+  (g_init_action)
+  (g_init_attrib)
+  (g_init_keys)
+  (g_init_util)
+  (scheme_init_undo))
 
 (define (precompile-run)
   (let ((script (getenv "LEPTON_SCM_PRECOMPILE_SCRIPT")))
@@ -194,7 +110,6 @@ exec @GUILE@ -s "$0" "$@"
   (format #t
           (G_ "Usage: ~A [OPTION ...] [--] [FILE ...]
 
-
 Interactively edit Lepton EDA schematics or symbols.
 If one or more FILEs are specified, open them for
 editing; otherwise, create a new, empty schematic.
@@ -203,7 +118,7 @@ Options:
   -q, --quiet              Quiet mode.
   -v, --verbose            Verbose mode.
   -L DIR                   Add DIR to Scheme search path.
-  -c EXPR                  Scheme expression to run at startup.
+  -c EXPR, --command=EXPR  Scheme expression to run at startup.
   -s FILE                  Scheme script to run at startup.
   -V, --version            Show version information.
   -h, --help               Help; this message.
@@ -211,27 +126,28 @@ Options:
 
 Report bugs at ~S
 Lepton EDA homepage: ~S\n")
-          (car (program-arguments))
+          (basename (car (program-arguments)))
           (lepton-version-ref 'bugs)
           (lepton-version-ref 'url))
-  (primitive-exit 0))
+  (exit 0))
 
 
 ;;; Parse lepton-schematic command-line options, displaying usage
 ;;; message or version information as required.
 (define (parse-commandline)
-  "Parse command line options"
+  "Parse command line options.  Return the list of non-option
+arguments which should represent the list of schematics to open."
   (reverse
    (args-fold
     (cdr (program-arguments))
     (list
      (option '(#\q "quiet") #f #f
              (lambda (opt name arg seeds)
-               (set-quiet-mode!)
+               (set_quiet_mode)
                seeds))
      (option '(#\v "verbose") #f #f
              (lambda (opt name arg seeds)
-               (set-verbose-mode!)
+               (set_verbose_mode)
                seeds))
      (option '(#\L) #t #f
              (lambda (opt name arg seeds)
@@ -241,7 +157,7 @@ Lepton EDA homepage: ~S\n")
              (lambda (opt name arg seeds)
                (add-post-load-expr! arg #t)
                seeds))
-     (option '(#\c) #t #f
+     (option '(#\c "command") #t #f
              (lambda (opt name arg seeds)
                (add-post-load-expr! arg #f)
                seeds))
@@ -251,7 +167,7 @@ Lepton EDA homepage: ~S\n")
      (option '(#\V "version") #f #f
              (lambda (opt name arg seeds)
                (display-lepton-version #:print-name #t #:copyright #t)
-               (primitive-exit 0))))
+               (exit 0))))
     (lambda (opt name arg seeds)
       (format #t
               (G_ "ERROR: Unknown option ~A.
@@ -260,47 +176,157 @@ Run `~A --help' for more information.\n")
                   (string-append "-" (char-set->string (char-set name)))
                   (string-append "--" name))
               (basename (car (program-arguments))))
-      (primitive-exit 1))
+      (exit 1))
     (lambda (op seeds) (cons op seeds))
     '())))
 
 
-(define main
-  (pointer->procedure
-   '*
-   (dynamic-func "main_prog" libleptongui)
-   (list '*)))
+;;; Load GTK resource files.
+;;; Search system and user configuration directories for
+;;; lepton-gtkrc files and load them in sequence.
+(define (parse-gtkrc)
+  (let loop ((dirs (append (sys-config-dirs)
+                           (list (user-config-dir)))))
+    (or (null? dirs)
+        (let ((filename (string-append (car dirs)
+                                       file-name-separator-string
+                                       "lepton-gtkrc")))
+          (when (file-readable? filename)
+            (gtk_rc_parse filename))
+          (loop (cdr dirs))))))
+
+
+
+
+;;; Setup default icon for GTK windows
+;;; Sets the default window icon by name, to be found in the
+;;; current icon theme.
+(define (set-window-default-icon)
+  (define %theme-icon-name "lepton-schematic")
+
+  (gtk_window_set_default_icon_name %theme-icon-name))
+
+;;; Setup icon search paths.
+;;; Add the icons installed by the program to the search path for
+;;; the default icon theme, so that they can be automatically
+;;; found by GTK.
+(define (init-window-icons)
+  ;; FIXME: this shouldn't be necessary, Lepton should just
+  ;; install its icons in the system hicolor icon theme and
+  ;; they'll be picked up automatically.
+  (let loop ((sys-dirs (sys-data-dirs)))
+    (or (null? sys-dirs)
+        (let ((icon-dir (string-append (car sys-dirs)
+                                       file-name-separator-string
+                                       "icons")))
+          (gtk_icon_theme_append_search_path (gtk_icon_theme_get_default)
+                                             icon-dir)
+          (loop (cdr sys-dirs))))))
+
+
+(define (open-log-window window)
+  (let ((cfg (path-config-context (getcwd))))
+    (when (string= (config-string cfg "schematic" "log-window")
+                   "startup")
+      (x_widgets_show_log window))))
+
+
+(define (get-absolute-filenames filename-list cwd)
+  (define (get-absolute-filename filename)
+    (if (absolute-file-name? filename)
+        ;; Path is already absolute so no need to do any concat of
+        ;; cwd.
+        filename
+        ;; Get absolute path.  At this point the filename might be
+        ;; unnormalized, like /path/to/foo/../bar/baz.sch.  Bad
+        ;; filenames will be normalized in f_open (called by
+        ;; x_window_open_page). This works for Linux and MINGW32.
+        (string-append cwd
+                       file-name-separator-string
+                       filename)))
+
+  (map get-absolute-filename filename-list))
+
+;;; Creates a new window in lepton-schematic.
+(define (make-schematic-window)
+  (define new-window (x_window_setup (x_window_new)))
+
+  (x_window_create_main new-window
+                        (make-main-menu new-window)))
+
+(define (main file-list)
+  ;; Create a new window and associated LeptonToplevel object.
+  (define window (make-schematic-window))
+  ;; Current directory.
+  (define cwd (getcwd))
+
+  (define (open-page *filename)
+    (x_window_open_page window *filename))
+
+  (define (string-ls->pointer-ls ls)
+    (map string->pointer ls))
+
+  ;; Open up log window on startup if requested in config.
+  (open-log-window window)
+
+  (let* ((filenames (get-absolute-filenames file-list cwd))
+         (*filenames (if (null? filenames)
+                         (list %null-pointer)
+                         (string-ls->pointer-ls filenames)))
+         (*pages (map open-page *filenames))
+         (*current-page (last *pages)))
+
+    ;; Update the window to show the current page:
+    (x_window_set_current_page window *current-page))
+
+  ;; Return the new window.
+  window)
+
 
 ;;; Init logging.
 (init-log "schematic")
 (display-lepton-version #:print-name #t #:log #t)
 
 ;;; Precompilation.
-(if (precompile-mode)
-    (precompile-prepare)
-    (set-guile-compiled-path))
-
-;;; Run precompilation.
+;;; If precompilation is requested, run it and exit.
 (when (precompile-mode)
-  (primitive-exit (precompile-run)))
+  (precompile-prepare)
+  (exit (precompile-run)))
+
+;;; Set up paths for Lepton's compiled Scheme modules.
+(set-guile-compiled-path)
 
 ;;; Initialize GTK.
 (gtk_init %null-pointer %null-pointer)
 
 ;;; Init global buffers.
-(init-buffers)
+(o_buffer_init)
 
 ;;; Register guile (scheme) functions
 (register-guile-funcs)
 
 ;;; Initialise color map (need to do this before reading rc
 ;;; files).
-(init-color)
-(init-undo*)
+(x_color_init)
+(o_undo_init)
+
+;;; Parse custom GTK resource files.
+(parse-gtkrc)
+
+;;; Set default icon theme and make sure we can find our own
+;;; icons.
+(set-window-default-icon)
+(init-window-icons)
+
+;;; Enable rendering of placeholders.
+(set_render_placeholders)
+
+;;; Init libstroke.
+(x_stroke_init)
 
 (let* ((schematics (parse-commandline))
        ;; Foreign pointer to w_current.
-       (window (main (scm->pointer schematics))))
+       (window (main schematics)))
 
   ;; %lepton-window is a fluid defined in C code, namely in
   ;; g_window.c.  When a new lepton-schematic window is created,
